////////////////////////////////////////////////////////////////////////////////
///	\file		CFW11_vars.inc
///
///	\brief		Definition of all inverter parameters and the methods to access
///				these parameters.
///
///	\version	5,70
///
///	\author		WEG
////////////////////////////////////////////////////////////////////////////////

VARIABLE g_wParNumber
{
	LABEL		"Parameter Number";
	CLASS		LOCAL;
	TYPE		UNSIGNED_INTEGER(2);
}

COMMAND WRITE_PAR_NUMBER
{
	SLOT 0;
	INDEX 48;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST { g_wParNumber }
		REPLY { }
	}
}

VARIABLE P0001
{
	LABEL "P0001 Speed Reference|de|P0001 Drehzahlsollwert|es|P0001 Referencia Velocidad";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 18000;
	}
	CONSTANT_UNIT "rpm";
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0001
	}
}

COMMAND READ_P0001
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0001 }
	}
}

METHOD SET_PAR_NUMBER_0001
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0002
{
	LABEL "P0002 Motor Speed     |de|P0002 Motordrehzahl|es|P0002 Velocidad Motor ";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 18000;
	}
	CONSTANT_UNIT "rpm";
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0002
	}
}

COMMAND READ_P0002
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0002 }
	}
}

METHOD SET_PAR_NUMBER_0002
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 2;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0003
{
	LABEL "P0003 Motor Current   |de|P0003 Motorstrom|es|P0003 Corriente Motor ";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE UNSIGNED_INTEGER(2)
	{
		SCALING_FACTOR 0.1;
	}
	CONSTANT_UNIT "A";
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0003
	}
}

COMMAND READ_P0003
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0003 }
	}
}

METHOD SET_PAR_NUMBER_0003
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 3;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0004
{
	LABEL "P0004 DC Link Voltage (Ud)|de|P0004 Zwischenkreisspannung|es|P0004 Tensin Bus CC";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 2000;
	}
	CONSTANT_UNIT "V";
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0004
	}
}

COMMAND READ_P0004
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0004 }
	}
}

METHOD SET_PAR_NUMBER_0004
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 4;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0005
{
	LABEL "P0005 Motor Frequency |de|P0005 Motorfrequenz|es|P0005 Frecuencia Motor";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE UNSIGNED_INTEGER(2)
	{
		SCALING_FACTOR 0.1;
	}
	CONSTANT_UNIT "Hz";
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0005
	}
}

COMMAND READ_P0005
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0005 }
	}
}

METHOD SET_PAR_NUMBER_0005
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 5;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0006
{
	LABEL "P0006 VFD Status      |de|P0006 Umrichterstatus|es|P0006 Estado Convertidor";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE ENUMERATED(2)
	{
		{ 0, "Ready|de|Ready (Bereit)|es|Ready (Pronto)" },
		{ 1, "Run  |de|Run (Betrieb)|es|Run(Ejecucin)" },
		{ 2, "Undervoltage|de|Unterspannung|es|Subtensin" },
		{ 3, "Fault|de|Fehler|es|Falla" },
		{ 4, "Self-Tuning|de|Selbstabgleich|es|Autoajuste" },
		{ 5, "Configuration|de|Konfiguration|es|Configuracin" },
		{ 6, "DC-Braking|de|G.Strom-Bremse|es|Frenado CC" },
		{ 7, "STO|de|STO|es|STO" }
		DEFAULT_VALUE 0;
	}
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0006
	}
}

COMMAND READ_P0006
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0006 }
	}
}

METHOD SET_PAR_NUMBER_0006
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 6;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0007
{
	LABEL "P0007 Motor Voltage   |de|P0007 Motorspannung|es|P0007 Tensin Salida  ";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 2000;
	}
	CONSTANT_UNIT "V";
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0007
	}
}

COMMAND READ_P0007
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0007 }
	}
}

METHOD SET_PAR_NUMBER_0007
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 7;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0009
{
	LABEL "P0009 Motor Torque    |de|P0009 Motordrehmoment|es|P0009 Torque en el Motor ";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE INTEGER(2)
	{
		SCALING_FACTOR 0.1;
	}
	CONSTANT_UNIT "%";
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0009
	}
}

COMMAND READ_P0009
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0009 }
	}
}

METHOD SET_PAR_NUMBER_0009
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 9;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0010
{
	LABEL "P0010 Output Power    |de|P0010 Ausgangsleistung|es|P0010 Potencia Salida ";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE UNSIGNED_INTEGER(2)
	{
		SCALING_FACTOR 0.1;
	}
	CONSTANT_UNIT "kW";
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0010
	}
}

COMMAND READ_P0010
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0010 }
	}
}

METHOD SET_PAR_NUMBER_0010
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 10;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0011
{
	LABEL "P0011 Output cosPhi|de|P0011 cosPhi Ausgang|es|P0011 cosPhi Salida";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE UNSIGNED_INTEGER(2)
	{
		SCALING_FACTOR 0.01;
	}
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0011
	}
}

COMMAND READ_P0011
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0011 }
	}
}

METHOD SET_PAR_NUMBER_0011
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 11;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0012
{
	LABEL "P0012 DI8 to DI1 Status|de|P0012 DI8...DI1 Status|es|P0012 Estado DI8...DI1";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE BIT_ENUMERATED(2)
	{
		{ 0x0001, "DI1|de|DI1|es|DI1" },
		{ 0x0002, "DI2|de|DI2|es|DI2" },
		{ 0x0004, "DI3|de|DI3|es|DI3" },
		{ 0x0008, "DI4|de|DI4|es|DI4" },
		{ 0x0010, "DI5|de|DI5|es|DI5" },
		{ 0x0020, "DI6|de|DI6|es|DI6" },
		{ 0x0040, "DI7|de|DI7|es|DI7" },
		{ 0x0080, "DI8|de|DI8|es|DI8" }
		DEFAULT_VALUE 0;
	}
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0012
	}
}

COMMAND READ_P0012
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0012 }
	}
}

METHOD SET_PAR_NUMBER_0012
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 12;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0013
{
	LABEL "P0013 DO5 to DO1 Status|de|P0013 DO5...DO1 Status|es|P0013 Estado DO5...DO1";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE BIT_ENUMERATED(2)
	{
		{ 0x0001, "DO1|de|DO1|es|DO1" },
		{ 0x0002, "DO2|de|DO2|es|DO2" },
		{ 0x0004, "DO3|de|DO3|es|DO3" },
		{ 0x0008, "DO4|de|DO4|es|DO4" },
		{ 0x0010, "DO5|de|DO5|es|DO5" }
		DEFAULT_VALUE 0;
	}
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0013
	}
}

COMMAND READ_P0013
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0013 }
	}
}

METHOD SET_PAR_NUMBER_0013
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 13;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0014
{
	LABEL "P0014 AO1 Value       |de|P0014 AO1 Wert|es|P0014 Valor de AO1    ";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE UNSIGNED_INTEGER(2)
	{
		SCALING_FACTOR 0.01;
	}
	CONSTANT_UNIT "%";
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0014
	}
}

COMMAND READ_P0014
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0014 }
	}
}

METHOD SET_PAR_NUMBER_0014
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 14;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0015
{
	LABEL "P0015 AO2 Value       |de|P0015 AO2 Wert|es|P0015 Valor de AO2    ";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE UNSIGNED_INTEGER(2)
	{
		SCALING_FACTOR 0.01;
	}
	CONSTANT_UNIT "%";
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0015
	}
}

COMMAND READ_P0015
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0015 }
	}
}

METHOD SET_PAR_NUMBER_0015
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 15;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0016
{
	LABEL "P0016 AO3 Value       |de|P0016 AO3 Wert|es|P0016 Valor de AO3    ";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE INTEGER(2)
	{
		SCALING_FACTOR 0.01;
	}
	CONSTANT_UNIT "%";
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0016
	}
}

COMMAND READ_P0016
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0016 }
	}
}

METHOD SET_PAR_NUMBER_0016
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 16;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0017
{
	LABEL "P0017 AO4 Value       |de|P0017 AO4 Wert|es|P0017 Valor de AO4    ";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE INTEGER(2)
	{
		SCALING_FACTOR 0.01;
	}
	CONSTANT_UNIT "%";
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0017
	}
}

COMMAND READ_P0017
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0017 }
	}
}

METHOD SET_PAR_NUMBER_0017
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 17;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0018
{
	LABEL "P0018 AI1 Value       |de|P0018 AI1 Wert|es|P0018 Valor de AI1    ";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE INTEGER(2)
	{
		SCALING_FACTOR 0.01;
	}
	CONSTANT_UNIT "%";
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0018
	}
}

COMMAND READ_P0018
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0018 }
	}
}

METHOD SET_PAR_NUMBER_0018
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 18;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0019
{
	LABEL "P0019 AI2 Value       |de|P0019 AI2 Wert|es|P0019 Valor de AI2    ";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE INTEGER(2)
	{
		SCALING_FACTOR 0.01;
	}
	CONSTANT_UNIT "%";
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0019
	}
}

COMMAND READ_P0019
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0019 }
	}
}

METHOD SET_PAR_NUMBER_0019
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 19;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0020
{
	LABEL "P0020 AI3 Value       |de|P0020 AI3 Wert|es|P0020 Valor de AI3    ";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE INTEGER(2)
	{
		SCALING_FACTOR 0.01;
	}
	CONSTANT_UNIT "%";
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0020
	}
}

COMMAND READ_P0020
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0020 }
	}
}

METHOD SET_PAR_NUMBER_0020
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 20;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0021
{
	LABEL "P0021 AI4 Value       |de|P0021 AI4 Wert|es|P0021 Valor de AI4    ";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE INTEGER(2)
	{
		SCALING_FACTOR 0.01;
	}
	CONSTANT_UNIT "%";
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0021
	}
}

COMMAND READ_P0021
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0021 }
	}
}

METHOD SET_PAR_NUMBER_0021
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 21;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0023
{
	LABEL "P0023 Software Version|de|P0023 Softwareversion|es|P0023 Versin Software ";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE UNSIGNED_INTEGER(2)
	{
		SCALING_FACTOR 0.01;
	}
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0023
	}
}

COMMAND READ_P0023
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0023 }
	}
}

METHOD SET_PAR_NUMBER_0023
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 23;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0025
{
	LABEL "P0025 DI16 to DI9 Status|de|P0025 DI16...DI9 Status|es|P0025 Estado DI16...DI9";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE BIT_ENUMERATED(2)
	{
		{ 0x0001, "DI9|de|DI9|es|DI9" },
		{ 0x0002, "DI10|de|DI10|es|DI10" },
		{ 0x0004, "DI11|de|DI11|es|DI11" },
		{ 0x0008, "DI12|de|DI12|es|DI12" },
		{ 0x0010, "DI13|de|DI13|es|DI13" },
		{ 0x0020, "DI14|de|DI14|es|DI14" },
		{ 0x0040, "DI15|de|DI15|es|DI15" },
		{ 0x0080, "DI16|de|DI16|es|DI16" }
		DEFAULT_VALUE 0;
	}
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0025
	}
}

COMMAND READ_P0025
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0025 }
	}
}

METHOD SET_PAR_NUMBER_0025
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 25;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0026
{
	LABEL "P0026 DO13 to DO6 Status|de|P0026 DO13...DO6 Status|es|P0026 Estado DO13...DO6";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE BIT_ENUMERATED(2)
	{
		{ 0x0001, "DO6|de|DO6|es|DO6" },
		{ 0x0002, "DO7|de|DO7|es|DO7" },
		{ 0x0004, "DO8|de|DO8|es|DO8" },
		{ 0x0008, "DO9|de|DO9|es|DO9" },
		{ 0x0010, "DO10|de|DO10|es|DO10" },
		{ 0x0020, "DO11|de|DO11|es|DO11" },
		{ 0x0040, "DO12|de|DO12|es|DO12" },
		{ 0x0080, "DO13|de|DO13|es|DO13" }
		DEFAULT_VALUE 0;
	}
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0026
	}
}

COMMAND READ_P0026
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0026 }
	}
}

METHOD SET_PAR_NUMBER_0026
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 26;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0027
{
	LABEL "P0027 Accessories Config. 1|de|P0027 Zubehrkonfig. 1|es|P0027 Config. Accesorios 1";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 65535;
	}
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0027
	}
}

COMMAND READ_P0027
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0027 }
	}
}

METHOD SET_PAR_NUMBER_0027
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 27;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0028
{
	LABEL "P0028 Accessories Config. 2|de|P0028 Zubehrkonfig. 2|es|P0028 Config. Accesorios 2";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 65535;
	}
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0028
	}
}

COMMAND READ_P0028
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0028 }
	}
}

METHOD SET_PAR_NUMBER_0028
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 28;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0029
{
	LABEL "P0029 Power Hardware Config|de|P0029 Leistungs-HW Konfig.|es|P0029 Config. HW Potencia";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE BIT_ENUMERATED(2)
	{
		{ 0x003F, "Rated Current|de|Nennstrom|es|Corriente Nom." },
		{ 0x00C0, "Rated Voltage|de|Nennspannung|es|Tensin Nom." },
		{ 0x0100, "EMC Filter|de|EMV Filter|es|Filtro EMC" },
		{ 0x0200, "Safety Relay|de|Sicherh. Rel.|es|Rel Seguridad" },
		{ 0x0400, "(0)24V/(1)DC Link |de|(0)24V/(1)DC Link |es|(0)24V/(1)Bus CC" },
		{ 0x0800, "DC special Hw|de|DC SpezialHW|es|Hw especial DC" },
		{ 0x1000, "Dyn.Brak. IGBT|de|BremsIGBT|es|IGBT Frenado " },
		{ 0x2000, "Special|de|Speziell|es|Especial" },
		{ 0xC000, "Reserved|de|Reserviert|es|Reservado" }
		DEFAULT_VALUE 0;
	}
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0029
	}
}

COMMAND READ_P0029
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0029 }
	}
}

METHOD SET_PAR_NUMBER_0029
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 29;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0030
{
	LABEL "P0030 IGBTs Temperature U|de|P0030 Temperatur IGBTs U|es|P0030 Temperatura IGBTs U";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE INTEGER(2)
	{
		SCALING_FACTOR 0.1;
	}
	CONSTANT_UNIT "C";
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0030
	}
}

COMMAND READ_P0030
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0030 }
	}
}

METHOD SET_PAR_NUMBER_0030
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 30;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0031
{
	LABEL "P0031 IGBTs Temperature V|de|P0031 Temperatur IGBTs V|es|P0031 Temperatura IGBTs V";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE INTEGER(2)
	{
		SCALING_FACTOR 0.1;
	}
	CONSTANT_UNIT "C";
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0031
	}
}

COMMAND READ_P0031
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0031 }
	}
}

METHOD SET_PAR_NUMBER_0031
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 31;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0032
{
	LABEL "P0032 IGBTs Temperature W|de|P0032 Temperatur IGBTs W|es|P0032 Temperatura IGBTs W";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE INTEGER(2)
	{
		SCALING_FACTOR 0.1;
	}
	CONSTANT_UNIT "C";
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0032
	}
}

COMMAND READ_P0032
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0032 }
	}
}

METHOD SET_PAR_NUMBER_0032
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 32;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0033
{
	LABEL "P0033 Rectifier Temperature|de|P0033 Gleichrichtertemp.|es|P0033 Temper. Rectificador";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE INTEGER(2)
	{
		SCALING_FACTOR 0.1;
	}
	CONSTANT_UNIT "C";
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0033
	}
}

COMMAND READ_P0033
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0033 }
	}
}

METHOD SET_PAR_NUMBER_0033
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 33;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0034
{
	LABEL "P0034 Internal Air Temp.|de|P0034 Interne Lufttemp.|es|P0034 Temper. Aire Interno";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE INTEGER(2)
	{
		SCALING_FACTOR 0.1;
	}
	CONSTANT_UNIT "C";
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0034
	}
}

COMMAND READ_P0034
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0034 }
	}
}

METHOD SET_PAR_NUMBER_0034
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 34;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0035
{
	LABEL "P0035 Control Air Temp.|de|P0035 Steuerkarte Lufttemp.|es|P0035 Temper. Aire Control";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE INTEGER(2)
	{
		SCALING_FACTOR 0.1;
	}
	CONSTANT_UNIT "C";
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0035
	}
}

COMMAND READ_P0035
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0035 }
	}
}

METHOD SET_PAR_NUMBER_0035
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 35;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0036
{
	LABEL "P0036 Fan Heatsink Speed|de|P0036 Lftergeschwindigkeit|es|P0036 Velocidad Ventilador";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 15000;
	}
	CONSTANT_UNIT "rpm";
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0036
	}
}

COMMAND READ_P0036
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0036 }
	}
}

METHOD SET_PAR_NUMBER_0036
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 36;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0037
{
	LABEL "P0037 Motor Overload Status|de|P0037 Motorberlaststatus|es|P0037 Sobrecarga del Motor";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 100;
	}
	CONSTANT_UNIT "%";
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0037
	}
}

COMMAND READ_P0037
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0037 }
	}
}

METHOD SET_PAR_NUMBER_0037
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 37;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0038
{
	LABEL "P0038 Encoder Speed|de|P0038 Drehgeber Geschw.|es|P0038 Velocidad del Encoder";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 65535;
	}
	CONSTANT_UNIT "rpm";
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0038
	}
}

COMMAND READ_P0038
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0038 }
	}
}

METHOD SET_PAR_NUMBER_0038
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 38;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0039
{
	LABEL "P0039 Encoder Pulses Count|de|P0039 Drehgeber PPR Zhler|es|P0039 Contador Pulsos Enc.";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 40000;
	}
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0039
	}
}

COMMAND READ_P0039
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0039 }
	}
}

METHOD SET_PAR_NUMBER_0039
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 39;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0040
{
	LABEL "P0040 PID Process Variable|de|P0040 Prozessvariable|es|P0040 Variable Proceso PID";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE UNSIGNED_INTEGER(2)
	{
		SCALING_FACTOR 0.1;
	}
	CONSTANT_UNIT "%";
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0040
	}
}

COMMAND READ_P0040
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0040 }
	}
}

METHOD SET_PAR_NUMBER_0040
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 40;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0041
{
	LABEL "P0041 PID Setpoint Value|de|P0041 PID Sollwert|es|P0041 Valor Setpoint PID";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE UNSIGNED_INTEGER(2)
	{
		SCALING_FACTOR 0.1;
	}
	CONSTANT_UNIT "%";
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0041
	}
}

COMMAND READ_P0041
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0041 }
	}
}

METHOD SET_PAR_NUMBER_0041
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 41;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0042
{
	LABEL "P0042 Time Powered    |de|P0042 Einschaltzeit|es|P0042 Horas Energizado";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 65535;
	}
	CONSTANT_UNIT "h";
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0042
	}
}

COMMAND READ_P0042
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0042 }
	}
}

METHOD SET_PAR_NUMBER_0042
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 42;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0043
{
	LABEL "P0043 Time Enabled    |de|P0043 Betriebszeit|es|P0043 Horas Habilitado";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE UNSIGNED_INTEGER(2)
	{
		SCALING_FACTOR 0.1;
	}
	CONSTANT_UNIT "h";
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0043
	}
}

COMMAND READ_P0043
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0043 }
	}
}

METHOD SET_PAR_NUMBER_0043
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 43;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0044
{
	LABEL "P0044 kWh Output Energy|de|P0044 kWh-Zhler|es|P0044 Contador kWh";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 65535;
	}
	CONSTANT_UNIT "kWh";
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0044
	}
}

COMMAND READ_P0044
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0044 }
	}
}

METHOD SET_PAR_NUMBER_0044
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 44;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0045
{
	LABEL "P0045 Fan Enabled Time|de|P0045 Laufzeit Lfter|es|P0045 Horas Ventil. Encend.";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 65535;
	}
	CONSTANT_UNIT "h";
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0045
	}
}

COMMAND READ_P0045
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0045 }
	}
}

METHOD SET_PAR_NUMBER_0045
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 45;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0048
{
	LABEL "P0048 Present Alarm      |de|P0048 Aktueller Alarm|es|P0048 Alarma Actual";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 999;
	}
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0048
	}
}

COMMAND READ_P0048
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0048 }
	}
}

METHOD SET_PAR_NUMBER_0048
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 48;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0049
{
	LABEL "P0049 Present Fault|de|P0049 Aktueller Fehler|es|P0049 Falla Actual";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 999;
	}
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0049
	}
}

COMMAND READ_P0049
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0049 }
	}
}

METHOD SET_PAR_NUMBER_0049
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 49;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0050
{
	LABEL "P0050 Last Fault|de|P0050 Letzter Fehler|es|P0050 ltima Falla";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 999;
	}
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0050
	}
}

COMMAND READ_P0050
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0050 }
	}
}

METHOD SET_PAR_NUMBER_0050
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 50;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0051
{
	LABEL "P0051 Last Fault Day/Month|de|P0051 Tag/Monat letzter F. |es|P0051 Da/Mes ltima Falla";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE UNSIGNED_INTEGER(2)
	{

	}
	POST_READ_ACTIONS { ConvertToDateTimeP0051 }
	HELP [DATE_TIME_HELP];
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0051
	}
}

METHOD ConvertToDateTimeP0051
{
	LABEL "Convert to day/month or hour/minute";
	DEFINITION { P0051 = (P0051&0x00FF) + (P0051>>8)*100; }
}

COMMAND READ_P0051
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0051 }
	}
}

METHOD SET_PAR_NUMBER_0051
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 51;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0052
{
	LABEL "P0052 Last Fault Year|de|P0052 Jahr letzter Fehler |es|P0052 Ao ltima Falla";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 99;
	}
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0052
	}
}

COMMAND READ_P0052
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0052 }
	}
}

METHOD SET_PAR_NUMBER_0052
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 52;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0053
{
	LABEL "P0053 Last Fault Time|de|P0053 Zeit letzter Fehler|es|P0053 Hora ltima Falla";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE UNSIGNED_INTEGER(2)
	{

	}
	POST_READ_ACTIONS { ConvertToDateTimeP0053 }
	HELP [DATE_TIME_HELP];
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0053
	}
}

METHOD ConvertToDateTimeP0053
{
	LABEL "Convert to day/month or hour/minute";
	DEFINITION { P0053 = (P0053&0x00FF) + (P0053>>8)*100; }
}

COMMAND READ_P0053
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0053 }
	}
}

METHOD SET_PAR_NUMBER_0053
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 53;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0054
{
	LABEL "P0054 Second Fault|de|P0054 Zweiter Fehler|es|P0054 Segunda Falla   ";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 999;
	}
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0054
	}
}

COMMAND READ_P0054
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0054 }
	}
}

METHOD SET_PAR_NUMBER_0054
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 54;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0055
{
	LABEL "P0055 Second Flt. Day/Month|de|P0055 Tag/Monat 2. Fehler |es|P0055 Da/Mes Segunda Falla";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE UNSIGNED_INTEGER(2)
	{

	}
	POST_READ_ACTIONS { ConvertToDateTimeP0055 }
	HELP [DATE_TIME_HELP];
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0055
	}
}

METHOD ConvertToDateTimeP0055
{
	LABEL "Convert to day/month or hour/minute";
	DEFINITION { P0055 = (P0055&0x00FF) + (P0055>>8)*100; }
}

COMMAND READ_P0055
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0055 }
	}
}

METHOD SET_PAR_NUMBER_0055
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 55;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0056
{
	LABEL "P0056 Second Fault Year|de|P0056 Jahr 2. Fehler|es|P0056 Ao Segunda Falla";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 99;
	}
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0056
	}
}

COMMAND READ_P0056
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0056 }
	}
}

METHOD SET_PAR_NUMBER_0056
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 56;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0057
{
	LABEL "P0057 Second Fault Time|de|P0057 Zeit 2. Fehler|es|P0057 Hora Segunda Falla";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE UNSIGNED_INTEGER(2)
	{

	}
	POST_READ_ACTIONS { ConvertToDateTimeP0057 }
	HELP [DATE_TIME_HELP];
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0057
	}
}

METHOD ConvertToDateTimeP0057
{
	LABEL "Convert to day/month or hour/minute";
	DEFINITION { P0057 = (P0057&0x00FF) + (P0057>>8)*100; }
}

COMMAND READ_P0057
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0057 }
	}
}

METHOD SET_PAR_NUMBER_0057
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 57;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0058
{
	LABEL "P0058 Third Fault|de|P0058 Dritter Fehler|es|P0058 Tercera Falla   ";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 999;
	}
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0058
	}
}

COMMAND READ_P0058
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0058 }
	}
}

METHOD SET_PAR_NUMBER_0058
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 58;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0059
{
	LABEL "P0059 Third Fault Day/Month|de|P0059 Tag/Monat 3. Fehler |es|P0059 Da/Mes Tercera Falla";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE UNSIGNED_INTEGER(2)
	{

	}
	POST_READ_ACTIONS { ConvertToDateTimeP0059 }
	HELP [DATE_TIME_HELP];
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0059
	}
}

METHOD ConvertToDateTimeP0059
{
	LABEL "Convert to day/month or hour/minute";
	DEFINITION { P0059 = (P0059&0x00FF) + (P0059>>8)*100; }
}

COMMAND READ_P0059
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0059 }
	}
}

METHOD SET_PAR_NUMBER_0059
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 59;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0060
{
	LABEL "P0060 Third Fault Year|de|P0060 Jahr 3. Fehler|es|P0060 Ao Tercera Falla";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 99;
	}
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0060
	}
}

COMMAND READ_P0060
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0060 }
	}
}

METHOD SET_PAR_NUMBER_0060
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 60;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0061
{
	LABEL "P0061 Third Fault Time|de|P0061 Zeit 3. Fehler|es|P0061 Hora Tercera Falla";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE UNSIGNED_INTEGER(2)
	{

	}
	POST_READ_ACTIONS { ConvertToDateTimeP0061 }
	HELP [DATE_TIME_HELP];
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0061
	}
}

METHOD ConvertToDateTimeP0061
{
	LABEL "Convert to day/month or hour/minute";
	DEFINITION { P0061 = (P0061&0x00FF) + (P0061>>8)*100; }
}

COMMAND READ_P0061
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0061 }
	}
}

METHOD SET_PAR_NUMBER_0061
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 61;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0062
{
	LABEL "P0062 Fourth Fault|de|P0062 Vierter Fehler|es|P0062 Cuarta Falla    ";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 999;
	}
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0062
	}
}

COMMAND READ_P0062
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0062 }
	}
}

METHOD SET_PAR_NUMBER_0062
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 62;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0063
{
	LABEL "P0063 Fourth Flt. Day/Month|de|P0063 Tag/Monat 4. Fehler |es|P0063 Da/Mes Cuarta Falla";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE UNSIGNED_INTEGER(2)
	{

	}
	POST_READ_ACTIONS { ConvertToDateTimeP0063 }
	HELP [DATE_TIME_HELP];
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0063
	}
}

METHOD ConvertToDateTimeP0063
{
	LABEL "Convert to day/month or hour/minute";
	DEFINITION { P0063 = (P0063&0x00FF) + (P0063>>8)*100; }
}

COMMAND READ_P0063
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0063 }
	}
}

METHOD SET_PAR_NUMBER_0063
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 63;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0064
{
	LABEL "P0064 Fourth Fault Year|de|P0064 Jahr 4. Fehler|es|P0064 Ao Cuarta Falla";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 99;
	}
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0064
	}
}

COMMAND READ_P0064
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0064 }
	}
}

METHOD SET_PAR_NUMBER_0064
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 64;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0065
{
	LABEL "P0065 Fourth Fault Time|de|P0065 Zeit 4. Fehler|es|P0065 Hora Cuarta Falla";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE UNSIGNED_INTEGER(2)
	{

	}
	POST_READ_ACTIONS { ConvertToDateTimeP0065 }
	HELP [DATE_TIME_HELP];
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0065
	}
}

METHOD ConvertToDateTimeP0065
{
	LABEL "Convert to day/month or hour/minute";
	DEFINITION { P0065 = (P0065&0x00FF) + (P0065>>8)*100; }
}

COMMAND READ_P0065
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0065 }
	}
}

METHOD SET_PAR_NUMBER_0065
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 65;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0066
{
	LABEL "P0066 Fifth Fault|de|P0066 Fnfter Fehler|es|P0066 Quinta Falla";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 999;
	}
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0066
	}
}

COMMAND READ_P0066
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0066 }
	}
}

METHOD SET_PAR_NUMBER_0066
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 66;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0067
{
	LABEL "P0067 Fifth Fault Day/Month|de|P0067 Tag/Monat 5. Fehler |es|P0067 Da/Mes Quinta Falla";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE UNSIGNED_INTEGER(2)
	{

	}
	POST_READ_ACTIONS { ConvertToDateTimeP0067 }
	HELP [DATE_TIME_HELP];
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0067
	}
}

METHOD ConvertToDateTimeP0067
{
	LABEL "Convert to day/month or hour/minute";
	DEFINITION { P0067 = (P0067&0x00FF) + (P0067>>8)*100; }
}

COMMAND READ_P0067
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0067 }
	}
}

METHOD SET_PAR_NUMBER_0067
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 67;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0068
{
	LABEL "P0068 Fifth Fault Year|de|P0068 Jahr 5. Fehler|es|P0068 Ao Quinta Falla";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 99;
	}
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0068
	}
}

COMMAND READ_P0068
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0068 }
	}
}

METHOD SET_PAR_NUMBER_0068
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 68;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0069
{
	LABEL "P0069 Fifth Fault Time|de|P0069 Zeit 5. Fehler|es|P0069 Hora Quinta Falla";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE UNSIGNED_INTEGER(2)
	{

	}
	POST_READ_ACTIONS { ConvertToDateTimeP0069 }
	HELP [DATE_TIME_HELP];
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0069
	}
}

METHOD ConvertToDateTimeP0069
{
	LABEL "Convert to day/month or hour/minute";
	DEFINITION { P0069 = (P0069&0x00FF) + (P0069>>8)*100; }
}

COMMAND READ_P0069
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0069 }
	}
}

METHOD SET_PAR_NUMBER_0069
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 69;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0070
{
	LABEL "P0070 Sixth Fault|de|P0070 Sechster Fehler|es|P0070 Sexta Falla";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 999;
	}
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0070
	}
}

COMMAND READ_P0070
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0070 }
	}
}

METHOD SET_PAR_NUMBER_0070
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 70;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0071
{
	LABEL "P0071 Sixth Fault Day/Month|de|P0071 Tag/Monat 6. Fehler |es|P0071 Da/Mes Sexta Falla";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE UNSIGNED_INTEGER(2)
	{

	}
	POST_READ_ACTIONS { ConvertToDateTimeP0071 }
	HELP [DATE_TIME_HELP];
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0071
	}
}

METHOD ConvertToDateTimeP0071
{
	LABEL "Convert to day/month or hour/minute";
	DEFINITION { P0071 = (P0071&0x00FF) + (P0071>>8)*100; }
}

COMMAND READ_P0071
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0071 }
	}
}

METHOD SET_PAR_NUMBER_0071
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 71;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0072
{
	LABEL "P0072 Sixth Fault Year|de|P0072 Jahr 6. Fehler|es|P0072 Ao Sexta Falla";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 99;
	}
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0072
	}
}

COMMAND READ_P0072
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0072 }
	}
}

METHOD SET_PAR_NUMBER_0072
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 72;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0073
{
	LABEL "P0073 Sixth Fault Time|de|P0073 Zeit 6. Fehler|es|P0073 Hora Sexta Falla";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE UNSIGNED_INTEGER(2)
	{

	}
	POST_READ_ACTIONS { ConvertToDateTimeP0073 }
	HELP [DATE_TIME_HELP];
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0073
	}
}

METHOD ConvertToDateTimeP0073
{
	LABEL "Convert to day/month or hour/minute";
	DEFINITION { P0073 = (P0073&0x00FF) + (P0073>>8)*100; }
}

COMMAND READ_P0073
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0073 }
	}
}

METHOD SET_PAR_NUMBER_0073
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 73;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0074
{
	LABEL "P0074 Seventh Fault|de|P0074 Siebter Fehler|es|P0074 Sptima Falla";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 999;
	}
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0074
	}
}

COMMAND READ_P0074
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0074 }
	}
}

METHOD SET_PAR_NUMBER_0074
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 74;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0075
{
	LABEL "P0075 Seventh Flt.Day/Month|de|P0075 Tag/Monat 7. Fehler |es|P0075 Da/Mes Sptima Falla";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE UNSIGNED_INTEGER(2)
	{

	}
	POST_READ_ACTIONS { ConvertToDateTimeP0075 }
	HELP [DATE_TIME_HELP];
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0075
	}
}

METHOD ConvertToDateTimeP0075
{
	LABEL "Convert to day/month or hour/minute";
	DEFINITION { P0075 = (P0075&0x00FF) + (P0075>>8)*100; }
}

COMMAND READ_P0075
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0075 }
	}
}

METHOD SET_PAR_NUMBER_0075
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 75;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0076
{
	LABEL "P0076 Seventh Fault Year|de|P0076 Jahr 7. Fehler|es|P0076 Ao Sptima Falla";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 99;
	}
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0076
	}
}

COMMAND READ_P0076
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0076 }
	}
}

METHOD SET_PAR_NUMBER_0076
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 76;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0077
{
	LABEL "P0077 Seventh Fault Time|de|P0077 Zeit 7. Fehler|es|P0077 Hora Sptima Falla";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE UNSIGNED_INTEGER(2)
	{

	}
	POST_READ_ACTIONS { ConvertToDateTimeP0077 }
	HELP [DATE_TIME_HELP];
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0077
	}
}

METHOD ConvertToDateTimeP0077
{
	LABEL "Convert to day/month or hour/minute";
	DEFINITION { P0077 = (P0077&0x00FF) + (P0077>>8)*100; }
}

COMMAND READ_P0077
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0077 }
	}
}

METHOD SET_PAR_NUMBER_0077
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 77;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0078
{
	LABEL "P0078 Eighth Fault|de|P0078 Achter Fehler|es|P0078 Octava Falla";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 999;
	}
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0078
	}
}

COMMAND READ_P0078
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0078 }
	}
}

METHOD SET_PAR_NUMBER_0078
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 78;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0079
{
	LABEL "P0079 Eighth Flt. Day/Month|de|P0079 Tag/Monat 8. Fehler |es|P0079 Da/Mes Octava Falla";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE UNSIGNED_INTEGER(2)
	{

	}
	POST_READ_ACTIONS { ConvertToDateTimeP0079 }
	HELP [DATE_TIME_HELP];
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0079
	}
}

METHOD ConvertToDateTimeP0079
{
	LABEL "Convert to day/month or hour/minute";
	DEFINITION { P0079 = (P0079&0x00FF) + (P0079>>8)*100; }
}

COMMAND READ_P0079
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0079 }
	}
}

METHOD SET_PAR_NUMBER_0079
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 79;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0080
{
	LABEL "P0080 Eighth Fault Year|de|P0080 Jahr 8. Fehler|es|P0080 Ao Octava Falla";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 99;
	}
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0080
	}
}

COMMAND READ_P0080
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0080 }
	}
}

METHOD SET_PAR_NUMBER_0080
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 80;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0081
{
	LABEL "P0081 Eighth Fault Time|de|P0081 Zeit 8. Fehler|es|P0081 Hora Octava Falla";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE UNSIGNED_INTEGER(2)
	{

	}
	POST_READ_ACTIONS { ConvertToDateTimeP0081 }
	HELP [DATE_TIME_HELP];
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0081
	}
}

METHOD ConvertToDateTimeP0081
{
	LABEL "Convert to day/month or hour/minute";
	DEFINITION { P0081 = (P0081&0x00FF) + (P0081>>8)*100; }
}

COMMAND READ_P0081
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0081 }
	}
}

METHOD SET_PAR_NUMBER_0081
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 81;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0082
{
	LABEL "P0082 Ninth Fault|de|P0082 Neunter Fehler|es|P0082 Novena Falla";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 999;
	}
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0082
	}
}

COMMAND READ_P0082
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0082 }
	}
}

METHOD SET_PAR_NUMBER_0082
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 82;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0083
{
	LABEL "P0083 Ninth Fault Day/Month|de|P0083 Tag/Monat 9. Fehler |es|P0083 Da/Mes Novena Falla";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE UNSIGNED_INTEGER(2)
	{

	}
	POST_READ_ACTIONS { ConvertToDateTimeP0083 }
	HELP [DATE_TIME_HELP];
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0083
	}
}

METHOD ConvertToDateTimeP0083
{
	LABEL "Convert to day/month or hour/minute";
	DEFINITION { P0083 = (P0083&0x00FF) + (P0083>>8)*100; }
}

COMMAND READ_P0083
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0083 }
	}
}

METHOD SET_PAR_NUMBER_0083
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 83;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0084
{
	LABEL "P0084 Ninth Fault Year|de|P0084 Jahr 9. Fehler|es|P0084 Ao Novena Falla";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 99;
	}
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0084
	}
}

COMMAND READ_P0084
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0084 }
	}
}

METHOD SET_PAR_NUMBER_0084
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 84;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0085
{
	LABEL "P0085 Ninth Fault Time|de|P0085 Zeit 9. Fehler|es|P0085 Hora Novena Falla";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE UNSIGNED_INTEGER(2)
	{

	}
	POST_READ_ACTIONS { ConvertToDateTimeP0085 }
	HELP [DATE_TIME_HELP];
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0085
	}
}

METHOD ConvertToDateTimeP0085
{
	LABEL "Convert to day/month or hour/minute";
	DEFINITION { P0085 = (P0085&0x00FF) + (P0085>>8)*100; }
}

COMMAND READ_P0085
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0085 }
	}
}

METHOD SET_PAR_NUMBER_0085
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 85;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0086
{
	LABEL "P0086 Tenth Fault|de|P0086 Zehnter Fehler|es|P0086 Dcima Falla";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 999;
	}
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0086
	}
}

COMMAND READ_P0086
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0086 }
	}
}

METHOD SET_PAR_NUMBER_0086
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 86;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0087
{
	LABEL "P0087 Tenth Fault Day/Month|de|P0087 Tag/Monat 10. Fehler |es|P0087 Da/Mes Dcima Falla";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE UNSIGNED_INTEGER(2)
	{

	}
	POST_READ_ACTIONS { ConvertToDateTimeP0087 }
	HELP [DATE_TIME_HELP];
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0087
	}
}

METHOD ConvertToDateTimeP0087
{
	LABEL "Convert to day/month or hour/minute";
	DEFINITION { P0087 = (P0087&0x00FF) + (P0087>>8)*100; }
}

COMMAND READ_P0087
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0087 }
	}
}

METHOD SET_PAR_NUMBER_0087
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 87;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0088
{
	LABEL "P0088 Tenth Fault Year|de|P0088 Jahr 10. Fehler|es|P0088 Ao Dcima Falla";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 99;
	}
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0088
	}
}

COMMAND READ_P0088
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0088 }
	}
}

METHOD SET_PAR_NUMBER_0088
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 88;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0089
{
	LABEL "P0089 Tenth Fault Time|de|P0089 Zeit 10. Fehler|es|P0089 Hora Dcima Falla";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE UNSIGNED_INTEGER(2)
	{

	}
	POST_READ_ACTIONS { ConvertToDateTimeP0089 }
	HELP [DATE_TIME_HELP];
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0089
	}
}

METHOD ConvertToDateTimeP0089
{
	LABEL "Convert to day/month or hour/minute";
	DEFINITION { P0089 = (P0089&0x00FF) + (P0089>>8)*100; }
}

COMMAND READ_P0089
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0089 }
	}
}

METHOD SET_PAR_NUMBER_0089
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 89;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0090
{
	LABEL "P0090 Current At Last Fault|de|P0090 Strom beim letzen F.|es|P0090 Corriente lt. Falla";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE UNSIGNED_INTEGER(2)
	{
		SCALING_FACTOR 0.1;
	}
	CONSTANT_UNIT "A";
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0090
	}
}

COMMAND READ_P0090
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0090 }
	}
}

METHOD SET_PAR_NUMBER_0090
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 90;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0091
{
	LABEL "P0091 DC Link At Last Fault|de|P0091 Zwischenkeispg. l. F.|es|P0091 Bus CC ltima Falla";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 2000;
	}
	CONSTANT_UNIT "V";
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0091
	}
}

COMMAND READ_P0091
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0091 }
	}
}

METHOD SET_PAR_NUMBER_0091
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 91;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0092
{
	LABEL "P0092 Speed At Last Fault|de|P0092 Geschwindigkeit l. F.|es|P0092 Velocidad lt. Falla";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 18000;
	}
	CONSTANT_UNIT "rpm";
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0092
	}
}

COMMAND READ_P0092
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0092 }
	}
}

METHOD SET_PAR_NUMBER_0092
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 92;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0093
{
	LABEL "P0093 Reference Last Fault|de|P0093 Sollwert letzter F.|es|P0093 Referencia lt. Falla";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 18000;
	}
	CONSTANT_UNIT "rpm";
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0093
	}
}

COMMAND READ_P0093
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0093 }
	}
}

METHOD SET_PAR_NUMBER_0093
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 93;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0094
{
	LABEL "P0094 Frequency Last Fault|de|P0094 Frequenz letzter F.|es|P0094 Frecuencia lt. Falla";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE UNSIGNED_INTEGER(2)
	{
		SCALING_FACTOR 0.1;
	}
	CONSTANT_UNIT "Hz";
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0094
	}
}

COMMAND READ_P0094
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0094 }
	}
}

METHOD SET_PAR_NUMBER_0094
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 94;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0095
{
	LABEL "P0095 Motor Volt.Last Fault|de|P0095 Motorspannung l. F.|es|P0095 Tensin Mot.lt.Falla";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 2000;
	}
	CONSTANT_UNIT "V";
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0095
	}
}

COMMAND READ_P0095
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0095 }
	}
}

METHOD SET_PAR_NUMBER_0095
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 95;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0096
{
	LABEL "P0096 DIx Status Last Fault|de|P0096 DIx Status letzter F.|es|P0096 Estado DIx lt. Falla";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE BIT_ENUMERATED(2)
	{
		{ 0x0001, "DI1|de|DI1|es|DI1" },
		{ 0x0002, "DI2|de|DI2|es|DI2" },
		{ 0x0004, "DI3|de|DI3|es|DI3" },
		{ 0x0008, "DI4|de|DI4|es|DI4" },
		{ 0x0010, "DI5|de|DI5|es|DI5" },
		{ 0x0020, "DI6|de|DI6|es|DI6" },
		{ 0x0040, "DI7|de|DI7|es|DI7" },
		{ 0x0080, "DI8|de|DI8|es|DI8" }
		DEFAULT_VALUE 0;
	}
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0096
	}
}

COMMAND READ_P0096
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0096 }
	}
}

METHOD SET_PAR_NUMBER_0096
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 96;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0097
{
	LABEL "P0097 DOx Status Last Fault|de|P0097 DOx Status letzter F.|es|P0097 Estado DOx lt. Falla";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE BIT_ENUMERATED(2)
	{
		{ 0x0001, "DO1|de|DO1|es|DO1" },
		{ 0x0002, "DO2|de|DO2|es|DO2" },
		{ 0x0004, "DO3|de|DO3|es|DO3" },
		{ 0x0008, "DO4|de|DO4|es|DO4" },
		{ 0x0010, "DO5|de|DO5|es|DO5" }
		DEFAULT_VALUE 0;
	}
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0097
	}
}

COMMAND READ_P0097
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0097 }
	}
}

METHOD SET_PAR_NUMBER_0097
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 97;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0100
{
	LABEL "P0100 Acceleration Time  |de|P0100 Hochlaufzeit|es|P0100 Tiempo Aceleracin  ";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{
		SCALING_FACTOR 0.1;
	}
	CONSTANT_UNIT "s";
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0100
	}
}

COMMAND READ_P0100
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0100 }
	}
}

METHOD SET_PAR_NUMBER_0100
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 100;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0100 LIKE READ_P0100
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 100, P0100 }
		REPLY { }
	}
}

VARIABLE P0101
{
	LABEL "P0101 Deceleration Time|de|P0101 Bremszeit|es|P0101 Tiempo Desaceleracin";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{
		SCALING_FACTOR 0.1;
	}
	CONSTANT_UNIT "s";
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0101
	}
}

COMMAND READ_P0101
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0101 }
	}
}

METHOD SET_PAR_NUMBER_0101
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 101;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0101 LIKE READ_P0101
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 101, P0101 }
		REPLY { }
	}
}

VARIABLE P0102
{
	LABEL "P0102 Acceleration Time 2|de|P0102 2. Hochlaufzeit|es|P0102 Tiempo Aceler. 2a";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{
		SCALING_FACTOR 0.1;
	}
	CONSTANT_UNIT "s";
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0102
	}
}

COMMAND READ_P0102
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0102 }
	}
}

METHOD SET_PAR_NUMBER_0102
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 102;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0102 LIKE READ_P0102
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 102, P0102 }
		REPLY { }
	}
}

VARIABLE P0103
{
	LABEL "P0103 Deceleration Time 2|de|P0103 2. Bremszeit|es|P0103 Tiempo Desacel. 2a";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{
		SCALING_FACTOR 0.1;
	}
	CONSTANT_UNIT "s";
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0103
	}
}

COMMAND READ_P0103
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0103 }
	}
}

METHOD SET_PAR_NUMBER_0103
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 103;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0103 LIKE READ_P0103
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 103, P0103 }
		REPLY { }
	}
}

VARIABLE P0104
{
	LABEL "P0104 S Ramp          |de|P0104 S-Rampe|es|P0104 Rampa S         ";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "Off       |de|Aus|es|Inactiva  " },
		{ 1, "50%|de|50%|es|50%" },
		{ 2, "100%|de|100%|es|100%" }
		DEFAULT_VALUE 0;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0104
	}
}

COMMAND READ_P0104
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0104 }
	}
}

METHOD SET_PAR_NUMBER_0104
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 104;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0104 LIKE READ_P0104
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 104, P0104 }
		REPLY { }
	}
}

VARIABLE P0105
{
	LABEL "P0105 1st/2nd Ramp Select.|de|P0105 1./2. Rampe Auswahl|es|P0105 Seleccin 1a/2a Rampa";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "1st Ramp|de|1. Rampe|es|1a Rampa" },
		{ 1, "2nd Ramp|de|2. Rampe|es|2a Rampa" },
		{ 2, "DIx       |de|DIx       |es|DIx       " },
		{ 3, "Serial/USB|de|Seriell/USB|es|Serie/USB" },
		{ 4, "Anybus-CC|de|Anybus-CC|es|Anybus-CC" },
		{ 5, "CANop/DNet/DP|de|CANop/DNet/DP|es|CANop/DNet/DP" },
		{ 6, "SoftPLC|de|SoftSPS|es|SoftPLC" },
		{ 7, "PLC11|de|PLC11|es|PLC11" }
		DEFAULT_VALUE 2;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0105
	}
}

COMMAND READ_P0105
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0105 }
	}
}

METHOD SET_PAR_NUMBER_0105
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 105;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0105 LIKE READ_P0105
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 105, P0105 }
		REPLY { }
	}
}

VARIABLE P0120
{
	LABEL "P0120 Speed Ref. Backup|de|P0120 Sollwertbackup|es|P0120 Backup Referencia";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "Off       |de|Aus|es|Inactiva  " },
		{ 1, "On        |de|Ein|es|Activa    " }
		DEFAULT_VALUE 1;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0120
	}
}

COMMAND READ_P0120
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0120 }
	}
}

METHOD SET_PAR_NUMBER_0120
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 120;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0120 LIKE READ_P0120
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 120, P0120 }
		REPLY { }
	}
}

VARIABLE P0121
{
	LABEL "P0121 Keypad Reference|de|P0121 Tastatursollwert|es|P0121 Referencia por la HMI";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 90;
		MIN_VALUE 0;
		MAX_VALUE 18000;
	}
	CONSTANT_UNIT "rpm";
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0121
	}
}

COMMAND READ_P0121
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0121 }
	}
}

METHOD SET_PAR_NUMBER_0121
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 121;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0121 LIKE READ_P0121
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 121, P0121 }
		REPLY { }
	}
}

VARIABLE P0122
{
	LABEL "P0122 JOG/JOG+ Reference   |de|P0122 JOG/JOG+ Sollwert|es|P0122 Referencia JOG/JOG+  ";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 150;
		MIN_VALUE 0;
		MAX_VALUE 18000;
	}
	CONSTANT_UNIT "rpm";
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0122
	}
}

COMMAND READ_P0122
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0122 }
	}
}

METHOD SET_PAR_NUMBER_0122
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 122;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0122 LIKE READ_P0122
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 122, P0122 }
		REPLY { }
	}
}

VARIABLE P0123
{
	LABEL "P0123 JOG- Reference  |de|P0123 JOG- Sollwert|es|P0123 Referencia JOG- ";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 150;
		MIN_VALUE 0;
		MAX_VALUE 18000;
	}
	CONSTANT_UNIT "rpm";
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0123
	}
}

COMMAND READ_P0123
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0123 }
	}
}

METHOD SET_PAR_NUMBER_0123
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 123;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0123 LIKE READ_P0123
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 123, P0123 }
		REPLY { }
	}
}

VARIABLE P0124
{
	LABEL "P0124 Multispeed Ref. 1|de|P0124 Multispeedsollwert 1|es|P0124 Ref. 1 Multispeed";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 90;
		MIN_VALUE 0;
		MAX_VALUE 18000;
	}
	CONSTANT_UNIT "rpm";
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0124
	}
}

COMMAND READ_P0124
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0124 }
	}
}

METHOD SET_PAR_NUMBER_0124
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 124;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0124 LIKE READ_P0124
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 124, P0124 }
		REPLY { }
	}
}

VARIABLE P0125
{
	LABEL "P0125 Multispeed Ref. 2|de|P0125 Multispeedsollwert 2|es|P0125 Ref. 2 Multispeed";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 300;
		MIN_VALUE 0;
		MAX_VALUE 18000;
	}
	CONSTANT_UNIT "rpm";
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0125
	}
}

COMMAND READ_P0125
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0125 }
	}
}

METHOD SET_PAR_NUMBER_0125
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 125;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0125 LIKE READ_P0125
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 125, P0125 }
		REPLY { }
	}
}

VARIABLE P0126
{
	LABEL "P0126 Multispeed Ref. 3|de|P0126 Multispeedsollwert 3|es|P0126 Ref. 3 Multispeed";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 600;
		MIN_VALUE 0;
		MAX_VALUE 18000;
	}
	CONSTANT_UNIT "rpm";
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0126
	}
}

COMMAND READ_P0126
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0126 }
	}
}

METHOD SET_PAR_NUMBER_0126
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 126;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0126 LIKE READ_P0126
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 126, P0126 }
		REPLY { }
	}
}

VARIABLE P0127
{
	LABEL "P0127 Multispeed Ref. 4|de|P0127 Multispeedsollwert 4|es|P0127 Ref. 4 Multispeed";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 900;
		MIN_VALUE 0;
		MAX_VALUE 18000;
	}
	CONSTANT_UNIT "rpm";
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0127
	}
}

COMMAND READ_P0127
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0127 }
	}
}

METHOD SET_PAR_NUMBER_0127
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 127;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0127 LIKE READ_P0127
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 127, P0127 }
		REPLY { }
	}
}

VARIABLE P0128
{
	LABEL "P0128 Multispeed Ref. 5|de|P0128 Multispeedsollwert 5|es|P0128 Ref. 5 Multispeed";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 1200;
		MIN_VALUE 0;
		MAX_VALUE 18000;
	}
	CONSTANT_UNIT "rpm";
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0128
	}
}

COMMAND READ_P0128
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0128 }
	}
}

METHOD SET_PAR_NUMBER_0128
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 128;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0128 LIKE READ_P0128
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 128, P0128 }
		REPLY { }
	}
}

VARIABLE P0129
{
	LABEL "P0129 Multispeed Ref. 6|de|P0129 Multispeedsollwert 6|es|P0129 Ref. 6 Multispeed";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 1500;
		MIN_VALUE 0;
		MAX_VALUE 18000;
	}
	CONSTANT_UNIT "rpm";
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0129
	}
}

COMMAND READ_P0129
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0129 }
	}
}

METHOD SET_PAR_NUMBER_0129
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 129;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0129 LIKE READ_P0129
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 129, P0129 }
		REPLY { }
	}
}

VARIABLE P0130
{
	LABEL "P0130 Multispeed Ref. 7|de|P0130 Multispeedsollwert 7|es|P0130 Ref. 7 Multispeed";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 1800;
		MIN_VALUE 0;
		MAX_VALUE 18000;
	}
	CONSTANT_UNIT "rpm";
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0130
	}
}

COMMAND READ_P0130
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0130 }
	}
}

METHOD SET_PAR_NUMBER_0130
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 130;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0130 LIKE READ_P0130
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 130, P0130 }
		REPLY { }
	}
}

VARIABLE P0131
{
	LABEL "P0131 Multispeed Ref. 8|de|P0131 Multispeedsollwert 8|es|P0131 Ref. 8 Multispeed";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 1650;
		MIN_VALUE 0;
		MAX_VALUE 18000;
	}
	CONSTANT_UNIT "rpm";
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0131
	}
}

COMMAND READ_P0131
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0131 }
	}
}

METHOD SET_PAR_NUMBER_0131
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 131;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0131 LIKE READ_P0131
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 131, P0131 }
		REPLY { }
	}
}

VARIABLE P0132
{
	LABEL "P0132 Max. Overspeed Level|de|P0132 berdrehzahlniveau|es|P0132 Nivel Mx.Sobreveloc.";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 10;
		MIN_VALUE 0;
		MAX_VALUE 100;
	}
	CONSTANT_UNIT "%";
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0132
	}
}

COMMAND READ_P0132
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0132 }
	}
}

METHOD SET_PAR_NUMBER_0132
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 132;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0132 LIKE READ_P0132
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 132, P0132 }
		REPLY { }
	}
}

VARIABLE P0133
{
	LABEL "P0133 Minimum Speed   |de|P0133 Minimaldrehzahl|es|P0133 Velocidad Mnima";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 90;
		MIN_VALUE 0;
		MAX_VALUE 18000;
	}
	CONSTANT_UNIT "rpm";
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0133
	}
}

COMMAND READ_P0133
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0133 }
	}
}

METHOD SET_PAR_NUMBER_0133
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 133;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0133 LIKE READ_P0133
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 133, P0133 }
		REPLY { }
	}
}

VARIABLE P0134
{
	LABEL "P0134 Maximum Speed   |de|P0134 Maximaldrehzahl|es|P0134 Velocidad Mxima";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 1800;
		MIN_VALUE 0;
		MAX_VALUE 18000;
	}
	CONSTANT_UNIT "rpm";
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0134
	}
}

COMMAND READ_P0134
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0134 }
	}
}

METHOD SET_PAR_NUMBER_0134
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 134;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0134 LIKE READ_P0134
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 134, P0134 }
		REPLY { }
	}
}

VARIABLE P0135
{
	LABEL "P0135 Max. Output Current|de|P0135 Maximalstrom|es|P0135 Corriente Mx. Salida";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{
		SCALING_FACTOR 0.1;
	}
	CONSTANT_UNIT "A";
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0135
	}
}

COMMAND READ_P0135
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0135 }
	}
}

METHOD SET_PAR_NUMBER_0135
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 135;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0135 LIKE READ_P0135
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 135, P0135 }
		REPLY { }
	}
}

VARIABLE P0136
{
	LABEL "P0136 Manual Torque Boost|de|P0136 Kompensation IxR|es|P0136 Boost de Torque Man.";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 1;
		MIN_VALUE 0;
		MAX_VALUE 9;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0136
	}
}

COMMAND READ_P0136
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0136 }
	}
}

METHOD SET_PAR_NUMBER_0136
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 136;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0136 LIKE READ_P0136
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 136, P0136 }
		REPLY { }
	}
}

VARIABLE P0137
{
	LABEL "P0137 Autom. Torque Boost|de|P0137 Autokompens. IxR|es|P0137 Boost de Torque Autom";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{
		SCALING_FACTOR 0.01;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0137
	}
}

COMMAND READ_P0137
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0137 }
	}
}

METHOD SET_PAR_NUMBER_0137
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 137;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0137 LIKE READ_P0137
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 137, P0137 }
		REPLY { }
	}
}

VARIABLE P0138
{
	LABEL "P0138 Slip Compensation|de|P0138 Nennschlupf|es|P0138 Compens.Deslizamiento";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{
		SCALING_FACTOR 0.1;
	}
	CONSTANT_UNIT "%";
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0138
	}
}

COMMAND READ_P0138
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0138 }
	}
}

METHOD SET_PAR_NUMBER_0138
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 138;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0138 LIKE READ_P0138
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 138, P0138 }
		REPLY { }
	}
}

VARIABLE P0139
{
	LABEL "P0139 Output Current Filter|de|P0139 Filterstrom|es|P0139 Filtro Corr. Salida";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{
		SCALING_FACTOR 0.1;
	}
	CONSTANT_UNIT "s";
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0139
	}
}

COMMAND READ_P0139
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0139 }
	}
}

METHOD SET_PAR_NUMBER_0139
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 139;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0139 LIKE READ_P0139
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 139, P0139 }
		REPLY { }
	}
}

VARIABLE P0140
{
	LABEL "P0140 Dwell Time At Start  |de|P0140 Dwell Zeit|es|P0140 Tiempo Acomodacin";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{
		SCALING_FACTOR 0.1;
	}
	CONSTANT_UNIT "s";
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0140
	}
}

COMMAND READ_P0140
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0140 }
	}
}

METHOD SET_PAR_NUMBER_0140
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 140;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0140 LIKE READ_P0140
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 140, P0140 }
		REPLY { }
	}
}

VARIABLE P0141
{
	LABEL "P0141 Dwell Speed At Start|de|P0141 Dwell Drehzahl|es|P0141 Velocidad Acomodacin";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 90;
		MIN_VALUE 0;
		MAX_VALUE 300;
	}
	CONSTANT_UNIT "rpm";
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0141
	}
}

COMMAND READ_P0141
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0141 }
	}
}

METHOD SET_PAR_NUMBER_0141
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 141;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0141 LIKE READ_P0141
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 141, P0141 }
		REPLY { }
	}
}

VARIABLE P0142
{
	LABEL "P0142 Max. Output Voltage|de|P0142 Maximale Motorspg.|es|P0142 Tensin Mxima  ";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{
		SCALING_FACTOR 0.1;
	}
	CONSTANT_UNIT "%";
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0142
	}
}

COMMAND READ_P0142
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0142 }
	}
}

METHOD SET_PAR_NUMBER_0142
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 142;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0142 LIKE READ_P0142
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 142, P0142 }
		REPLY { }
	}
}

VARIABLE P0143
{
	LABEL "P0143 Interm.Output Voltage|de|P0143 Durchschn. Motorspg.|es|P0143 Tensin Intermediria";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{
		SCALING_FACTOR 0.1;
	}
	CONSTANT_UNIT "%";
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0143
	}
}

COMMAND READ_P0143
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0143 }
	}
}

METHOD SET_PAR_NUMBER_0143
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 143;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0143 LIKE READ_P0143
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 143, P0143 }
		REPLY { }
	}
}

VARIABLE P0144
{
	LABEL "P0144 3Hz Output Voltage|de|P0144 Spannung bei 3Hz|es|P0144 Tensin en 3Hz  ";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{
		SCALING_FACTOR 0.1;
	}
	CONSTANT_UNIT "%";
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0144
	}
}

COMMAND READ_P0144
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0144 }
	}
}

METHOD SET_PAR_NUMBER_0144
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 144;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0144 LIKE READ_P0144
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 144, P0144 }
		REPLY { }
	}
}

VARIABLE P0145
{
	LABEL "P0145 Field Weakening Speed|de|P0145 Feldschwchdrehzahl|es|P0145 Vel. Inicio Deb.Campo";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 1800;
		MIN_VALUE 0;
		MAX_VALUE 18000;
	}
	CONSTANT_UNIT "rpm";
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0145
	}
}

COMMAND READ_P0145
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0145 }
	}
}

METHOD SET_PAR_NUMBER_0145
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 145;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0145 LIKE READ_P0145
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 145, P0145 }
		REPLY { }
	}
}

VARIABLE P0146
{
	LABEL "P0146 Intermediate Speed |de|P0146 Durchschn. Drehzahl|es|P0146 Vel. Intermediria  ";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 900;
		MIN_VALUE 0;
		MAX_VALUE 18000;
	}
	CONSTANT_UNIT "rpm";
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0146
	}
}

COMMAND READ_P0146
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0146 }
	}
}

METHOD SET_PAR_NUMBER_0146
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 146;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0146 LIKE READ_P0146
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 146, P0146 }
		REPLY { }
	}
}

VARIABLE P0150
{
	LABEL "P0150 DC Regul. Type V/f|de|P0150 DC Kontrollart  V/f|es|P0150 Tipo Regul. Ud V/f";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "Ramp Hold|de|Halterampe|es|Hold Rampa" },
		{ 1, "Ramp Accel.|de|Hochlauframpe|es|Acelera Rampa" }
		DEFAULT_VALUE 0;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0150
	}
}

COMMAND READ_P0150
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0150 }
	}
}

METHOD SET_PAR_NUMBER_0150
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 150;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0150 LIKE READ_P0150
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 150, P0150 }
		REPLY { }
	}
}

VARIABLE P0151
{
	LABEL "P0151 DC Regul. Level V/f|de|P0151 Zwischenkr.Pegel V/f|es|P0151 Nivel Reg. DC V/f   ";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{

	}
	CONSTANT_UNIT "V";
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0151
	}
}

COMMAND READ_P0151
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0151 }
	}
}

METHOD SET_PAR_NUMBER_0151
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 151;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0151 LIKE READ_P0151
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 151, P0151 }
		REPLY { }
	}
}

VARIABLE P0152
{
	LABEL "P0152 DC Link Regul. P Gain|de|P0152 Zwischenkr.Vrst.|es|P0152 Ganancia Prop.Reg. Ud";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{
		SCALING_FACTOR 0.01;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0152
	}
}

COMMAND READ_P0152
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0152 }
	}
}

METHOD SET_PAR_NUMBER_0152
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 152;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0152 LIKE READ_P0152
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 152, P0152 }
		REPLY { }
	}
}

VARIABLE P0153
{
	LABEL "P0153 Dyn. Braking Level |de|P0153 Dyn. Bremspegel|es|P0153 Nivel Frenado Reost.";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{

	}
	CONSTANT_UNIT "V";
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0153
	}
}

COMMAND READ_P0153
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0153 }
	}
}

METHOD SET_PAR_NUMBER_0153
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 153;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0153 LIKE READ_P0153
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 153, P0153 }
		REPLY { }
	}
}

VARIABLE P0154
{
	LABEL "P0154 Dyn. Braking Resistor|de|P0154 Bremswiderstand|es|P0154 Resistor Frenado ";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{
		SCALING_FACTOR 0.1;
	}
	CONSTANT_UNIT "ohm";
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0154
	}
}

COMMAND READ_P0154
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0154 }
	}
}

METHOD SET_PAR_NUMBER_0154
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 154;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0154 LIKE READ_P0154
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 154, P0154 }
		REPLY { }
	}
}

VARIABLE P0155
{
	LABEL "P0155 Dyn. B. Resist. Power|de|P0155 Widerstandsleistung|es|P0155 Potencia en Res.Fren.";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{
		SCALING_FACTOR 0.01;
	}
	CONSTANT_UNIT "kW";
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0155
	}
}

COMMAND READ_P0155
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0155 }
	}
}

METHOD SET_PAR_NUMBER_0155
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 155;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0155 LIKE READ_P0155
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 155, P0155 }
		REPLY { }
	}
}

VARIABLE P0156
{
	LABEL "P0156 Overl.Curr.100% Speed|de|P0156 berstrom 100%|es|P0156 Corriente Sobrecarga";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{
		SCALING_FACTOR 0.1;
	}
	CONSTANT_UNIT "A";
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0156
	}
}

COMMAND READ_P0156
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0156 }
	}
}

METHOD SET_PAR_NUMBER_0156
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 156;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0156 LIKE READ_P0156
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 156, P0156 }
		REPLY { }
	}
}

VARIABLE P0157
{
	LABEL "P0157 Overl.Curr. 50% Speed|de|P0157 berstrom 50%|es|P0157 Corr. Sobrecarga 50%";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{
		SCALING_FACTOR 0.1;
	}
	CONSTANT_UNIT "A";
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0157
	}
}

COMMAND READ_P0157
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0157 }
	}
}

METHOD SET_PAR_NUMBER_0157
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 157;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0157 LIKE READ_P0157
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 157, P0157 }
		REPLY { }
	}
}

VARIABLE P0158
{
	LABEL "P0158 Overl.Curr.  5% Speed|de|P0158 berstrom 5%|es|P0158 Corr. Sobrecarga 5%";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{
		SCALING_FACTOR 0.1;
	}
	CONSTANT_UNIT "A";
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0158
	}
}

COMMAND READ_P0158
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0158 }
	}
}

METHOD SET_PAR_NUMBER_0158
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 158;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0158 LIKE READ_P0158
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 158, P0158 }
		REPLY { }
	}
}

VARIABLE P0159
{
	LABEL "P0159 Motor Thermal Class|de|P0159 Thermische Schutzkl.|es|P0159 Clase Trmica Motor";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "Class 5|de|Klasse 5|es|Clase 5" },
		{ 1, "Class 10|de|Klasse 10|es|Clase 10" },
		{ 2, "Class 15|de|Klasse 15|es|Clase 15" },
		{ 3, "Class 20|de|Klasse 20|es|Clase 20" },
		{ 4, "Class 25|de|Klasse 25|es|Clase 25" },
		{ 5, "Class 30|de|Klasse 30|es|Clase 30" },
		{ 6, "Class 35|de|Klasse 35|es|Clase 35" },
		{ 7, "Class 40|de|Klasse 40|es|Clase 40" },
		{ 8, "Class 45|de|Klasse 45|es|Clase 45" }
		DEFAULT_VALUE 1;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0159
	}
}

COMMAND READ_P0159
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0159 }
	}
}

METHOD SET_PAR_NUMBER_0159
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 159;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0159 LIKE READ_P0159
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 159, P0159 }
		REPLY { }
	}
}

VARIABLE P0160
{
	LABEL "P0160 Speed Regul. Config.|de|P0160 Kon. Drehz. Kontrolle|es|P0160 Configuracin Reg.Vel";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "Normal|de|Normal|es|Normal" },
		{ 1, "Saturated|de|Gesttigt|es|Saturado" }
		DEFAULT_VALUE 0;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0160
	}
}

COMMAND READ_P0160
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0160 }
	}
}

METHOD SET_PAR_NUMBER_0160
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 160;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0160 LIKE READ_P0160
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 160, P0160 }
		REPLY { }
	}
}

VARIABLE P0161
{
	LABEL "P0161 Speed Prop. Gain|de|P0161 P Drehzahlverstrkung|es|P0161 Ganancia Prop. Vel.";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{
		SCALING_FACTOR 0.1;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0161
	}
}

COMMAND READ_P0161
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0161 }
	}
}

METHOD SET_PAR_NUMBER_0161
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 161;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0161 LIKE READ_P0161
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 161, P0161 }
		REPLY { }
	}
}

VARIABLE P0162
{
	LABEL "P0162 Speed Integral Gain|de|P0162 I Drehzahlverstrkung|es|P0162 Ganancia Int. Vel.";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{
		SCALING_FACTOR 0.001;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0162
	}
}

COMMAND READ_P0162
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0162 }
	}
}

METHOD SET_PAR_NUMBER_0162
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 162;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0162 LIKE READ_P0162
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 162, P0162 }
		REPLY { }
	}
}

VARIABLE P0163
{
	LABEL "P0163 LOC Reference Offset|de|P0163 LOC Sollwertoffset |es|P0163 Offset Referencia LOC";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -999;
		MAX_VALUE 999;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0163
	}
}

COMMAND READ_P0163
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0163 }
	}
}

METHOD SET_PAR_NUMBER_0163
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 163;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0163 LIKE READ_P0163
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 163, P0163 }
		REPLY { }
	}
}

VARIABLE P0164
{
	LABEL "P0164 REM Reference Offset|de|P0164 REM Sollwertoffset|es|P0164 Offset Referencia REM";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -999;
		MAX_VALUE 999;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0164
	}
}

COMMAND READ_P0164
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0164 }
	}
}

METHOD SET_PAR_NUMBER_0164
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 164;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0164 LIKE READ_P0164
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 164, P0164 }
		REPLY { }
	}
}

VARIABLE P0165
{
	LABEL "P0165 Speed Filter|de|P0165 Drehzahlfilter |es|P0165 Filtro Velocidad";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{
		SCALING_FACTOR 0.001;
	}
	CONSTANT_UNIT "s";
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0165
	}
}

COMMAND READ_P0165
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0165 }
	}
}

METHOD SET_PAR_NUMBER_0165
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 165;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0165 LIKE READ_P0165
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 165, P0165 }
		REPLY { }
	}
}

VARIABLE P0166
{
	LABEL "P0166 Speed Diff. Gain|de|P0166 D Drehzahlverstrkung|es|P0166 Ganancia Dif. Vel.";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{
		SCALING_FACTOR 0.01;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0166
	}
}

COMMAND READ_P0166
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0166 }
	}
}

METHOD SET_PAR_NUMBER_0166
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 166;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0166 LIKE READ_P0166
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 166, P0166 }
		REPLY { }
	}
}

VARIABLE P0167
{
	LABEL "P0167 Current Prop. Gain|de|P0167 P Stromverstrkung|es|P0167 Ganancia Prop. Corr.";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{
		SCALING_FACTOR 0.01;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0167
	}
}

COMMAND READ_P0167
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0167 }
	}
}

METHOD SET_PAR_NUMBER_0167
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 167;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0167 LIKE READ_P0167
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 167, P0167 }
		REPLY { }
	}
}

VARIABLE P0168
{
	LABEL "P0168 Current Integral Gain|de|P0168 I Stromverstrkung|es|P0168 Ganancia Int. Corr.";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{
		SCALING_FACTOR 0.001;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0168
	}
}

COMMAND READ_P0168
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0168 }
	}
}

METHOD SET_PAR_NUMBER_0168
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 168;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0168 LIKE READ_P0168
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 168, P0168 }
		REPLY { }
	}
}

VARIABLE P0169
{
	LABEL "P0169 Max. + Torque Curr.|de|P0169 Max. +Drehmomentstrom|es|P0169 Mxima Corr.Torque +";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{
		SCALING_FACTOR 0.1;
	}
	CONSTANT_UNIT "%";
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0169
	}
}

COMMAND READ_P0169
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0169 }
	}
}

METHOD SET_PAR_NUMBER_0169
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 169;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0169 LIKE READ_P0169
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 169, P0169 }
		REPLY { }
	}
}

VARIABLE P0170
{
	LABEL "P0170 Max. - Torque Curr.|de|P0170 Max. -Drehmomentstrom|es|P0170 Mxima Corr.Torque -";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{
		SCALING_FACTOR 0.1;
	}
	CONSTANT_UNIT "%";
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0170
	}
}

COMMAND READ_P0170
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0170 }
	}
}

METHOD SET_PAR_NUMBER_0170
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 170;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0170 LIKE READ_P0170
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 170, P0170 }
		REPLY { }
	}
}

VARIABLE P0175
{
	LABEL "P0175 Flux Proport. Gain|de|P0175 P Flussverstrkung|es|P0175 Ganancia Prop. Flujo";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{
		SCALING_FACTOR 0.1;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0175
	}
}

COMMAND READ_P0175
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0175 }
	}
}

METHOD SET_PAR_NUMBER_0175
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 175;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0175 LIKE READ_P0175
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 175, P0175 }
		REPLY { }
	}
}

VARIABLE P0176
{
	LABEL "P0176 Flux Integral Gain|de|P0176 I Flussverstrkung|es|P0176 Ganancia Int. Flujo";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{
		SCALING_FACTOR 0.001;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0176
	}
}

COMMAND READ_P0176
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0176 }
	}
}

METHOD SET_PAR_NUMBER_0176
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 176;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0176 LIKE READ_P0176
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 176, P0176 }
		REPLY { }
	}
}

VARIABLE P0178
{
	LABEL "P0178 Rated Flux      |de|P0178 Nennfluss|es|P0178 Flujo Nominal   ";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 100;
		MIN_VALUE 0;
		MAX_VALUE 120;
	}
	CONSTANT_UNIT "%";
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0178
	}
}

COMMAND READ_P0178
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0178 }
	}
}

METHOD SET_PAR_NUMBER_0178
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 178;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0178 LIKE READ_P0178
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 178, P0178 }
		REPLY { }
	}
}

VARIABLE P0180
{
	LABEL "P0180 Iq* after the I/f|de|P0180 Iq* nach I/f|es|P0180 Iq* despus de I/f";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 10;
		MIN_VALUE 0;
		MAX_VALUE 350;
	}
	CONSTANT_UNIT "%";
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0180
	}
}

COMMAND READ_P0180
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0180 }
	}
}

METHOD SET_PAR_NUMBER_0180
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 180;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0180 LIKE READ_P0180
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 180, P0180 }
		REPLY { }
	}
}

VARIABLE P0181
{
	LABEL "P0181 Magnetization Mode|de|P0181 Magnetisierungsmodus|es|P0181 Modo Magnetizar";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "General Enable|de|Freigabe|es|Habil. General" },
		{ 1, "Run/Stop  |de|Start/Stop|es|Gira/Para " }
		DEFAULT_VALUE 0;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0181
	}
}

COMMAND READ_P0181
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0181 }
	}
}

METHOD SET_PAR_NUMBER_0181
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 181;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0181 LIKE READ_P0181
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 181, P0181 }
		REPLY { }
	}
}

VARIABLE P0182
{
	LABEL "P0182 Speed for I/F Activ. |de|P0182 Drehzahl fr I/F|es|P0182 Veloc.p/Actuacin I/F";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 18;
		MIN_VALUE 0;
		MAX_VALUE 180;
	}
	CONSTANT_UNIT "rpm";
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0182
	}
}

COMMAND READ_P0182
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0182 }
	}
}

METHOD SET_PAR_NUMBER_0182
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 182;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0182 LIKE READ_P0182
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 182, P0182 }
		REPLY { }
	}
}

VARIABLE P0183
{
	LABEL "P0183 Current in I/F Mode|de|P0183 Strom fr I/F|es|P0183 Corriente en modo I/F";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 1;
		MIN_VALUE 0;
		MAX_VALUE 9;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0183
	}
}

COMMAND READ_P0183
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0183 }
	}
}

METHOD SET_PAR_NUMBER_0183
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 183;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0183 LIKE READ_P0183
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 183, P0183 }
		REPLY { }
	}
}

VARIABLE P0184
{
	LABEL "P0184 DC Link Regul. Mode|de|P0184 Zwischenkreisregelart|es|P0184 Modo Regulacin Ud ";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "With losses|de|mit Verlusten|es|Con prdidas" },
		{ 1, "Without losses|de|ohne Verluste|es|Sin prdidas" },
		{ 2, "Enab/Disab DIx|de|Ein/Aus DIx|es|Hab/Deshab.DIx" }
		DEFAULT_VALUE 1;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0184
	}
}

COMMAND READ_P0184
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0184 }
	}
}

METHOD SET_PAR_NUMBER_0184
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 184;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0184 LIKE READ_P0184
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 184, P0184 }
		REPLY { }
	}
}

VARIABLE P0185
{
	LABEL "P0185 DC Link Regul. Level|de|P0185 Zwischenkr. Pegel Vek|es|P0185 Nivel Regulac. Bus CC";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{

	}
	CONSTANT_UNIT "V";
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0185
	}
}

COMMAND READ_P0185
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0185 }
	}
}

METHOD SET_PAR_NUMBER_0185
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 185;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0185 LIKE READ_P0185
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 185, P0185 }
		REPLY { }
	}
}

VARIABLE P0186
{
	LABEL "P0186 DC Link Prop. Gain|de|P0186 P Zwischenkr. Verst.|es|P0186 Ganancia Prop. Ud";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{
		SCALING_FACTOR 0.1;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0186
	}
}

COMMAND READ_P0186
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0186 }
	}
}

METHOD SET_PAR_NUMBER_0186
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 186;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0186 LIKE READ_P0186
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 186, P0186 }
		REPLY { }
	}
}

VARIABLE P0187
{
	LABEL "P0187 DC Link Integral Gain|de|P0187 I Zwischenkr. Verst.|es|P0187 Ganancia Integr. Ud";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{
		SCALING_FACTOR 0.001;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0187
	}
}

COMMAND READ_P0187
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0187 }
	}
}

METHOD SET_PAR_NUMBER_0187
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 187;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0187 LIKE READ_P0187
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 187, P0187 }
		REPLY { }
	}
}

VARIABLE P0188
{
	LABEL "P0188 Voltage Proport. Gain|de|P0188 P Ausgansspg. Verst.|es|P0188 Ganan. Prop. V.Salida";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{
		SCALING_FACTOR 0.001;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0188
	}
}

COMMAND READ_P0188
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0188 }
	}
}

METHOD SET_PAR_NUMBER_0188
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 188;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0188 LIKE READ_P0188
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 188, P0188 }
		REPLY { }
	}
}

VARIABLE P0189
{
	LABEL "P0189 Voltage Integral Gain|de|P0189 I Ausgansspg. Verst.|es|P0189 Ganan. Int. V.Salida";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{
		SCALING_FACTOR 0.001;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0189
	}
}

COMMAND READ_P0189
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0189 }
	}
}

METHOD SET_PAR_NUMBER_0189
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 189;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0189 LIKE READ_P0189
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 189, P0189 }
		REPLY { }
	}
}

VARIABLE P0190
{
	LABEL "P0190 Max. Output Voltage|de|P0190 Max. Ausgangsspannung|es|P0190 Tensin Salida Mxima";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{

	}
	CONSTANT_UNIT "V";
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0190
	}
}

COMMAND READ_P0190
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0190 }
	}
}

METHOD SET_PAR_NUMBER_0190
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 190;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0190 LIKE READ_P0190
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 190, P0190 }
		REPLY { }
	}
}

VARIABLE P0191
{
	LABEL "P0191 Encoder Zero Search|de|P0191 Nullsuche Drehgeber|es|P0191 Bsqueda Cero Encoder";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "Off       |de|Aus|es|Inactiva  " },
		{ 1, "On        |de|Ein|es|Activa    " }
		DEFAULT_VALUE 0;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0191
	}
}

COMMAND READ_P0191
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0191 }
	}
}

METHOD SET_PAR_NUMBER_0191
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 191;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0191 LIKE READ_P0191
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 191, P0191 }
		REPLY { }
	}
}

VARIABLE P0192
{
	LABEL "P0192 Status Enc ZeroSearch|de|P0192 Status Nullsuche D.|es|P0192 Estado Bsq Cero Enc";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE ENUMERATED(2)
	{
		{ 0, "Off       |de|Aus      |es|Inactivo" },
		{ 1, "Finished|de|Fertig|es|Concluso" }
		DEFAULT_VALUE 0;
	}
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0192
	}
}

COMMAND READ_P0192
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0192 }
	}
}

METHOD SET_PAR_NUMBER_0192
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 192;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0200
{
	LABEL "P0200 Password        |de|P0200 Passwort|es|P0200 Contrasea";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "Off       |de|Aus|es|Inactiva  " },
		{ 1, "On        |de|Ein|es|Activa    " },
		{ 2, "Change Pass.|de|Pass. ndern|es|Cambiar Seg." }
		DEFAULT_VALUE 1;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0200
	}
}

COMMAND READ_P0200
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0200 }
	}
}

METHOD SET_PAR_NUMBER_0200
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 200;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0200 LIKE READ_P0200
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 200, P0200 }
		REPLY { }
	}
}

VARIABLE P0201
{
	LABEL "P0201 Language        |de|P0201 Sprache|es|P0201 Idioma          ";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "Portugus |de|Portugus |es|Portugus " },
		{ 1, "English|de|English|es|English" },
		{ 2, "Espaol|de|Espaol|es|Espaol" },
		{ 3, "Deutsch|de|Deutsch|es|Deutsch" },
		{ 4, "Franais|de|Franais|es|Franais" }
		DEFAULT_VALUE 0;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0201
	}
}

COMMAND READ_P0201
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0201 }
	}
}

METHOD SET_PAR_NUMBER_0201
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 201;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0201 LIKE READ_P0201
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 201, P0201 }
		REPLY { }
	}
}

VARIABLE P0202
{
	LABEL "P0202 Type of Control|de|P0202 Regelungsart|es|P0202 Tipo de Control ";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "V/f 60 Hz |de|U/f 60 Hz|es|V/f 60 Hz " },
		{ 1, "V/f 50 Hz|de|U/f 50 Hz|es|V/f 50 Hz " },
		{ 2, "V/f Adjustable|de|U/f variabel|es|V/f Ajustable" },
		{ 3, "Sensorless|de|Sensorless|es|Sensorless" },
		{ 4, "Encoder   |de|Drehgeber|es|Encoder   " },
		{ 5, "VVW|de|VVW|es|VVW" },
		{ 6, "Encoder PM|de|PM Drehgeber|es|PM con Encoder" },
		{ 7, "Sensorless PM|de|PM Sensorless|es|PM Sensorless" }
		DEFAULT_VALUE 0;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0202
	}
}

COMMAND READ_P0202
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0202 }
	}
}

METHOD SET_PAR_NUMBER_0202
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 202;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0202 LIKE READ_P0202
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 202, P0202 }
		REPLY { }
	}
}

VARIABLE P0203
{
	LABEL "P0203 Special Function Sel.|de|P0203 Auswahl Sonderfunk.|es|P0203 Sel. Funcin Especial";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "None      |de|Keine|es|Ninguna   " },
		{ 1, "PID Regulator |de|PID Regler|es|Regulador PID" }
		DEFAULT_VALUE 0;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0203
	}
}

COMMAND READ_P0203
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0203 }
	}
}

METHOD SET_PAR_NUMBER_0203
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 203;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0203 LIKE READ_P0203
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 203, P0203 }
		REPLY { }
	}
}

VARIABLE P0204
{
	LABEL "P0204 Load/Save Parameters|de|P0204 Lade/Speicher Param.|es|P0204 Carga/Salva Parm.";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "Not Used  |de|Ohne Funktion|es|Sin Funcin " },
		{ 1, "Not Used  |de|Ohne Funktion|es|Sin Funcin " },
		{ 2, "Reset P0045|de|Reset P0045|es|Reset P0045" },
		{ 3, "Reset P0043|de|Reset P0043|es|Reset P0043" },
		{ 4, "Reset P0044|de|Reset P0044|es|Reset P0044" },
		{ 5, "Load 60Hz|de|Lade 60Hz|es|Carga 60Hz" },
		{ 6, "Load 50Hz|de|Lade 50Hz|es|Carga 50Hz" },
		{ 7, "Load User 1|de|Lade Benutz. 1|es|CargaUsuario 1" },
		{ 8, "Load User 2|de|Lade Benutz. 2|es|CargaUsuario 2" },
		{ 9, "Load User 3|de|Lade Benutz. 3|es|CargaUsuario 3" },
		{ 10, "Save User 1|de|Speic. Benutz1|es|SalvaUsuario 1" },
		{ 11, "Save User 2|de|Speic. Benutz2|es|SalvaUsuario 2" },
		{ 12, "Save User 3|de|Speic. Benutz3|es|SalvaUsuario 3" }
		DEFAULT_VALUE 0;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0204
	}
}

COMMAND READ_P0204
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0204 }
	}
}

METHOD SET_PAR_NUMBER_0204
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 204;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0204 LIKE READ_P0204
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 204, P0204 }
		REPLY { }
	}
}

VARIABLE P0205
{
	LABEL "P0205 Read Parameter Sel. 1|de|P0205 Anzeigeauswahl 1|es|P0205 Sel. Parm. Lectura 1";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "Not selected|de|Aus|es|Inactivo  " },
		{ 1, "Speed Refer. #|de|Drehz.Sollw. #|es|Ref. Veloc.  #" },
		{ 2, "Motor Speed  #|de|Motordrehz.  #|es|Veloc. Motor #" },
		{ 3, "MotorCurrent #|de|Motorstrom   #|es|Corr. Motor  #" },
		{ 4, "DC Link Volt #|de|ZwischenkrSpg#|es|Tensin CC   #" },
		{ 5, "Motor Freq.  #|de|Motorfrequenz#|es|Frec. Motor  #" },
		{ 6, "MotorVoltage #|de|Motorspg     #|es|Tensin Sal. #" },
		{ 7, "Motor Torque #|de|Motormoment  #|es|Torque Motor #" },
		{ 8, "Output Power #|de|Ausgangsleist#|es|Potencia Sal.#" },
		{ 9, "Process Var. #|de|Prozessvar.  #|es|Var. Proceso #" },
		{ 10, "Setpoint PID #|de|PID Sollwert #|es|Setpoint PID #" },
		{ 11, "Speed Refer. -|de|Drehz.Sollw. -|es|Ref. Veloc.  -" },
		{ 12, "Motor Speed  -|de|Motordrehz.  -|es|Veloc. Motor -" },
		{ 13, "MotorCurrent -|de|Motorstrom   -|es|Corr. Motor  -" },
		{ 14, "DC Link Volt -|de|ZwischenkrSpg-|es|Tensin CC   -" },
		{ 15, "Motor Freq.  -|de|Motorfrequenz-|es|Frec. Motor  -" },
		{ 16, "MotorVoltage -|de|Motorspg     -|es|Tensin Sal. -" },
		{ 17, "Motor Torque -|de|Motormoment  -|es|Torque Motor -" },
		{ 18, "Output Power -|de|Ausgangsleist-|es|Potencia Sal.-" },
		{ 19, "Process Var. -|de|Prozessvar.  -|es|Var. Proceso -" },
		{ 20, "Setpoint PID -|de|PID Sollwert -|es|Setpoint PID -" },
		{ 21, "SoftPLC P1010#|de|SoftPLC P1010#|es|SoftPLC P1010#" },
		{ 22, "SoftPLC P1011#|de|SoftPLC P1011#|es|SoftPLC P1011#" },
		{ 23, "SoftPLC P1012#|de|SoftPLC P1012#|es|SoftPLC P1012#" },
		{ 24, "SoftPLC P1013#|de|SoftPLC P1013#|es|SoftPLC P1013#" },
		{ 25, "SoftPLC P1014#|de|SoftPLC P1014#|es|SoftPLC P1014#" },
		{ 26, "SoftPLC P1015#|de|SoftPLC P1015#|es|SoftPLC P1015#" },
		{ 27, "SoftPLC P1016#|de|SoftPLC P1016#|es|SoftPLC P1016#" },
		{ 28, "SoftPLC P1017#|de|SoftPLC P1017#|es|SoftPLC P1017#" },
		{ 29, "SoftPLC P1018#|de|SoftPLC P1018#|es|SoftPLC P1018#" },
		{ 30, "SoftPLC P1019#|de|SoftPLC P1019#|es|SoftPLC P1019#" },
		{ 31, "PLC11  P1300 #|de|PLC11  P1300 #|es|PLC11  P1300 #" },
		{ 32, "PLC11  P1301 #|de|PLC11  P1301 #|es|PLC11  P1301 #" },
		{ 33, "PLC11  P1302 #|de|PLC11  P1302 #|es|PLC11  P1302 #" },
		{ 34, "PLC11  P1303 #|de|PLC11  P1303 #|es|PLC11  P1303 #" },
		{ 35, "PLC11  P1304 #|de|PLC11  P1304 #|es|PLC11  P1304 #" },
		{ 36, "PLC11  P1305 #|de|PLC11  P1305 #|es|PLC11  P1305 #" },
		{ 37, "PLC11  P1306 #|de|PLC11  P1306 #|es|PLC11  P1306 #" },
		{ 38, "PLC11  P1307 #|de|PLC11  P1307 #|es|PLC11  P1307 #" },
		{ 39, "PLC11  P1308 #|de|PLC11  P1308 #|es|PLC11  P1308 #" },
		{ 40, "PLC11  P1309 #|de|PLC11  P1309 #|es|PLC11  P1309 #" }
		DEFAULT_VALUE 2;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0205
	}
}

COMMAND READ_P0205
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0205 }
	}
}

METHOD SET_PAR_NUMBER_0205
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 205;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0205 LIKE READ_P0205
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 205, P0205 }
		REPLY { }
	}
}

VARIABLE P0206
{
	LABEL "P0206 Read Parameter Sel. 2|de|P0206 Anzeigeauswahl 2|es|P0206 Sel. Parm. Lectura 2";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "Not selected|de|Aus|es|Inactivo  " },
		{ 1, "Speed Refer. #|de|Drehz.Sollw. #|es|Ref. Veloc.  #" },
		{ 2, "Motor Speed  #|de|Motordrehz.  #|es|Veloc. Motor #" },
		{ 3, "MotorCurrent #|de|Motorstrom   #|es|Corr. Motor  #" },
		{ 4, "DC Link Volt #|de|ZwischenkrSpg#|es|Tensin CC   #" },
		{ 5, "Motor Freq.  #|de|Motorfrequenz#|es|Frec. Motor  #" },
		{ 6, "MotorVoltage #|de|Motorspg     #|es|Tensin Sal. #" },
		{ 7, "Motor Torque #|de|Motormoment  #|es|Torque Motor #" },
		{ 8, "Output Power #|de|Ausgangsleist#|es|Potencia Sal.#" },
		{ 9, "Process Var. #|de|Prozessvar.  #|es|Var. Proceso #" },
		{ 10, "Setpoint PID #|de|PID Sollwert #|es|Setpoint PID #" },
		{ 11, "Speed Refer. -|de|Drehz.Sollw. -|es|Ref. Veloc.  -" },
		{ 12, "Motor Speed  -|de|Motordrehz.  -|es|Veloc. Motor -" },
		{ 13, "MotorCurrent -|de|Motorstrom   -|es|Corr. Motor  -" },
		{ 14, "DC Link Volt -|de|ZwischenkrSpg-|es|Tensin CC   -" },
		{ 15, "Motor Freq.  -|de|Motorfrequenz-|es|Frec. Motor  -" },
		{ 16, "MotorVoltage -|de|Motorspg     -|es|Tensin Sal. -" },
		{ 17, "Motor Torque -|de|Motormoment  -|es|Torque Motor -" },
		{ 18, "Output Power -|de|Ausgangsleist-|es|Potencia Sal.-" },
		{ 19, "Process Var. -|de|Prozessvar.  -|es|Var. Proceso -" },
		{ 20, "Setpoint PID -|de|PID Sollwert -|es|Setpoint PID -" },
		{ 21, "SoftPLC P1010#|de|SoftPLC P1010#|es|SoftPLC P1010#" },
		{ 22, "SoftPLC P1011#|de|SoftPLC P1011#|es|SoftPLC P1011#" },
		{ 23, "SoftPLC P1012#|de|SoftPLC P1012#|es|SoftPLC P1012#" },
		{ 24, "SoftPLC P1013#|de|SoftPLC P1013#|es|SoftPLC P1013#" },
		{ 25, "SoftPLC P1014#|de|SoftPLC P1014#|es|SoftPLC P1014#" },
		{ 26, "SoftPLC P1015#|de|SoftPLC P1015#|es|SoftPLC P1015#" },
		{ 27, "SoftPLC P1016#|de|SoftPLC P1016#|es|SoftPLC P1016#" },
		{ 28, "SoftPLC P1017#|de|SoftPLC P1017#|es|SoftPLC P1017#" },
		{ 29, "SoftPLC P1018#|de|SoftPLC P1018#|es|SoftPLC P1018#" },
		{ 30, "SoftPLC P1019#|de|SoftPLC P1019#|es|SoftPLC P1019#" },
		{ 31, "PLC11  P1300 #|de|PLC11  P1300 #|es|PLC11  P1300 #" },
		{ 32, "PLC11  P1301 #|de|PLC11  P1301 #|es|PLC11  P1301 #" },
		{ 33, "PLC11  P1302 #|de|PLC11  P1302 #|es|PLC11  P1302 #" },
		{ 34, "PLC11  P1303 #|de|PLC11  P1303 #|es|PLC11  P1303 #" },
		{ 35, "PLC11  P1304 #|de|PLC11  P1304 #|es|PLC11  P1304 #" },
		{ 36, "PLC11  P1305 #|de|PLC11  P1305 #|es|PLC11  P1305 #" },
		{ 37, "PLC11  P1306 #|de|PLC11  P1306 #|es|PLC11  P1306 #" },
		{ 38, "PLC11  P1307 #|de|PLC11  P1307 #|es|PLC11  P1307 #" },
		{ 39, "PLC11  P1308 #|de|PLC11  P1308 #|es|PLC11  P1308 #" },
		{ 40, "PLC11  P1309 #|de|PLC11  P1309 #|es|PLC11  P1309 #" }
		DEFAULT_VALUE 3;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0206
	}
}

COMMAND READ_P0206
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0206 }
	}
}

METHOD SET_PAR_NUMBER_0206
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 206;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0206 LIKE READ_P0206
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 206, P0206 }
		REPLY { }
	}
}

VARIABLE P0207
{
	LABEL "P0207 Read Parameter Sel. 3|de|P0207 Anzeigeauswahl 3|es|P0207 Sel. Parm. Lectura 3";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "Not selected|de|Aus|es|Inactivo  " },
		{ 1, "Speed Refer. #|de|Drehz.Sollw. #|es|Ref. Veloc.  #" },
		{ 2, "Motor Speed  #|de|Motordrehz.  #|es|Veloc. Motor #" },
		{ 3, "MotorCurrent #|de|Motorstrom   #|es|Corr. Motor  #" },
		{ 4, "DC Link Volt #|de|ZwischenkrSpg#|es|Tensin CC   #" },
		{ 5, "Motor Freq.  #|de|Motorfrequenz#|es|Frec. Motor  #" },
		{ 6, "MotorVoltage #|de|Motorspg     #|es|Tensin Sal. #" },
		{ 7, "Motor Torque #|de|Motormoment  #|es|Torque Motor #" },
		{ 8, "Output Power #|de|Ausgangsleist#|es|Potencia Sal.#" },
		{ 9, "Process Var. #|de|Prozessvar.  #|es|Var. Proceso #" },
		{ 10, "Setpoint PID #|de|PID Sollwert #|es|Setpoint PID #" },
		{ 11, "Speed Refer. -|de|Drehz.Sollw. -|es|Ref. Veloc.  -" },
		{ 12, "Motor Speed  -|de|Motordrehz.  -|es|Veloc. Motor -" },
		{ 13, "MotorCurrent -|de|Motorstrom   -|es|Corr. Motor  -" },
		{ 14, "DC Link Volt -|de|ZwischenkrSpg-|es|Tensin CC   -" },
		{ 15, "Motor Freq.  -|de|Motorfrequenz-|es|Frec. Motor  -" },
		{ 16, "MotorVoltage -|de|Motorspg     -|es|Tensin Sal. -" },
		{ 17, "Motor Torque -|de|Motormoment  -|es|Torque Motor -" },
		{ 18, "Output Power -|de|Ausgangsleist-|es|Potencia Sal.-" },
		{ 19, "Process Var. -|de|Prozessvar.  -|es|Var. Proceso -" },
		{ 20, "Setpoint PID -|de|PID Sollwert -|es|Setpoint PID -" },
		{ 21, "SoftPLC P1010#|de|SoftPLC P1010#|es|SoftPLC P1010#" },
		{ 22, "SoftPLC P1011#|de|SoftPLC P1011#|es|SoftPLC P1011#" },
		{ 23, "SoftPLC P1012#|de|SoftPLC P1012#|es|SoftPLC P1012#" },
		{ 24, "SoftPLC P1013#|de|SoftPLC P1013#|es|SoftPLC P1013#" },
		{ 25, "SoftPLC P1014#|de|SoftPLC P1014#|es|SoftPLC P1014#" },
		{ 26, "SoftPLC P1015#|de|SoftPLC P1015#|es|SoftPLC P1015#" },
		{ 27, "SoftPLC P1016#|de|SoftPLC P1016#|es|SoftPLC P1016#" },
		{ 28, "SoftPLC P1017#|de|SoftPLC P1017#|es|SoftPLC P1017#" },
		{ 29, "SoftPLC P1018#|de|SoftPLC P1018#|es|SoftPLC P1018#" },
		{ 30, "SoftPLC P1019#|de|SoftPLC P1019#|es|SoftPLC P1019#" },
		{ 31, "PLC11  P1300 #|de|PLC11  P1300 #|es|PLC11  P1300 #" },
		{ 32, "PLC11  P1301 #|de|PLC11  P1301 #|es|PLC11  P1301 #" },
		{ 33, "PLC11  P1302 #|de|PLC11  P1302 #|es|PLC11  P1302 #" },
		{ 34, "PLC11  P1303 #|de|PLC11  P1303 #|es|PLC11  P1303 #" },
		{ 35, "PLC11  P1304 #|de|PLC11  P1304 #|es|PLC11  P1304 #" },
		{ 36, "PLC11  P1305 #|de|PLC11  P1305 #|es|PLC11  P1305 #" },
		{ 37, "PLC11  P1306 #|de|PLC11  P1306 #|es|PLC11  P1306 #" },
		{ 38, "PLC11  P1307 #|de|PLC11  P1307 #|es|PLC11  P1307 #" },
		{ 39, "PLC11  P1308 #|de|PLC11  P1308 #|es|PLC11  P1308 #" },
		{ 40, "PLC11  P1309 #|de|PLC11  P1309 #|es|PLC11  P1309 #" }
		DEFAULT_VALUE 5;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0207
	}
}

COMMAND READ_P0207
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0207 }
	}
}

METHOD SET_PAR_NUMBER_0207
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 207;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0207 LIKE READ_P0207
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 207, P0207 }
		REPLY { }
	}
}

VARIABLE P0208
{
	LABEL "P0208 Ref. Scale Factor|de|P0208 Sollwert Skalafaktor|es|P0208 Factor Escala Ref. ";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 1800;
		MIN_VALUE 1;
		MAX_VALUE 18000;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0208
	}
}

COMMAND READ_P0208
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0208 }
	}
}

METHOD SET_PAR_NUMBER_0208
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 208;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0208 LIKE READ_P0208
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 208, P0208 }
		REPLY { }
	}
}

VARIABLE P0209
{
	LABEL "P0209 Ref. Eng. Unit 1|de|P0209 1. Einheit Sollwert|es|P0209 Unidad Ing. Ref. 1";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 114;
		MIN_VALUE 32;
		MAX_VALUE 127;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0209
	}
}

COMMAND READ_P0209
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0209 }
	}
}

METHOD SET_PAR_NUMBER_0209
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 209;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0209 LIKE READ_P0209
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 209, P0209 }
		REPLY { }
	}
}

VARIABLE P0210
{
	LABEL "P0210 Ref. Eng. Unit 2|de|P0210 2. Einheit Sollwert|es|P0210 Unidad Ing. Ref. 2";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 112;
		MIN_VALUE 32;
		MAX_VALUE 127;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0210
	}
}

COMMAND READ_P0210
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0210 }
	}
}

METHOD SET_PAR_NUMBER_0210
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 210;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0210 LIKE READ_P0210
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 210, P0210 }
		REPLY { }
	}
}

VARIABLE P0211
{
	LABEL "P0211 Ref. Eng. Unit 3|de|P0211 3. Einheit Sollwert|es|P0211 Unidad Ing. Ref. 3";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 109;
		MIN_VALUE 32;
		MAX_VALUE 127;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0211
	}
}

COMMAND READ_P0211
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0211 }
	}
}

METHOD SET_PAR_NUMBER_0211
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 211;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0211 LIKE READ_P0211
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 211, P0211 }
		REPLY { }
	}
}

VARIABLE P0212
{
	LABEL "P0212 Ref. Decimal Point |de|P0212 Sollw. Dezimalpkt.|es|P0212 Modo Indicacin Ref.";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "wxyz|de|wxyz|es|wxyz" },
		{ 1, "wxy.z|de|wxy.z|es|wxy.z" },
		{ 2, "wx.yz|de|wx.yz|es|wx.yz" },
		{ 3, "w.xyz|de|w.xyz|es|w.xyz" }
		DEFAULT_VALUE 0;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0212
	}
}

COMMAND READ_P0212
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0212 }
	}
}

METHOD SET_PAR_NUMBER_0212
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 212;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0212 LIKE READ_P0212
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 212, P0212 }
		REPLY { }
	}
}

VARIABLE P0213
{
	LABEL "P0213 Full Scale Read 1|de|P0213 Anzeigebereich 1|es|P0213 Fondo Escala Lectura1";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{
		SCALING_FACTOR 0.1;
	}
	CONSTANT_UNIT "%";
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0213
	}
}

COMMAND READ_P0213
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0213 }
	}
}

METHOD SET_PAR_NUMBER_0213
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 213;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0213 LIKE READ_P0213
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 213, P0213 }
		REPLY { }
	}
}

VARIABLE P0214
{
	LABEL "P0214 Full Scale Read 2|de|P0214 Anzeigebereich 2|es|P0214 Fondo Escala Lectura2";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{
		SCALING_FACTOR 0.1;
	}
	CONSTANT_UNIT "%";
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0214
	}
}

COMMAND READ_P0214
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0214 }
	}
}

METHOD SET_PAR_NUMBER_0214
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 214;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0214 LIKE READ_P0214
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 214, P0214 }
		REPLY { }
	}
}

VARIABLE P0215
{
	LABEL "P0215 Full Scale Read 3|de|P0215 Anzeigebereich 3|es|P0215 Fondo Escala Lectura3";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{
		SCALING_FACTOR 0.1;
	}
	CONSTANT_UNIT "%";
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0215
	}
}

COMMAND READ_P0215
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0215 }
	}
}

METHOD SET_PAR_NUMBER_0215
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 215;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0215 LIKE READ_P0215
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 215, P0215 }
		REPLY { }
	}
}

VARIABLE P0216
{
	LABEL "P0216 HMI Display Contrast|de|P0216 LCD Kontrast|es|P0216 Contraste Display HMI";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 27;
		MIN_VALUE 0;
		MAX_VALUE 37;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0216
	}
}

COMMAND READ_P0216
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0216 }
	}
}

METHOD SET_PAR_NUMBER_0216
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 216;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0216 LIKE READ_P0216
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 216, P0216 }
		REPLY { }
	}
}

VARIABLE P0217
{
	LABEL "P0217 Zero Speed Disable|de|P0217 Stillstandsblockade|es|P0217 Bloqueo por Vel. Nula";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "Off       |de|Aus|es|Inactivo  " },
		{ 1, "On (N* and N)|de|Ein (N* und N)|es|Activo(N* y N)" },
		{ 2, "On (N*)|de|Ein (N*)|es|Activo (N*)" }
		DEFAULT_VALUE 0;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0217
	}
}

COMMAND READ_P0217
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0217 }
	}
}

METHOD SET_PAR_NUMBER_0217
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 217;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0217 LIKE READ_P0217
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 217, P0217 }
		REPLY { }
	}
}

VARIABLE P0218
{
	LABEL "P0218 Zero Speed Dis. Out|de|P0218 StillstBlock. Grenz.|es|P0218 Salida Bloq. Vel.Nula";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "Ref. or Speed|de|Sollw o. Drehz|es|Ref. o Vel." },
		{ 1, "Reference |de|Sollwert|es|Referencia" }
		DEFAULT_VALUE 0;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0218
	}
}

COMMAND READ_P0218
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0218 }
	}
}

METHOD SET_PAR_NUMBER_0218
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 218;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0218 LIKE READ_P0218
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 218, P0218 }
		REPLY { }
	}
}

VARIABLE P0219
{
	LABEL "P0219 Zero Speed Time|de|P0219 Stillstandblock. Zeit|es|P0219 Tiempo con Vel. Nula";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 999;
	}
	CONSTANT_UNIT "s";
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0219
	}
}

COMMAND READ_P0219
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0219 }
	}
}

METHOD SET_PAR_NUMBER_0219
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 219;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0219 LIKE READ_P0219
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 219, P0219 }
		REPLY { }
	}
}

VARIABLE P0220
{
	LABEL "P0220 LOC/REM Selection Src|de|P0220 LOC/REM Auswahl|es|P0220 Seleccin LOC/REM   ";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "Always LOC|de|Immer LOC|es|Siempre LOC" },
		{ 1, "Always REM|de|Immer REM|es|Siempre REM" },
		{ 2, "LR Key LOC|de|Taste LOC|es|Tecla LR (LOC)" },
		{ 3, "LR Key REM|de|Taste REM|es|Tecla LR (REM)" },
		{ 4, "DIx|de|DIx|es|DIx" },
		{ 5, "Serial/USB LOC|de|Seriel/USB LOC|es|Serie/USB LOC " },
		{ 6, "Serial/USB REM|de|Seriel/USB REM|es|Serie/USB REM " },
		{ 7, "Anybus-CC LOC|de|Anybus-CC LOC|es|Anybus-CC LOC" },
		{ 8, "Anybus-CC REM|de|Anybus-CC REM|es|Anybus-CC REM" },
		{ 9, "CO/DN/DP LOC|de|CO/DN/DP LOC|es|CO/DN/DP LOC" },
		{ 10, "CO/DN/DP REM|de|CO/DN/DP REM|es|CO/DN/DP REM" },
		{ 11, "SoftPLC LOC|de|SoftPLC LOC|es|SoftPLC LOC" },
		{ 12, "SoftPLC REM|de|SoftPLC REM|es|SoftPLC REM" },
		{ 13, "PLC11 LOC|de|PLC11 LOC|es|PLC11 LOC" },
		{ 14, "PLC11 REM|de|PLC11 REM|es|PLC11 REM" }
		DEFAULT_VALUE 2;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0220
	}
}

COMMAND READ_P0220
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0220 }
	}
}

METHOD SET_PAR_NUMBER_0220
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 220;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0220 LIKE READ_P0220
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 220, P0220 }
		REPLY { }
	}
}

VARIABLE P0221
{
	LABEL "P0221 LOC Reference Sel. |de|P0221 LOC Sollw. Auswahl|es|P0221 Selec. Referencia LOC";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "Keypad    |de|Fernbedienung|es|HMI" },
		{ 1, "AI1       |de|AI1|es|AI1       " },
		{ 2, "AI2       |de|AI2|es|AI2       " },
		{ 3, "AI3       |de|AI3|es|AI3       " },
		{ 4, "AI4       |de|AI4|es|AI4       " },
		{ 5, "Sum AIs > 0  |de|Summe AIs > 0|es|Suma AIs > 0 " },
		{ 6, "Sum AIs |de|Summe AI|es|Suma AIs   " },
		{ 7, "E.P.      |de|Elekt. Pot.|es|E.P.      " },
		{ 8, "Multispeed|de|Multispeed|es|Multispeed" },
		{ 9, "Serial/USB    |de|Seriell / USB|es|Serie/USB" },
		{ 10, "Anybus-CC|de|Anybus-CC|es|Anybus-CC" },
		{ 11, "CANop/DNet/DP|de|CANop/DNet/DP|es|CANop/DNet/DP" },
		{ 12, "SoftPLC|de|SoftPLC|es|SoftPLC" },
		{ 13, "PLC11|de|PLC11|es|PLC11" }
		DEFAULT_VALUE 0;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0221
	}
}

COMMAND READ_P0221
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0221 }
	}
}

METHOD SET_PAR_NUMBER_0221
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 221;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0221 LIKE READ_P0221
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 221, P0221 }
		REPLY { }
	}
}

VARIABLE P0222
{
	LABEL "P0222 REM Reference Sel. |de|P0222 REM Sollw. Auswahl|es|P0222 Selec. Referencia REM";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "Keypad    |de|Fernbedienung|es|HMI" },
		{ 1, "AI1       |de|AI1|es|AI1       " },
		{ 2, "AI2       |de|AI2|es|AI2       " },
		{ 3, "AI3       |de|AI3|es|AI3       " },
		{ 4, "AI4       |de|AI4|es|AI4       " },
		{ 5, "Sum AIs > 0  |de|Summe AIs > 0|es|Suma AIs > 0 " },
		{ 6, "Sum AIs |de|Summe AI|es|Suma AIs   " },
		{ 7, "E.P.      |de|Elekt. Pot.|es|E.P.      " },
		{ 8, "Multispeed|de|Multispeed|es|Multispeed" },
		{ 9, "Serial/USB    |de|Seriell / USB|es|Serie/USB" },
		{ 10, "Anybus-CC|de|Anybus-CC|es|Anybus-CC" },
		{ 11, "CANop/DNet/DP|de|CANop/DNet/DP|es|CANop/DNet/DP" },
		{ 12, "SoftPLC|de|SoftPLC|es|SoftPLC" },
		{ 13, "PLC11|de|PLC11|es|PLC11" }
		DEFAULT_VALUE 1;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0222
	}
}

COMMAND READ_P0222
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0222 }
	}
}

METHOD SET_PAR_NUMBER_0222
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 222;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0222 LIKE READ_P0222
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 222, P0222 }
		REPLY { }
	}
}

VARIABLE P0223
{
	LABEL "P0223 LOC FWD/REV Selection|de|P0223 LOC Drehrichtungswahl|es|P0223 Seleccin Giro LOC";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "Always FWD|de|Rechtslauf|es|Horario   " },
		{ 1, "Always REV|de|Linkslauf|es|Anti-Horario" },
		{ 2, "FR Key FWD|de|Fernbed. (R)|es|Tecla SG (H)  " },
		{ 3, "FR Key REV|de|Fernbed. (L)|es|Tecla SG (AH) " },
		{ 4, "DIx       |de|DIx       |es|DIx       " },
		{ 5, "Serial/USB FWD|de|Seriell/USB(R)|es|Serie/USB (H) " },
		{ 6, "Serial/USB REV|de|Seriell/USB(L)|es|Serie/USB (AH)" },
		{ 7, "Anybus-CC FWD|de|Anybus-CC (R)|es|Anybus-CC (H)" },
		{ 8, "Anybus-CC REV|de|Anybus-CC (L)|es|Anybus-CC (AH)" },
		{ 9, "CO/DN/DP FWD|de|CO/DN/DP (R)|es|CO/DN/DP (H)" },
		{ 10, "CO/DN/DP REV|de|CO/DN/DP (L)|es|CO/DN/DP (AH)" },
		{ 11, "AI4 Polarity|de|AI4 Polaritt|es|Polaridad AI4" },
		{ 12, "SoftPLC FWD|de|SoftPLC (R)|es|SoftPLC (H)" },
		{ 13, "SoftPLC REV|de|SoftPLC (L)|es|SoftPLC (AH)" },
		{ 14, "AI2 Polarity|de|AI2 Polaritt|es|Polaridad AI2" },
		{ 15, "PLC11 FWD|de|PLC11 (R)|es|PLC11  (H)" },
		{ 16, "PLC11 REV|de|PLC11 (L)|es|PLC11 (AH)" }
		DEFAULT_VALUE 2;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0223
	}
}

COMMAND READ_P0223
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0223 }
	}
}

METHOD SET_PAR_NUMBER_0223
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 223;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0223 LIKE READ_P0223
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 223, P0223 }
		REPLY { }
	}
}

VARIABLE P0224
{
	LABEL "P0224 LOC Run/Stop Sel.|de|P0224 LOC Start/Stop Ausw.|es|P0224 Selec. Gira/Para LOC";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "I,O Keys  |de|Fernbed. I,O|es|Teclas I,O" },
		{ 1, "DIx       |de|DIx|es|DIx       " },
		{ 2, "Serial/USB    |de|Seriell / USB|es|Serie/USB    " },
		{ 3, "Anybus-CC|de|Anybus-CC|es|Anybus-CC" },
		{ 4, "CANop/DNet/DP|de|CANop/DNet/DP|es|CANop/DNet/DP" },
		{ 5, "SoftPLC|de|SoftPLC|es|SoftPLC" },
		{ 6, "PLC11|de|PLC11|es|PLC11" }
		DEFAULT_VALUE 0;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0224
	}
}

COMMAND READ_P0224
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0224 }
	}
}

METHOD SET_PAR_NUMBER_0224
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 224;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0224 LIKE READ_P0224
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 224, P0224 }
		REPLY { }
	}
}

VARIABLE P0225
{
	LABEL "P0225 LOC JOG Selection|de|P0225 LOC JOG Auswahl|es|P0225 Seleccin JOG LOC";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "Disable   |de|Aus|es|Inactivo  " },
		{ 1, "JOG Key|de|Fernbedienung|es|Tecla JOG" },
		{ 2, "DIx       |de|DIx       |es|DIx       " },
		{ 3, "Serial/USB    |de|Seriell / USB|es|Serie/USB" },
		{ 4, "Anybus-CC|de|Anybus-CC|es|Anybus-CC" },
		{ 5, "CANop/DNet/DP|de|CANop/DNet/DP|es|CANop/DNet/DP" },
		{ 6, "SoftPLC|de|SoftPLC|es|SoftPLC" },
		{ 7, "PLC11|de|PLC11|es|PLC11" }
		DEFAULT_VALUE 1;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0225
	}
}

COMMAND READ_P0225
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0225 }
	}
}

METHOD SET_PAR_NUMBER_0225
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 225;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0225 LIKE READ_P0225
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 225, P0225 }
		REPLY { }
	}
}

VARIABLE P0226
{
	LABEL "P0226 REM FWD/REV Sel.|de|P0226 REM Drehrichtung|es|P0226 Seleccin Giro REM  ";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "Always FWD|de|Rechtslauf|es|Horario   " },
		{ 1, "Always REV|de|Linkslauf|es|Anti-Horario" },
		{ 2, "FR Key FWD|de|Fernbed. (R)|es|Tecla SG (H)  " },
		{ 3, "FR Key REV|de|Fernbed. (L)|es|Tecla SG (AH) " },
		{ 4, "DIx       |de|DIx       |es|DIx       " },
		{ 5, "Serial/USB FWD|de|Seriell/USB(R)|es|Serie/USB (H) " },
		{ 6, "Serial/USB REV|de|Seriell/USB(L)|es|Serie/USB (AH)" },
		{ 7, "Anybus-CC FWD|de|Anybus-CC (R)|es|Anybus-CC (H)" },
		{ 8, "Anybus-CC REV|de|Anybus-CC (L)|es|Anybus-CC (AH)" },
		{ 9, "CO/DN/DP FWD|de|CO/DN/DP (R)|es|CO/DN/DP (H)" },
		{ 10, "CO/DN/DP REV|de|CO/DN/DP (L)|es|CO/DN/DP (AH)" },
		{ 11, "AI4 Polarity|de|AI4 Polaritt|es|Polaridad AI4" },
		{ 12, "SoftPLC FWD|de|SoftPLC (R)|es|SoftPLC (H)" },
		{ 13, "SoftPLC REV|de|SoftPLC (L)|es|SoftPLC (AH)" },
		{ 14, "AI2 Polarity|de|AI2 Polaritt|es|Polaridad AI2" },
		{ 15, "PLC11 FWD|de|PLC11 (R)|es|PLC11  (H)" },
		{ 16, "PLC11 REV|de|PLC11 (L)|es|PLC11 (AH)" }
		DEFAULT_VALUE 4;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0226
	}
}

COMMAND READ_P0226
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0226 }
	}
}

METHOD SET_PAR_NUMBER_0226
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 226;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0226 LIKE READ_P0226
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 226, P0226 }
		REPLY { }
	}
}

VARIABLE P0227
{
	LABEL "P0227 REM Run/Stop Sel.|de|P0227 REM Start/Stop Ausw.|es|P0227 Selec. Gira/Para REM";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "I,O Keys  |de|Fernbed. I,O|es|Teclas I,O" },
		{ 1, "DIx       |de|DIx|es|DIx       " },
		{ 2, "Serial/USB    |de|Seriell / USB|es|Serie/USB    " },
		{ 3, "Anybus-CC|de|Anybus-CC|es|Anybus-CC" },
		{ 4, "CANop/DNet/DP|de|CANop/DNet/DP|es|CANop/DNet/DP" },
		{ 5, "SoftPLC|de|SoftPLC|es|SoftPLC" },
		{ 6, "PLC11|de|PLC11|es|PLC11" }
		DEFAULT_VALUE 1;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0227
	}
}

COMMAND READ_P0227
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0227 }
	}
}

METHOD SET_PAR_NUMBER_0227
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 227;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0227 LIKE READ_P0227
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 227, P0227 }
		REPLY { }
	}
}

VARIABLE P0228
{
	LABEL "P0228 REM JOG Selection |de|P0228 REM JOG Auswahl|es|P0228 Seleccin JOG REM";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "Disable   |de|Aus|es|Inactivo  " },
		{ 1, "JOG Key|de|Fernbedienung|es|Tecla JOG" },
		{ 2, "DIx       |de|DIx       |es|DIx       " },
		{ 3, "Serial/USB    |de|Seriell / USB|es|Serie/USB    " },
		{ 4, "Anybus-CC|de|Anybus-CC|es|Anybus-CC" },
		{ 5, "CANop/DNet/DP|de|CANop/DNet/DP|es|CANop/DNet/DP" },
		{ 6, "SoftPLC|de|SoftPLC|es|SoftPLC" },
		{ 7, "PLC11|de|PLC11|es|PLC11" }
		DEFAULT_VALUE 2;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0228
	}
}

COMMAND READ_P0228
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0228 }
	}
}

METHOD SET_PAR_NUMBER_0228
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 228;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0228 LIKE READ_P0228
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 228, P0228 }
		REPLY { }
	}
}

VARIABLE P0229
{
	LABEL "P0229 Stop Mode Selection|de|P0229 Auswahl Stopmodus|es|P0229 Seleccin de Parada";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "Ramp to Stop|de|Start/Stop|es|Por Rampa" },
		{ 1, "Coast to Stop|de|Gen. Abschalt.|es|Por Inercia" },
		{ 2, "Fast Stop |de|Schnellstop|es|Parada Rpida" },
		{ 3, "Ramp Stop Iq=0|de|Start/StopIq=0|es|Por Rampa Iq=0" },
		{ 4, "Fast Stop Iq=0|de|SchnelstopIq=0|es|ParRpida Iq=0" }
		DEFAULT_VALUE 0;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0229
	}
}

COMMAND READ_P0229
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0229 }
	}
}

METHOD SET_PAR_NUMBER_0229
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 229;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0229 LIKE READ_P0229
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 229, P0229 }
		REPLY { }
	}
}

VARIABLE P0230
{
	LABEL "P0230 Dead Zone (AIs)|de|P0230 Totzone (AIs)|es|P0230 Zona Muerta     ";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "Off       |de|Aus|es|Inactiva  " },
		{ 1, "On        |de|Ein|es|Activa    " }
		DEFAULT_VALUE 0;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0230
	}
}

COMMAND READ_P0230
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0230 }
	}
}

METHOD SET_PAR_NUMBER_0230
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 230;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0230 LIKE READ_P0230
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 230, P0230 }
		REPLY { }
	}
}

VARIABLE P0231
{
	LABEL "P0231 AI1 Signal Function|de|P0231 AI1 Signalfunktion|es|P0231 Funcin Seal AI1  ";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "Speed Ref.|de|Drehzahlsollw.|es|Ref. Veloc." },
		{ 1, "No Ramp Ref.|de|N* ohne Rampe|es|N* sin Rampa" },
		{ 2, "Max.Torque Cur|de|Max.Momentstr.|es|Mx.Cor.Torque" },
		{ 3, "Process Var.|de|Prozess Var.|es|Var. Proceso" },
		{ 4, "PTC|de|PTC|es|PTC" },
		{ 5, "Not Used  |de|Ohne Funktion|es|Sin Funcin " },
		{ 6, "Not Used  |de|Ohne Funktion|es|Sin Funcin " },
		{ 7, "PLC Use   |de|PLC Benutzung|es|Uso PLC   " }
		DEFAULT_VALUE 0;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0231
	}
}

COMMAND READ_P0231
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0231 }
	}
}

METHOD SET_PAR_NUMBER_0231
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 231;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0231 LIKE READ_P0231
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 231, P0231 }
		REPLY { }
	}
}

VARIABLE P0232
{
	LABEL "P0232 AI1 Gain|de|P0232 AI1 Verstrkung|es|P0232 Ganancia Entrada AI1 ";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{
		SCALING_FACTOR 0.001;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0232
	}
}

COMMAND READ_P0232
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0232 }
	}
}

METHOD SET_PAR_NUMBER_0232
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 232;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0232 LIKE READ_P0232
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 232, P0232 }
		REPLY { }
	}
}

VARIABLE P0233
{
	LABEL "P0233 AI1 Signal Type |de|P0233 AI1 Signaltyp|es|P0233 Seal Entrada AI1  ";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "0 to 10V/20mA|de|0 bis 10V/20mA|es|0 a 10V/20mA" },
		{ 1, "4 to 20 mA |de|4 bis 20mA|es|4 a 20 mA " },
		{ 2, "10V/20mA to 0|de|10V/20mA bis 0|es|10V/20mA a 0" },
		{ 3, "20 to 4 mA |de|20 bis 4mA|es|20 a 4 mA " }
		DEFAULT_VALUE 0;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0233
	}
}

COMMAND READ_P0233
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0233 }
	}
}

METHOD SET_PAR_NUMBER_0233
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 233;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0233 LIKE READ_P0233
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 233, P0233 }
		REPLY { }
	}
}

VARIABLE P0234
{
	LABEL "P0234 AI1 Offset      |de|P0234 AI1 Offset|es|P0234 Offset Entrada AI1 ";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{
		SCALING_FACTOR 0.01;
	}
	CONSTANT_UNIT "%";
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0234
	}
}

COMMAND READ_P0234
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0234 }
	}
}

METHOD SET_PAR_NUMBER_0234
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 234;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0234 LIKE READ_P0234
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 234, P0234 }
		REPLY { }
	}
}

VARIABLE P0235
{
	LABEL "P0235 AI1 Filter|de|P0235 AI1 Filter|es|P0235 Filtro Entrada AI1";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{
		SCALING_FACTOR 0.01;
	}
	CONSTANT_UNIT "s";
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0235
	}
}

COMMAND READ_P0235
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0235 }
	}
}

METHOD SET_PAR_NUMBER_0235
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 235;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0235 LIKE READ_P0235
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 235, P0235 }
		REPLY { }
	}
}

VARIABLE P0236
{
	LABEL "P0236 AI2 Signal Function|de|P0236 AI2 Signalfunktion|es|P0236 Funcin Seal AI2  ";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "Speed Ref.|de|Drehzahlsollw.|es|Ref. Veloc." },
		{ 1, "No Ramp Ref.|de|N* ohne Rampe|es|N* sin Rampa" },
		{ 2, "Max.Torque Cur|de|Max.Momentstr.|es|Mx.Cor.Torque" },
		{ 3, "Process Var.|de|Prozess Var.|es|Var. Proceso" },
		{ 4, "PTC|de|PTC|es|PTC" },
		{ 5, "Not Used  |de|Ohne Funktion|es|Sin Funcin " },
		{ 6, "Not Used  |de|Ohne Funktion|es|Sin Funcin " },
		{ 7, "PLC Use   |de|PLC Benutzung|es|Uso PLC   " }
		DEFAULT_VALUE 0;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0236
	}
}

COMMAND READ_P0236
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0236 }
	}
}

METHOD SET_PAR_NUMBER_0236
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 236;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0236 LIKE READ_P0236
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 236, P0236 }
		REPLY { }
	}
}

VARIABLE P0237
{
	LABEL "P0237 AI2 Gain        |de|P0237 AI2 Verstrkung|es|P0237 Ganancia Entrada AI2 ";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{
		SCALING_FACTOR 0.001;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0237
	}
}

COMMAND READ_P0237
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0237 }
	}
}

METHOD SET_PAR_NUMBER_0237
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 237;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0237 LIKE READ_P0237
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 237, P0237 }
		REPLY { }
	}
}

VARIABLE P0238
{
	LABEL "P0238 AI2 Signal Type |de|P0238 AI2 Signaltyp|es|P0238 Seal Entrada AI2  ";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "0 to 10V/20mA|de|0 bis 10V/20mA|es|0 a 10V/20mA" },
		{ 1, "4 to 20 mA |de|4 bis 20mA|es|4 a 20 mA " },
		{ 2, "10V/20mA to 0|de|10V/20mA bis 0|es|10V/20mA a 0" },
		{ 3, "20 to 4 mA |de|20 bis 4mA|es|20 a 4 mA " },
		{ 4, "-10 to +10V|de|-10 bis +10V|es|-10 a +10V" }
		DEFAULT_VALUE 0;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0238
	}
}

COMMAND READ_P0238
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0238 }
	}
}

METHOD SET_PAR_NUMBER_0238
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 238;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0238 LIKE READ_P0238
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 238, P0238 }
		REPLY { }
	}
}

VARIABLE P0239
{
	LABEL "P0239 AI2 Offset      |de|P0239 AI2 Offset|es|P0239 Offset Entrada AI2 ";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{
		SCALING_FACTOR 0.01;
	}
	CONSTANT_UNIT "%";
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0239
	}
}

COMMAND READ_P0239
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0239 }
	}
}

METHOD SET_PAR_NUMBER_0239
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 239;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0239 LIKE READ_P0239
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 239, P0239 }
		REPLY { }
	}
}

VARIABLE P0240
{
	LABEL "P0240 AI2 Filter|de|P0240 AI2 Filter|es|P0240 Filtro Entrada AI2";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{
		SCALING_FACTOR 0.01;
	}
	CONSTANT_UNIT "s";
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0240
	}
}

COMMAND READ_P0240
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0240 }
	}
}

METHOD SET_PAR_NUMBER_0240
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 240;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0240 LIKE READ_P0240
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 240, P0240 }
		REPLY { }
	}
}

VARIABLE P0241
{
	LABEL "P0241 AI3 Signal Function|de|P0241 AI3 Signalfunktion|es|P0241 Funcin Seal AI3";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "Speed Ref.|de|Drehzahlsollw.|es|Ref. Veloc." },
		{ 1, "No Ramp Ref.|de|N* ohne Rampe|es|N* sin Rampa" },
		{ 2, "Max.Torque Cur|de|Max.Momentstr.|es|Mx.Cor.Torque" },
		{ 3, "Process Var.|de|Prozess Var.|es|Var. Proceso" },
		{ 4, "PTC|de|PTC|es|PTC" },
		{ 5, "Not Used  |de|Ohne Funktion|es|Sin Funcin " },
		{ 6, "Not Used  |de|Ohne Funktion|es|Sin Funcin " },
		{ 7, "PLC Use   |de|PLC Benutzung|es|Uso PLC   " }
		DEFAULT_VALUE 0;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0241
	}
}

COMMAND READ_P0241
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0241 }
	}
}

METHOD SET_PAR_NUMBER_0241
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 241;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0241 LIKE READ_P0241
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 241, P0241 }
		REPLY { }
	}
}

VARIABLE P0242
{
	LABEL "P0242 AI3 Gain        |de|P0242 AI3 Verstrkung|es|P0242 Ganancia Entrada AI3 ";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{
		SCALING_FACTOR 0.001;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0242
	}
}

COMMAND READ_P0242
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0242 }
	}
}

METHOD SET_PAR_NUMBER_0242
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 242;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0242 LIKE READ_P0242
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 242, P0242 }
		REPLY { }
	}
}

VARIABLE P0243
{
	LABEL "P0243 AI3 Signal Type |de|P0243 AI3 Signaltyp|es|P0243 Seal Entrada AI3  ";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "0 to 10V/20mA|de|0 bis 10V/20mA|es|0 a 10V/20mA" },
		{ 1, "4 to 20 mA |de|4 bis 20mA|es|4 a 20 mA " },
		{ 2, "10V/20mA to 0|de|10V/20mA bis 0|es|10V/20mA a 0" },
		{ 3, "20 to 4 mA |de|20 bis 4mA|es|20 a 4 mA " }
		DEFAULT_VALUE 0;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0243
	}
}

COMMAND READ_P0243
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0243 }
	}
}

METHOD SET_PAR_NUMBER_0243
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 243;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0243 LIKE READ_P0243
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 243, P0243 }
		REPLY { }
	}
}

VARIABLE P0244
{
	LABEL "P0244 AI3 Offset      |de|P0244 AI3 Offset|es|P0244 Offset Entrada AI3 ";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{
		SCALING_FACTOR 0.01;
	}
	CONSTANT_UNIT "%";
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0244
	}
}

COMMAND READ_P0244
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0244 }
	}
}

METHOD SET_PAR_NUMBER_0244
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 244;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0244 LIKE READ_P0244
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 244, P0244 }
		REPLY { }
	}
}

VARIABLE P0245
{
	LABEL "P0245 AI3 Filter|de|P0245 AI3 Filter|es|P0245 Filtro Entrada AI3";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{
		SCALING_FACTOR 0.01;
	}
	CONSTANT_UNIT "s";
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0245
	}
}

COMMAND READ_P0245
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0245 }
	}
}

METHOD SET_PAR_NUMBER_0245
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 245;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0245 LIKE READ_P0245
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 245, P0245 }
		REPLY { }
	}
}

VARIABLE P0246
{
	LABEL "P0246 AI4 Signal Function|de|P0246 AI4Signalfunkt.|es|P0246 Funcin Seal AI4";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "Speed Ref.|de|Drehzahlsollw.|es|Ref. Veloc." },
		{ 1, "No Ramp Ref.|de|N* ohne Rampe|es|N* sin Rampa" },
		{ 2, "Max.Torque Cur|de|Max.Momentstr.|es|Mx.Cor.Torque" },
		{ 3, "Process Var.|de|Prozess Var.|es|Var. Proceso" },
		{ 4, "Not Used  |de|Ohne Funktion|es|Sin Funcin " },
		{ 5, "Not Used  |de|Ohne Funktion|es|Sin Funcin " },
		{ 6, "Not Used  |de|Ohne Funktion|es|Sin Funcin " },
		{ 7, "PLC Use   |de|PLC Benutzung|es|Uso PLC   " }
		DEFAULT_VALUE 0;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0246
	}
}

COMMAND READ_P0246
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0246 }
	}
}

METHOD SET_PAR_NUMBER_0246
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 246;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0246 LIKE READ_P0246
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 246, P0246 }
		REPLY { }
	}
}

VARIABLE P0247
{
	LABEL "P0247 AI4 Gain        |de|P0247 AI4 Verstrkung|es|P0247 Ganancia Entrada AI4 ";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{
		SCALING_FACTOR 0.001;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0247
	}
}

COMMAND READ_P0247
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0247 }
	}
}

METHOD SET_PAR_NUMBER_0247
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 247;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0247 LIKE READ_P0247
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 247, P0247 }
		REPLY { }
	}
}

VARIABLE P0248
{
	LABEL "P0248 AI4 Signal Type |de|P0248 AI4 Signaltyp|es|P0248 Seal Entrada AI4  ";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "0 to 10V/20mA|de|0 bis 10V/20mA|es|0 a 10V/20mA" },
		{ 1, "4 to 20 mA |de|4 bis 20mA|es|4 a 20 mA " },
		{ 2, "10V/20mA to 0|de|10V/20mA bis 0|es|10V/20mA a 0" },
		{ 3, "20 to 4 mA |de|20 bis 4mA|es|20 a 4 mA " },
		{ 4, "-10 to +10 V|de|-10 bis +10V|es|-10 a +10V" }
		DEFAULT_VALUE 0;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0248
	}
}

COMMAND READ_P0248
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0248 }
	}
}

METHOD SET_PAR_NUMBER_0248
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 248;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0248 LIKE READ_P0248
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 248, P0248 }
		REPLY { }
	}
}

VARIABLE P0249
{
	LABEL "P0249 AI4 Offset      |de|P0249 AI4 Offset|es|P0249 Offset Entrada AI4 ";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{
		SCALING_FACTOR 0.01;
	}
	CONSTANT_UNIT "%";
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0249
	}
}

COMMAND READ_P0249
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0249 }
	}
}

METHOD SET_PAR_NUMBER_0249
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 249;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0249 LIKE READ_P0249
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 249, P0249 }
		REPLY { }
	}
}

VARIABLE P0250
{
	LABEL "P0250 AI4 Filter|de|P0250 AI4 Filter|es|P0250 Filtro Entrada AI4";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{
		SCALING_FACTOR 0.01;
	}
	CONSTANT_UNIT "s";
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0250
	}
}

COMMAND READ_P0250
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0250 }
	}
}

METHOD SET_PAR_NUMBER_0250
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 250;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0250 LIKE READ_P0250
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 250, P0250 }
		REPLY { }
	}
}

VARIABLE P0251
{
	LABEL "P0251 AO1 Function    |de|P0251 AO1 Funktion|es|P0251 Funcin Salida AO1  ";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "Speed Ref.|de|Drehzahlsollw.|es|Ref. Velocidad" },
		{ 1, "Total Ref.|de|Gesamtsollwert|es|Ref. Total" },
		{ 2, "Real Speed|de|Istdrehzahl|es|Velocidad Real" },
		{ 3, "Torque Cur.Ref|de|Momentsollw.|es|Ref.Cor.Torque" },
		{ 4, "Torque Current|de|Momentstrom|es|Corr. Torque" },
		{ 5, "Output Current|de|Ausgangsstrom|es|Corr. Salida" },
		{ 6, "Process Var.|de|Prozess Var.|es|Var. Proceso" },
		{ 7, "Active Current|de|Wirkstrom|es|Corr. Activa" },
		{ 8, "Output Power |de|Ausgangsleist.|es|Pot. Salida" },
		{ 9, "PID Setpoint|de|PID Sollwert|es|Setpoint PID" },
		{ 10, "Torque Cur.> 0|de|Momentstrom >0|es|Corr. Torque>0" },
		{ 11, "Motor Torque|de|Motormoment|es|Torque Motor " },
		{ 12, "SoftPLC|de|SoftPLC|es|SoftPLC" },
		{ 13, "PTC|de|PTC|es|PTC" },
		{ 14, "Not Used  |de|Ohne Funktion|es|Sin Funcin " },
		{ 15, "Not Used  |de|Ohne Funktion|es|Sin Funcin " },
		{ 16, "Motor Ixt|de|Motor I x t|es|Ixt Motor" },
		{ 17, "Encoder Speed|de|Drehgeb.Geschw|es|Veloc. Encoder" },
		{ 18, "P0696 Value|de|P0696 Wert|es|ContenidoP0696" },
		{ 19, "P0697 Value|de|P0697 Wert|es|ContenidoP0697" },
		{ 20, "P0698 Value|de|P0698 Wert|es|ContenidoP0698" },
		{ 21, "P0699 Value|de|P0699 Wert|es|ContenidoP0699" },
		{ 22, "PLC11|de|PLC11|es|PLC11" },
		{ 23, "Id* Current|de|Id* Strom|es|Corriente Id*" }
		DEFAULT_VALUE 2;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0251
	}
}

COMMAND READ_P0251
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0251 }
	}
}

METHOD SET_PAR_NUMBER_0251
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 251;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0251 LIKE READ_P0251
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 251, P0251 }
		REPLY { }
	}
}

VARIABLE P0252
{
	LABEL "P0252 AO1 Gain        |de|P0252 AO1 Verstrkung|es|P0252 Ganancia Salida AO1";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{
		SCALING_FACTOR 0.001;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0252
	}
}

COMMAND READ_P0252
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0252 }
	}
}

METHOD SET_PAR_NUMBER_0252
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 252;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0252 LIKE READ_P0252
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 252, P0252 }
		REPLY { }
	}
}

VARIABLE P0253
{
	LABEL "P0253 AO1 Signal Type |de|P0253 AO1 Signaltyp|es|P0253 Seal Salida AO1  ";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "0 to 10V/20mA|de|0 bis 10V/20mA|es|0 a 10V/20mA" },
		{ 1, "4 to 20 mA |de|4 bis 20mA |es|4 a 20 mA " },
		{ 2, "10V/20mA to 0|de|10V/20mA bis 0|es|10V/20mA a 0" },
		{ 3, "20 to 4 mA |de|20 bis 4mA |es|20 a 4 mA " }
		DEFAULT_VALUE 0;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0253
	}
}

COMMAND READ_P0253
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0253 }
	}
}

METHOD SET_PAR_NUMBER_0253
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 253;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0253 LIKE READ_P0253
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 253, P0253 }
		REPLY { }
	}
}

VARIABLE P0254
{
	LABEL "P0254 AO2 Function    |de|P0254 AO2 Funktion|es|P0254 Funcin Salida AO2  ";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "Speed Ref.|de|Drehzahlsollw.|es|Ref. Velocidad" },
		{ 1, "Total Ref.|de|Gesamtsollwert|es|Ref. Total" },
		{ 2, "Real Speed|de|Istdrehzahl|es|Velocidad Real" },
		{ 3, "Torque Cur.Ref|de|Momentsollw.|es|Ref.Cor.Torque" },
		{ 4, "Torque Current|de|Momentstrom|es|Corr. Torque" },
		{ 5, "Output Current|de|Ausgangsstrom|es|Corr. Salida" },
		{ 6, "Process Var.|de|Prozess Var.|es|Var. Proceso" },
		{ 7, "Active Current|de|Wirkstrom|es|Corr. Activa" },
		{ 8, "Output Power |de|Ausgangsleist.|es|Pot. Salida" },
		{ 9, "PID Setpoint|de|PID Sollwert|es|Setpoint PID" },
		{ 10, "Torque Cur.> 0|de|Momentstrom >0|es|Corr. Torque>0" },
		{ 11, "Motor Torque|de|Motormoment|es|Torque Motor " },
		{ 12, "SoftPLC|de|SoftPLC|es|SoftPLC" },
		{ 13, "PTC|de|PTC|es|PTC" },
		{ 14, "Not Used  |de|Ohne Funktion|es|Sin Funcin " },
		{ 15, "Not Used  |de|Ohne Funktion|es|Sin Funcin " },
		{ 16, "Motor Ixt|de|Motor I x t|es|Ixt Motor" },
		{ 17, "Encoder Speed|de|Drehgeb.Geschw|es|Veloc. Encoder" },
		{ 18, "P0696 Value|de|P0696 Wert|es|ContenidoP0696" },
		{ 19, "P0697 Value|de|P0697 Wert|es|ContenidoP0697" },
		{ 20, "P0698 Value|de|P0698 Wert|es|ContenidoP0698" },
		{ 21, "P0699 Value|de|P0699 Wert|es|ContenidoP0699" },
		{ 22, "PLC11|de|PLC11|es|PLC11" },
		{ 23, "Id* Current|de|Id* Strom|es|Corriente Id*" }
		DEFAULT_VALUE 5;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0254
	}
}

COMMAND READ_P0254
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0254 }
	}
}

METHOD SET_PAR_NUMBER_0254
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 254;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0254 LIKE READ_P0254
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 254, P0254 }
		REPLY { }
	}
}

VARIABLE P0255
{
	LABEL "P0255 AO2 Gain        |de|P0255 AO2 Verstrkung|es|P0255 Ganancia Salida AO2";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{
		SCALING_FACTOR 0.001;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0255
	}
}

COMMAND READ_P0255
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0255 }
	}
}

METHOD SET_PAR_NUMBER_0255
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 255;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0255 LIKE READ_P0255
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 255, P0255 }
		REPLY { }
	}
}

VARIABLE P0256
{
	LABEL "P0256 AO2 Signal Type |de|P0256 AO2 Signaltyp|es|P0256 Seal Salida AO2";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "0 to 10V/20mA|de|0 bis 10V/20mA|es|0 a 10V/20mA" },
		{ 1, "4 to 20 mA |de|4 bis 20mA |es|4 a 20 mA " },
		{ 2, "10V/20mA to 0|de|10V/20mA bis 0|es|10V/20mA a 0" },
		{ 3, "20 to 4 mA |de|20 bis 4mA |es|20 a 4 mA " }
		DEFAULT_VALUE 0;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0256
	}
}

COMMAND READ_P0256
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0256 }
	}
}

METHOD SET_PAR_NUMBER_0256
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 256;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0256 LIKE READ_P0256
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 0, P0256 }
		REPLY { }
	}
}

VARIABLE P0257
{
	LABEL "P0257 AO3 Function    |de|P0257 AO3 Funktion|es|P0257 Funcin Salida AO3 ";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "Speed Ref.|de|Drehzahlsollw.|es|Ref. Velocidad" },
		{ 1, "Total Ref.|de|Gesamtsollwert|es|Ref. Total" },
		{ 2, "Real Speed|de|Istdrehzahl|es|Velocidad Real" },
		{ 3, "Torque Cur.Ref|de|Momentsollw.|es|Ref.Cor.Torque" },
		{ 4, "Torque Current|de|Momentstrom|es|Corr. Torque" },
		{ 5, "Output Current|de|Ausgangsstrom|es|Corr. Salida" },
		{ 6, "Process Var.|de|Prozess Var.|es|Var. Proceso" },
		{ 7, "Active Current|de|Wirkstrom|es|Corr. Activa" },
		{ 8, "Output Power |de|Ausgangsleist.|es|Pot. Salida" },
		{ 9, "PID Setpoint|de|PID Sollwert|es|Setpoint PID" },
		{ 10, "Torque Cur.> 0|de|Momentstrom >0|es|Corr. Torque>0" },
		{ 11, "Motor Torque|de|Motormoment|es|Torque Motor " },
		{ 12, "SoftPLC|de|SoftPLC|es|SoftPLC" },
		{ 13, "Not Used  |de|Ohne Funktion|es|Sin Funcin " },
		{ 14, "Not Used  |de|Ohne Funktion|es|Sin Funcin " },
		{ 15, "Not Used  |de|Ohne Funktion|es|Sin Funcin " },
		{ 16, "Motor Ixt|de|Motor I x t|es|Ixt Motor" },
		{ 17, "Encoder Speed|de|Drehgeb.Geschw|es|Veloc. Encoder" },
		{ 18, "P0696 Value|de|P0696 Wert|es|ContenidoP0696" },
		{ 19, "P0697 Value|de|P0697 Wert|es|ContenidoP0697" },
		{ 20, "P0698 Value|de|P0698 Wert|es|ContenidoP0698" },
		{ 21, "P0699 Value|de|P0699 Wert|es|ContenidoP0699" },
		{ 22, "Not Used  |de|Ohne Funktion|es|Sin Funcin " },
		{ 23, "Id* Current|de|Id* Strom|es|Corriente Id*" },
		{ 24, "Iq* Current|de|Iq* Strom|es|Corriente Iq*" },
		{ 25, "Id Current|de|Id Strom|es|Corriente Id" },
		{ 26, "Iq Current|de|Iq Strom|es|Corriente Iq" },
		{ 27, "Isa Current|de|Isa Strom|es|Corriente Isa" },
		{ 28, "Isb Current|de|Isb Strom|es|Corriente Isb" },
		{ 29, "Idq Current|de|Idq Strom|es|Corriente Idq" },
		{ 30, "Imr* Current|de|Imr* Strom|es|Corriente Imr*" },
		{ 31, "Imr Current|de|Imr Strom|es|Corriente Imr" },
		{ 32, "Ud Voltage|de|Ud Spannung|es|Tensin Ud" },
		{ 33, "Uq Voltage|de|Uq Spannung|es|Tensin Uq" },
		{ 34, "Flux Angle|de|Flusswinkel|es|ngulo Flujo" },
		{ 35, "Usal_rec|de|Usal_rec|es|Usal_rec" },
		{ 36, "Ixt Output|de|I x t Ausgang|es|Salida Ixt" },
		{ 37, "Rotor speed|de|Rotorgeschw.|es|Veloc. Rotor" },
		{ 38, "Phi Angle|de|Winkel Phi|es|ngulo Phi" },
		{ 39, "Usd_rec|de|Usd_rec|es|Usd_rec" },
		{ 40, "Usq_rec|de|Usq_rec|es|Usq_rec" },
		{ 41, "Flux_a1|de|Fluss_a1|es|Flux_a1" },
		{ 42, "Flux_b1|de|Fluss_b1|es|Flux_b1" },
		{ 43, "Stator Speed|de|Statorgeschw.|es|Vel. Estator" },
		{ 44, "Slip|de|Schlupf|es|Deslizamiento" },
		{ 45, "Flux reference|de|Flusssollwert|es|Ref. de flujo" },
		{ 46, "Real Flux|de|Istfluss|es|Flujo real" },
		{ 47, "Igen = Reg_ud|de|Igen = Reg_ud|es|Igen = Reg_ud" },
		{ 48, "Not Used  |de|Ohne Funktion|es|Sin Funcin " },
		{ 49, "Total Curr wIt|de|Gesamtstr. wIt|es|Cor. Total wIt" },
		{ 50, "Is Current|de|Is Strom|es|Corriente Is" },
		{ 51, "Iactive|de|Iaktiv|es|Iactiva" },
		{ 52, "sR|de|sR|es|sR" },
		{ 53, "TR|de|TR|es|TR" },
		{ 54, "PfeR|de|PfeR|es|PfeR" },
		{ 55, "Pfe |de|Pfe |es|Pfe " },
		{ 56, "Pgap|de|Pgap|es|Pgap" },
		{ 57, "TL|de|TL|es|TL" },
		{ 58, "Fslip |de|Fslip |es|Fslip " },
		{ 59, "m_nc|de|m_nc|es|m_nc" },
		{ 60, "m_AST|de|m_AST|es|m_AST" },
		{ 61, "m_|de|m_|es|m_" },
		{ 62, "m_LINHA|de|m_LINHA|es|m_LINHA" },
		{ 63, "m_BOOST|de|m_BOOST|es|m_BOOST" },
		{ 64, "SINPHI|de|SINPHI|es|SINPHI" },
		{ 65, "SINPHI120|de|SINPHI120|es|SINPHI120" },
		{ 66, "Ib|de|Ib|es|Ib" },
		{ 67, "Ic|de|Ic|es|Ic" },
		{ 68, "It|de|It|es|It" },
		{ 69, "MOD_I|de|MOD_I|es|MOD_I" },
		{ 70, "ZERO_V|de|ZERO_V|es|ZERO_V" },
		{ 71, "P0676 Value|de|P0676 Wert|es|ContenidoP0676" }
		DEFAULT_VALUE 2;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0257
	}
}

COMMAND READ_P0257
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0257 }
	}
}

METHOD SET_PAR_NUMBER_0257
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 257;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0257 LIKE READ_P0257
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 1, P0257 }
		REPLY { }
	}
}

VARIABLE P0258
{
	LABEL "P0258 AO3 Gain        |de|P0258 AO3 Verstrkung|es|P0258 Ganancia Salida AO3";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{
		SCALING_FACTOR 0.001;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0258
	}
}

COMMAND READ_P0258
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0258 }
	}
}

METHOD SET_PAR_NUMBER_0258
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 258;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0258 LIKE READ_P0258
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 2, P0258 }
		REPLY { }
	}
}

VARIABLE P0259
{
	LABEL "P0259 AO3 Signal Type |de|P0259 AO3 Signaltyp|es|P0259 Seal Salida AO3  ";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "0 to 20 mA|de|0 bis 20 mA|es|0 a 20mA" },
		{ 1, "4 to 20 mA |de|4 bis 20 mA |es|4 a 20 mA " },
		{ 2, "20 to 0 mA|de|20 bis 0 mA|es|20mA a 0" },
		{ 3, "20 to 4 mA |de|20 bis 4 mA |es|20 a 4 mA " },
		{ 4, "0 to 10 V|de|0 bis 10 V|es|0 a 10 V" },
		{ 5, "10 to 0 V|de|10 bis 0 V|es|10 a 0 V" },
		{ 6, "-10 to +10V|de|-10 bis +10V|es|-10 a +10V" }
		DEFAULT_VALUE 4;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0259
	}
}

COMMAND READ_P0259
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0259 }
	}
}

METHOD SET_PAR_NUMBER_0259
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 259;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0259 LIKE READ_P0259
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 3, P0259 }
		REPLY { }
	}
}

VARIABLE P0260
{
	LABEL "P0260 AO4 Function    |de|P0260 AO4 Funktion|es|P0260 Funcin Salida AO4 ";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "Speed Ref.|de|Drehzahlsollw.|es|Ref. Velocidad" },
		{ 1, "Total Ref.|de|Gesamtsollwert|es|Ref. Total" },
		{ 2, "Real Speed|de|Istdrehzahl|es|Velocidad Real" },
		{ 3, "Torque Cur.Ref|de|Momentsollw.|es|Ref.Cor.Torque" },
		{ 4, "Torque Current|de|Momentstrom|es|Corr. Torque" },
		{ 5, "Output Current|de|Ausgangsstrom|es|Corr. Salida" },
		{ 6, "Process Var.|de|Prozess Var.|es|Var. Proceso" },
		{ 7, "Active Current|de|Wirkstrom|es|Corr. Activa" },
		{ 8, "Output Power |de|Ausgangsleist.|es|Pot. Salida" },
		{ 9, "PID Setpoint|de|PID Sollwert|es|Setpoint PID" },
		{ 10, "Torque Cur.> 0|de|Momentstrom >0|es|Corr. Torque>0" },
		{ 11, "Motor Torque|de|Motormoment|es|Torque Motor " },
		{ 12, "SoftPLC|de|SoftPLC|es|SoftPLC" },
		{ 13, "Not Used  |de|Ohne Funktion|es|Sin Funcin " },
		{ 14, "Not Used  |de|Ohne Funktion|es|Sin Funcin " },
		{ 15, "Not Used  |de|Ohne Funktion|es|Sin Funcin " },
		{ 16, "Motor Ixt|de|Motor I x t|es|Ixt Motor" },
		{ 17, "Encoder Speed|de|Drehgeb.Geschw|es|Veloc. Encoder" },
		{ 18, "P0696 Value|de|P0696 Wert|es|ContenidoP0696" },
		{ 19, "P0697 Value|de|P0697 Wert|es|ContenidoP0697" },
		{ 20, "P0698 Value|de|P0698 Wert|es|ContenidoP0698" },
		{ 21, "P0699 Value|de|P0699 Wert|es|ContenidoP0699" },
		{ 22, "Not Used  |de|Ohne Funktion|es|Sin Funcin " },
		{ 23, "Id* Current|de|Id* Strom|es|Corriente Id*" },
		{ 24, "Iq* Current|de|Iq* Strom|es|Corriente Iq*" },
		{ 25, "Id Current|de|Id Strom|es|Corriente Id" },
		{ 26, "Iq Current|de|Iq Strom|es|Corriente Iq" },
		{ 27, "Isa Current|de|Isa Strom|es|Corriente Isa" },
		{ 28, "Isb Current|de|Isb Strom|es|Corriente Isb" },
		{ 29, "Idq Current|de|Idq Strom|es|Corriente Idq" },
		{ 30, "Imr* Current|de|Imr* Strom|es|Corriente Imr*" },
		{ 31, "Imr Current|de|Imr Strom|es|Corriente Imr" },
		{ 32, "Ud Voltage|de|Ud Spannung|es|Tensin Ud" },
		{ 33, "Uq Voltage|de|Uq Spannung|es|Tensin Uq" },
		{ 34, "Flux Angle|de|Flusswinkel|es|ngulo Flujo" },
		{ 35, "Usal_rec|de|Usal_rec|es|Usal_rec" },
		{ 36, "Ixt Output|de|I x t Ausgang|es|Salida Ixt" },
		{ 37, "Rotor speed|de|Rotorgeschw.|es|Veloc. Rotor" },
		{ 38, "Phi Angle|de|Winkel Phi|es|ngulo Phi" },
		{ 39, "Usd_rec|de|Usd_rec|es|Usd_rec" },
		{ 40, "Usq_rec|de|Usq_rec|es|Usq_rec" },
		{ 41, "Flux_a1|de|Fluss_a1|es|Flux_a1" },
		{ 42, "Flux_b1|de|Fluss_b1|es|Flux_b1" },
		{ 43, "Stator Speed|de|Statorgeschw.|es|Vel. Estator" },
		{ 44, "Slip|de|Schlupf|es|Deslizamiento" },
		{ 45, "Flux reference|de|Flusssollwert|es|Ref. de flujo" },
		{ 46, "Real Flux|de|Istfluss|es|Flujo real" },
		{ 47, "Igen = Reg_ud|de|Igen = Reg_ud|es|Igen = Reg_ud" },
		{ 48, "Not Used  |de|Ohne Funktion|es|Sin Funcin " },
		{ 49, "Total Curr wIt|de|Gesamtstr. wIt|es|Cor. Total wIt" },
		{ 50, "Is Current|de|Is Strom|es|Corriente Is" },
		{ 51, "Iactive|de|Iaktiv|es|Iactiva" },
		{ 52, "sR|de|sR|es|sR" },
		{ 53, "TR|de|TR|es|TR" },
		{ 54, "PfeR|de|PfeR|es|PfeR" },
		{ 55, "Pfe |de|Pfe |es|Pfe " },
		{ 56, "Pgap|de|Pgap|es|Pgap" },
		{ 57, "TL|de|TL|es|TL" },
		{ 58, "Fslip |de|Fslip |es|Fslip " },
		{ 59, "m_nc|de|m_nc|es|m_nc" },
		{ 60, "m_AST|de|m_AST|es|m_AST" },
		{ 61, "m_|de|m_|es|m_" },
		{ 62, "m_LINHA|de|m_LINHA|es|m_LINHA" },
		{ 63, "m_BOOST|de|m_BOOST|es|m_BOOST" },
		{ 64, "SINPHI|de|SINPHI|es|SINPHI" },
		{ 65, "SINPHI120|de|SINPHI120|es|SINPHI120" },
		{ 66, "Ib|de|Ib|es|Ib" },
		{ 67, "Ic|de|Ic|es|Ic" },
		{ 68, "It|de|It|es|It" },
		{ 69, "MOD_I|de|MOD_I|es|MOD_I" },
		{ 70, "ZERO_V|de|ZERO_V|es|ZERO_V" },
		{ 71, "P0676 Value|de|P0676 Wert|es|ContenidoP0676" }
		DEFAULT_VALUE 5;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0260
	}
}

COMMAND READ_P0260
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0260 }
	}
}

METHOD SET_PAR_NUMBER_0260
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 260;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0260 LIKE READ_P0260
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 4, P0260 }
		REPLY { }
	}
}

VARIABLE P0261
{
	LABEL "P0261 AO4 Gain        |de|P0261 AO4 Verstrkung|es|P0261 Ganancia Salida AO4";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{
		SCALING_FACTOR 0.001;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0261
	}
}

COMMAND READ_P0261
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0261 }
	}
}

METHOD SET_PAR_NUMBER_0261
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 261;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0261 LIKE READ_P0261
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 5, P0261 }
		REPLY { }
	}
}

VARIABLE P0262
{
	LABEL "P0262 AO4 Signal Type |de|P0262 AO4 Signaltyp|es|P0262 Seal Salida AO4  ";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "0 to 20 mA|de|0 bis 20 mA|es|0 a 20mA" },
		{ 1, "4 to 20 mA |de|4 bis 20 mA |es|4 a 20 mA " },
		{ 2, "20 to 0 mA|de|20 bis 0 mA|es|20mA a 0" },
		{ 3, "20 to 4 mA |de|20 bis 4 mA |es|20 a 4 mA " },
		{ 4, "0 to 10 V|de|0 bis 10 V|es|0 a 10 V" },
		{ 5, "10 to 0 V|de|10 bis 0 V|es|10 a 0 V" },
		{ 6, "-10 to +10V|de|-10 bis +10V|es|-10 a +10V" }
		DEFAULT_VALUE 4;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0262
	}
}

COMMAND READ_P0262
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0262 }
	}
}

METHOD SET_PAR_NUMBER_0262
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 262;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0262 LIKE READ_P0262
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 6, P0262 }
		REPLY { }
	}
}

VARIABLE P0263
{
	LABEL "P0263 DI1 Function    |de|P0263 DI1 Funktion|es|P0263 Funcin Entrada DI1  ";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "Not Used  |de|Ohne Funktion|es|Sin Funcin " },
		{ 1, "Run/Stop  |de|Start / Stop|es|Gira/Para " },
		{ 2, "General Enable|de|Freigabe|es|Hab. General" },
		{ 3, "Fast Stop |de|Schnellstop|es|Parada Rpida" },
		{ 4, "FWD Run   |de|Rechtslauf|es|Avance    " },
		{ 5, "REV Run   |de|Linkslauf|es|Retroceso " },
		{ 6, "3-Wire Start|de|Start|es|Start     " },
		{ 7, "3-Wire Stop |de|Stop|es|Stop      " },
		{ 8, "FWD/REV   |de|Drehrichtung|es|Sentido Giro " },
		{ 9, "LOC/REM   |de|LOC / REM|es|LOC/REM   " },
		{ 10, "JOG       |de|JOG|es|JOG       " },
		{ 11, "Increase EP|de|EP Beschleunig|es|Acelera EP" },
		{ 12, "Decrease EP|de|EP Bremsen |es|Desacelera EP" },
		{ 13, "Not Used  |de|Ohne Funktion|es|Sin Funcin " },
		{ 14, "Ramp 2    |de|2. Rampe|es|2a. Rampa  " },
		{ 15, "Speed/Torque|de|Drehz./Moment|es|Veloc./Torque" },
		{ 16, "JOG+|de|JOG+|es|JOG+    " },
		{ 17, "JOG-|de|JOG-|es|JOG-    " },
		{ 18, "No Ext. Alarm|de|Ohne ext. Ala.|es|Sin Alarma Ext" },
		{ 19, "No Ext. Fault|de|Ohne ext. Feh.|es|Sin Falla Ext." },
		{ 20, "Reset|de|Reset|es|Reset     " },
		{ 21, "PLC Use   |de|PLC Benutzung|es|Uso PLC   " },
		{ 22, "Manual/Auto|de|Manual / Autom|es|Manual/Autom." },
		{ 23, "Not Used  |de|Ohne Funktion|es|Sin Funcin " },
		{ 24, "Disab.FlyStart|de|FliegSt Sperre|es|Deshab. FS" },
		{ 25, "DC Link Regul.|de|ZwKrSpg Reg.|es|Regul. Bus CC" },
		{ 26, "Progr. Off|de|Programm Aus|es|Bloquea Prog." },
		{ 27, "Load User 1/2|de|Lade Ben. 1/2|es|Carga Us. 1/2" },
		{ 28, "Load User 3|de|Lade Benutz. 3|es|Carga Us. 3" },
		{ 29, "DO2 Timer|de|Timer DO2|es|Temporiz. DO2" },
		{ 30, "DO3 Timer|de|Timer DO3|es|Temporiz. DO3" },
		{ 31, "Trace Function|de|Trace-Funktion|es|Funcin Trace" }
		DEFAULT_VALUE 1;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0263
	}
}

COMMAND READ_P0263
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0263 }
	}
}

METHOD SET_PAR_NUMBER_0263
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 263;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0263 LIKE READ_P0263
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 7, P0263 }
		REPLY { }
	}
}

VARIABLE P0264
{
	LABEL "P0264 DI2 Function    |de|P0264 DI2 Funktion|es|P0264 Funcin Entrada DI2  ";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "Not Used  |de|Ohne Funktion|es|Sin Funcin " },
		{ 1, "Run/Stop  |de|Start / Stop|es|Gira/Para " },
		{ 2, "General Enable|de|Freigabe|es|Hab. General" },
		{ 3, "Fast Stop |de|Schnellstop|es|Parada Rpida" },
		{ 4, "FWD Run   |de|Rechtslauf|es|Avance    " },
		{ 5, "REV Run   |de|Linkslauf|es|Retroceso " },
		{ 6, "3-Wire Start|de|Start|es|Start     " },
		{ 7, "3-Wire Stop |de|Stop|es|Stop      " },
		{ 8, "FWD/REV   |de|Drehrichtung|es|Sentido Giro " },
		{ 9, "LOC/REM   |de|LOC / REM|es|LOC/REM   " },
		{ 10, "JOG       |de|JOG|es|JOG       " },
		{ 11, "Increase EP|de|EP Beschleunig|es|Acelera EP" },
		{ 12, "Decrease EP|de|EP Bremsen |es|Desacelera EP" },
		{ 13, "Not Used  |de|Ohne Funktion|es|Sin Funcin " },
		{ 14, "Ramp 2    |de|2. Rampe|es|2a. Rampa  " },
		{ 15, "Speed/Torque|de|Drehz./Moment|es|Veloc./Torque" },
		{ 16, "JOG+|de|JOG+|es|JOG+    " },
		{ 17, "JOG-|de|JOG-|es|JOG-    " },
		{ 18, "No Ext. Alarm|de|Ohne ext. Ala.|es|Sin Alarma Ext" },
		{ 19, "No Ext. Fault|de|Ohne ext. Feh.|es|Sin Falla Ext." },
		{ 20, "Reset|de|Reset|es|Reset     " },
		{ 21, "PLC Use   |de|PLC Benutzung|es|Uso PLC   " },
		{ 22, "Manual/Auto|de|Manual / Autom|es|Manual/Autom." },
		{ 23, "Not Used  |de|Ohne Funktion|es|Sin Funcin " },
		{ 24, "Disab.FlyStart|de|FliegSt Sperre|es|Deshab. FS" },
		{ 25, "DC Link Regul.|de|ZwKrSpg Reg.|es|Regul. Bus CC" },
		{ 26, "Progr. Off|de|Programm Aus|es|Bloquea Prog." },
		{ 27, "Load User 1/2|de|Lade Ben. 1/2|es|Carga Us. 1/2" },
		{ 28, "Load User 3|de|Lade Benutz. 3|es|Carga Us. 3" },
		{ 29, "DO2 Timer|de|Timer DO2|es|Temporiz. DO2" },
		{ 30, "DO3 Timer|de|Timer DO3|es|Temporiz. DO3" },
		{ 31, "Trace Function|de|Trace-Funktion|es|Funcin Trace" }
		DEFAULT_VALUE 8;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0264
	}
}

COMMAND READ_P0264
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0264 }
	}
}

METHOD SET_PAR_NUMBER_0264
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 264;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0264 LIKE READ_P0264
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 8, P0264 }
		REPLY { }
	}
}

VARIABLE P0265
{
	LABEL "P0265 DI3 Function    |de|P0265 DI3 Funktion|es|P0265 Funcin Entrada DI3  ";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "Not Used  |de|Ohne Funktion|es|Sin Funcin " },
		{ 1, "Run/Stop  |de|Start / Stop|es|Gira/Para " },
		{ 2, "General Enable|de|Freigabe|es|Hab. General" },
		{ 3, "Fast Stop |de|Schnellstop|es|Parada Rpida" },
		{ 4, "FWD Run   |de|Rechtslauf|es|Avance    " },
		{ 5, "REV Run   |de|Linkslauf|es|Retroceso " },
		{ 6, "3-Wire Start|de|Start|es|Start     " },
		{ 7, "3-Wire Stop |de|Stop|es|Stop      " },
		{ 8, "FWD/REV   |de|Drehrichtung|es|Sentido Giro " },
		{ 9, "LOC/REM   |de|LOC / REM|es|LOC/REM   " },
		{ 10, "JOG       |de|JOG|es|JOG       " },
		{ 11, "Increase EP|de|EP Beschleunig|es|Acelera EP" },
		{ 12, "Decrease EP|de|EP Bremsen |es|Desacelera EP" },
		{ 13, "Not Used  |de|Ohne Funktion|es|Sin Funcin " },
		{ 14, "Ramp 2    |de|2. Rampe|es|2a. Rampa  " },
		{ 15, "Speed/Torque|de|Drehz./Moment|es|Veloc./Torque" },
		{ 16, "JOG+|de|JOG+|es|JOG+    " },
		{ 17, "JOG-|de|JOG-|es|JOG-    " },
		{ 18, "No Ext. Alarm|de|Ohne ext. Ala.|es|Sin Alarma Ext" },
		{ 19, "No Ext. Fault|de|Ohne ext. Feh.|es|Sin Falla Ext." },
		{ 20, "Reset|de|Reset|es|Reset     " },
		{ 21, "PLC Use   |de|PLC Benutzung|es|Uso PLC   " },
		{ 22, "Manual/Auto|de|Manual / Autom|es|Manual/Autom." },
		{ 23, "Not Used  |de|Ohne Funktion|es|Sin Funcin " },
		{ 24, "Disab.FlyStart|de|FliegSt Sperre|es|Deshab. FS" },
		{ 25, "DC Link Regul.|de|ZwKrSpg Reg.|es|Regul. Bus CC" },
		{ 26, "Progr. Off|de|Programm Aus|es|Bloquea Prog." },
		{ 27, "Load User 1/2|de|Lade Ben. 1/2|es|Carga Us. 1/2" },
		{ 28, "Load User 3|de|Lade Benutz. 3|es|Carga Us. 3" },
		{ 29, "DO2 Timer|de|Timer DO2|es|Temporiz. DO2" },
		{ 30, "DO3 Timer|de|Timer DO3|es|Temporiz. DO3" },
		{ 31, "Trace Function|de|Trace-Funktion|es|Funcin Trace" }
		DEFAULT_VALUE 0;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0265
	}
}

COMMAND READ_P0265
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0265 }
	}
}

METHOD SET_PAR_NUMBER_0265
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 265;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0265 LIKE READ_P0265
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 9, P0265 }
		REPLY { }
	}
}

VARIABLE P0266
{
	LABEL "P0266 DI4 Function    |de|P0266 DI4 Funktion|es|P0266 Funcin Entrada DI4  ";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "Not Used  |de|Ohne Funktion|es|Sin Funcin " },
		{ 1, "Run/Stop  |de|Start / Stop|es|Gira/Para " },
		{ 2, "General Enable|de|Freigabe|es|Hab. General" },
		{ 3, "Fast Stop |de|Schnellstop|es|Parada Rpida" },
		{ 4, "FWD Run   |de|Rechtslauf|es|Avance    " },
		{ 5, "REV Run   |de|Linkslauf|es|Retroceso " },
		{ 6, "3-Wire Start|de|Start|es|Start     " },
		{ 7, "3-Wire Stop |de|Stop|es|Stop      " },
		{ 8, "FWD/REV   |de|Drehrichtung|es|Sentido Giro " },
		{ 9, "LOC/REM   |de|LOC / REM|es|LOC/REM   " },
		{ 10, "JOG       |de|JOG|es|JOG       " },
		{ 11, "Increase EP|de|EP Beschleunig|es|Acelera EP" },
		{ 12, "Decrease EP|de|EP Bremsen |es|Desacelera EP" },
		{ 13, "Multispeed|de|Multispeed|es|Multispeed" },
		{ 14, "Ramp 2    |de|2. Rampe|es|2a. Rampa  " },
		{ 15, "Speed/Torque|de|Drehz./Moment|es|Veloc./Torque" },
		{ 16, "JOG+|de|JOG+|es|JOG+    " },
		{ 17, "JOG-|de|JOG-|es|JOG-    " },
		{ 18, "No Ext. Alarm|de|Ohne ext. Ala.|es|Sin Alarma Ext" },
		{ 19, "No Ext. Fault|de|Ohne ext. Feh.|es|Sin Falla Ext." },
		{ 20, "Reset|de|Reset|es|Reset     " },
		{ 21, "PLC Use   |de|PLC Benutzung|es|Uso PLC   " },
		{ 22, "Manual/Auto|de|Manual / Autom|es|Manual/Autom." },
		{ 23, "Not Used  |de|Ohne Funktion|es|Sin Funcin " },
		{ 24, "Disab.FlyStart|de|FliegSt Sperre|es|Deshab. FS" },
		{ 25, "DC Link Regul.|de|ZwKrSpg Reg.|es|Regul. Bus CC" },
		{ 26, "Progr. Off|de|Programm Aus|es|Bloquea Prog." },
		{ 27, "Load User 1/2|de|Lade Ben. 1/2|es|Carga Us. 1/2" },
		{ 28, "Load User 3|de|Lade Benutz. 3|es|Carga Us. 3" },
		{ 29, "DO2 Timer|de|Timer DO2|es|Temporiz. DO2" },
		{ 30, "DO3 Timer|de|Timer DO3|es|Temporiz. DO3" },
		{ 31, "Trace Function|de|Trace-Funktion|es|Funcin Trace" }
		DEFAULT_VALUE 0;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0266
	}
}

COMMAND READ_P0266
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0266 }
	}
}

METHOD SET_PAR_NUMBER_0266
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 266;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0266 LIKE READ_P0266
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 10, P0266 }
		REPLY { }
	}
}

VARIABLE P0267
{
	LABEL "P0267 DI5 Function    |de|P0267 DI5 Funktion|es|P0267 Funcin Entrada DI5  ";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "Not Used  |de|Ohne Funktion|es|Sin Funcin " },
		{ 1, "Run/Stop  |de|Start / Stop|es|Gira/Para " },
		{ 2, "General Enable|de|Freigabe|es|Hab. General" },
		{ 3, "Fast Stop |de|Schnellstop|es|Parada Rpida" },
		{ 4, "FWD Run   |de|Rechtslauf|es|Avance    " },
		{ 5, "REV Run   |de|Linkslauf|es|Retroceso " },
		{ 6, "3-Wire Start|de|Start|es|Start     " },
		{ 7, "3-Wire Stop |de|Stop|es|Stop      " },
		{ 8, "FWD/REV   |de|Drehrichtung|es|Sentido Giro " },
		{ 9, "LOC/REM   |de|LOC / REM|es|LOC/REM   " },
		{ 10, "JOG       |de|JOG|es|JOG       " },
		{ 11, "Increase EP|de|EP Beschleunig|es|Acelera EP" },
		{ 12, "Decrease EP|de|EP Bremsen |es|Desacelera EP" },
		{ 13, "Multispeed|de|Multispeed|es|Multispeed" },
		{ 14, "Ramp 2    |de|2. Rampe|es|2a. Rampa  " },
		{ 15, "Speed/Torque|de|Drehz./Moment|es|Veloc./Torque" },
		{ 16, "JOG+|de|JOG+|es|JOG+    " },
		{ 17, "JOG-|de|JOG-|es|JOG-    " },
		{ 18, "No Ext. Alarm|de|Ohne ext. Ala.|es|Sin Alarma Ext" },
		{ 19, "No Ext. Fault|de|Ohne ext. Feh.|es|Sin Falla Ext." },
		{ 20, "Reset|de|Reset|es|Reset     " },
		{ 21, "PLC Use   |de|PLC Benutzung|es|Uso PLC   " },
		{ 22, "Manual/Auto|de|Manual / Autom|es|Manual/Autom." },
		{ 23, "Not Used  |de|Ohne Funktion|es|Sin Funcin " },
		{ 24, "Disab.FlyStart|de|FliegSt Sperre|es|Deshab. FS" },
		{ 25, "DC Link Regul.|de|ZwKrSpg Reg.|es|Regul. Bus CC" },
		{ 26, "Progr. Off|de|Programm Aus|es|Bloquea Prog." },
		{ 27, "Load User 1/2|de|Lade Ben. 1/2|es|Carga Us. 1/2" },
		{ 28, "Load User 3|de|Lade Benutz. 3|es|Carga Us. 3" },
		{ 29, "DO2 Timer|de|Timer DO2|es|Temporiz. DO2" },
		{ 30, "DO3 Timer|de|Timer DO3|es|Temporiz. DO3" },
		{ 31, "Trace Function|de|Trace-Funktion|es|Funcin Trace" }
		DEFAULT_VALUE 10;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0267
	}
}

COMMAND READ_P0267
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0267 }
	}
}

METHOD SET_PAR_NUMBER_0267
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 267;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0267 LIKE READ_P0267
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 11, P0267 }
		REPLY { }
	}
}

VARIABLE P0268
{
	LABEL "P0268 DI6 Function    |de|P0268 DI6 Funktion|es|P0268 Funcin Entrada DI6 ";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "Not Used  |de|Ohne Funktion|es|Sin Funcin " },
		{ 1, "Run/Stop  |de|Start / Stop|es|Gira/Para " },
		{ 2, "General Enable|de|Freigabe|es|Hab. General" },
		{ 3, "Fast Stop |de|Schnellstop|es|Parada Rpida" },
		{ 4, "FWD Run   |de|Rechtslauf|es|Avance    " },
		{ 5, "REV Run   |de|Linkslauf|es|Retroceso " },
		{ 6, "3-Wire Start|de|Start|es|Start     " },
		{ 7, "3-Wire Stop |de|Stop|es|Stop      " },
		{ 8, "FWD/REV   |de|Drehrichtung|es|Sentido Giro " },
		{ 9, "LOC/REM   |de|LOC / REM|es|LOC/REM   " },
		{ 10, "JOG       |de|JOG|es|JOG       " },
		{ 11, "Increase EP|de|EP Beschleunig|es|Acelera EP" },
		{ 12, "Decrease EP|de|EP Bremsen |es|Desacelera EP" },
		{ 13, "Multispeed|de|Multispeed|es|Multispeed" },
		{ 14, "Ramp 2    |de|2. Rampe|es|2a. Rampa  " },
		{ 15, "Speed/Torque|de|Drehz./Moment|es|Veloc./Torque" },
		{ 16, "JOG+|de|JOG+|es|JOG+    " },
		{ 17, "JOG-|de|JOG-|es|JOG-    " },
		{ 18, "No Ext. Alarm|de|Ohne ext. Ala.|es|Sin Alarma Ext" },
		{ 19, "No Ext. Fault|de|Ohne ext. Feh.|es|Sin Falla Ext." },
		{ 20, "Reset|de|Reset|es|Reset     " },
		{ 21, "PLC Use   |de|PLC Benutzung|es|Uso PLC   " },
		{ 22, "Manual/Auto|de|Manual / Autom|es|Manual/Autom." },
		{ 23, "Not Used  |de|Ohne Funktion|es|Sin Funcin " },
		{ 24, "Disab.FlyStart|de|FliegSt Sperre|es|Deshab. FS" },
		{ 25, "DC Link Regul.|de|ZwKrSpg Reg.|es|Regul. Bus CC" },
		{ 26, "Progr. Off|de|Programm Aus|es|Bloquea Prog." },
		{ 27, "Load User 1/2|de|Lade Ben. 1/2|es|Carga Us. 1/2" },
		{ 28, "Load User 3|de|Lade Benutz. 3|es|Carga Us. 3" },
		{ 29, "DO2 Timer|de|Timer DO2|es|Temporiz. DO2" },
		{ 30, "DO3 Timer|de|Timer DO3|es|Temporiz. DO3" },
		{ 31, "Trace Function|de|Trace-Funktion|es|Funcin Trace" }
		DEFAULT_VALUE 14;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0268
	}
}

COMMAND READ_P0268
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0268 }
	}
}

METHOD SET_PAR_NUMBER_0268
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 268;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0268 LIKE READ_P0268
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 12, P0268 }
		REPLY { }
	}
}

VARIABLE P0269
{
	LABEL "P0269 DI7 Function    |de|P0269 DI7 Funktion|es|P0269 Funcin Entrada DI7  ";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "Not Used  |de|Ohne Funktion|es|Sin Funcin " },
		{ 1, "Run/Stop  |de|Start / Stop|es|Gira/Para " },
		{ 2, "General Enable|de|Freigabe|es|Hab. General" },
		{ 3, "Fast Stop |de|Schnellstop|es|Parada Rpida" },
		{ 4, "FWD Run   |de|Rechtslauf|es|Avance    " },
		{ 5, "REV Run   |de|Linkslauf|es|Retroceso " },
		{ 6, "3-Wire Start|de|Start|es|Start     " },
		{ 7, "3-Wire Stop |de|Stop|es|Stop      " },
		{ 8, "FWD/REV   |de|Drehrichtung|es|Sentido Giro " },
		{ 9, "LOC/REM   |de|LOC / REM|es|LOC/REM   " },
		{ 10, "JOG       |de|JOG|es|JOG       " },
		{ 11, "Increase EP|de|EP Beschleunig|es|Acelera EP" },
		{ 12, "Decrease EP|de|EP Bremsen |es|Desacelera EP" },
		{ 13, "Not Used  |de|Ohne Funktion|es|Sin Funcin " },
		{ 14, "Ramp 2    |de|2. Rampe|es|2a. Rampa  " },
		{ 15, "Speed/Torque|de|Drehz./Moment|es|Veloc./Torque" },
		{ 16, "JOG+|de|JOG+|es|JOG+    " },
		{ 17, "JOG-|de|JOG-|es|JOG-    " },
		{ 18, "No Ext. Alarm|de|Ohne ext. Ala.|es|Sin Alarma Ext" },
		{ 19, "No Ext. Fault|de|Ohne ext. Feh.|es|Sin Falla Ext." },
		{ 20, "Reset|de|Reset|es|Reset     " },
		{ 21, "PLC Use   |de|PLC Benutzung|es|Uso PLC   " },
		{ 22, "Manual/Auto|de|Manual / Autom|es|Manual/Autom." },
		{ 23, "Not Used  |de|Ohne Funktion|es|Sin Funcin " },
		{ 24, "Disab.FlyStart|de|FliegSt Sperre|es|Deshab. FS" },
		{ 25, "DC Link Regul.|de|ZwKrSpg Reg.|es|Regul. Bus CC" },
		{ 26, "Progr. Off|de|Programm Aus|es|Bloquea Prog." },
		{ 27, "Load User 1/2|de|Lade Ben. 1/2|es|Carga Us. 1/2" },
		{ 28, "Load User 3|de|Lade Benutz. 3|es|Carga Us. 3" },
		{ 29, "DO2 Timer|de|Timer DO2|es|Temporiz. DO2" },
		{ 30, "DO3 Timer|de|Timer DO3|es|Temporiz. DO3" },
		{ 31, "Trace Function|de|Trace-Funktion|es|Funcin Trace" }
		DEFAULT_VALUE 0;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0269
	}
}

COMMAND READ_P0269
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0269 }
	}
}

METHOD SET_PAR_NUMBER_0269
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 269;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0269 LIKE READ_P0269
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 13, P0269 }
		REPLY { }
	}
}

VARIABLE P0270
{
	LABEL "P0270 DI8 Function    |de|P0270 DI8 Funktion|es|P0270 Funcin Entrada DI8  ";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "Not Used  |de|Ohne Funktion|es|Sin Funcin " },
		{ 1, "Run/Stop  |de|Start / Stop|es|Gira/Para " },
		{ 2, "General Enable|de|Freigabe|es|Hab. General" },
		{ 3, "Fast Stop |de|Schnellstop|es|Parada Rpida" },
		{ 4, "FWD Run   |de|Rechtslauf|es|Avance    " },
		{ 5, "REV Run   |de|Linkslauf|es|Retroceso " },
		{ 6, "3-Wire Start|de|Start|es|Start     " },
		{ 7, "3-Wire Stop |de|Stop|es|Stop      " },
		{ 8, "FWD/REV   |de|Drehrichtung|es|Sentido Giro " },
		{ 9, "LOC/REM   |de|LOC / REM|es|LOC/REM   " },
		{ 10, "JOG       |de|JOG|es|JOG       " },
		{ 11, "Increase EP|de|EP Beschleunig|es|Acelera EP" },
		{ 12, "Decrease EP|de|EP Bremsen |es|Desacelera EP" },
		{ 13, "Not Used  |de|Ohne Funktion|es|Sin Funcin " },
		{ 14, "Ramp 2    |de|2. Rampe|es|2a. Rampa  " },
		{ 15, "Speed/Torque|de|Drehz./Moment|es|Veloc./Torque" },
		{ 16, "JOG+|de|JOG+|es|JOG+    " },
		{ 17, "JOG-|de|JOG-|es|JOG-    " },
		{ 18, "No Ext. Alarm|de|Ohne ext. Ala.|es|Sin Alarma Ext" },
		{ 19, "No Ext. Fault|de|Ohne ext. Feh.|es|Sin Falla Ext." },
		{ 20, "Reset|de|Reset|es|Reset     " },
		{ 21, "PLC Use   |de|PLC Benutzung|es|Uso PLC   " },
		{ 22, "Manual/Auto|de|Manual / Autom|es|Manual/Autom." },
		{ 23, "Not Used  |de|Ohne Funktion|es|Sin Funcin " },
		{ 24, "Disab.FlyStart|de|FliegSt Sperre|es|Deshab. FS" },
		{ 25, "DC Link Regul.|de|ZwKrSpg Reg.|es|Regul. Bus CC" },
		{ 26, "Progr. Off|de|Programm Aus|es|Bloquea Prog." },
		{ 27, "Load User 1/2|de|Lade Ben. 1/2|es|Carga Us. 1/2" },
		{ 28, "Load User 3|de|Lade Benutz. 3|es|Carga Us. 3" },
		{ 29, "DO2 Timer|de|Timer DO2|es|Temporiz. DO2" },
		{ 30, "DO3 Timer|de|Timer DO3|es|Temporiz. DO3" },
		{ 31, "Trace Function|de|Trace-Funktion|es|Funcin Trace" }
		DEFAULT_VALUE 0;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0270
	}
}

COMMAND READ_P0270
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0270 }
	}
}

METHOD SET_PAR_NUMBER_0270
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 270;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0270 LIKE READ_P0270
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 14, P0270 }
		REPLY { }
	}
}

VARIABLE P0273
{
	LABEL "P0273 Iq Filter|de|P0273 Iq Filter       |es|P0273 Filtro Iq";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{
		SCALING_FACTOR 0.01;
	}
	CONSTANT_UNIT "s";
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0273
	}
}

COMMAND READ_P0273
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0273 }
	}
}

METHOD SET_PAR_NUMBER_0273
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 273;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0273 LIKE READ_P0273
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 17, P0273 }
		REPLY { }
	}
}

VARIABLE P0274
{
	LABEL "P0274 Iq DOx Hysteresis|de|P0274 Iq DOx   Hysteresis|es|P0274 Histerese DOx Iq";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{
		SCALING_FACTOR 0.01;
	}
	CONSTANT_UNIT "%";
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0274
	}
}

COMMAND READ_P0274
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0274 }
	}
}

METHOD SET_PAR_NUMBER_0274
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 274;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0274 LIKE READ_P0274
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 18, P0274 }
		REPLY { }
	}
}

VARIABLE P0275
{
	LABEL "P0275 DO1 Function (RL1)|de|P0275 DO1 Funktion (RL1)|es|P0275 Funcin de DO1 (RL1)";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "Not Used  |de|Ohne Funktion|es|Sin Funcin " },
		{ 1, "N* > Nx   |de|N* > Nx|es|N* > Nx   " },
		{ 2, "N > Nx    |de|N > Nx|es|N > Nx    " },
		{ 3, "N < Ny    |de|N < Ny|es|N < Ny    " },
		{ 4, "N = N*    |de|N = N*|es|N = N*    " },
		{ 5, "Zero Speed|de|Stillstand|es|Veloc. Nula" },
		{ 6, "Is > Ix   |de|Is > Ix|es|Is > Ix   " },
		{ 7, "Is < Ix   |de|Is < Ix|es|Is < Ix   " },
		{ 8, "Torque > Tx |de|Moment > Mx|es|Torque > Tx " },
		{ 9, "Torque < Tx |de|Moment < Mx|es|Torque < Tx " },
		{ 10, "Remote    |de|REM|es|Remoto    " },
		{ 11, "Run       |de|Ein|es|Run       " },
		{ 12, "Ready     |de|Bereit|es|Ready     " },
		{ 13, "No Fault  |de|Ohne Fehler|es|Sin Falla " },
		{ 14, "No F070    |de|Ohne F070|es|Sin F070   " },
		{ 15, "No F071    |de|Ohne F071|es|Sin F071  " },
		{ 16, "No F006/21/22|de|OhneF006/21/22|es|Sin F006/21/22" },
		{ 17, "No F051/54/57|de|OhneF051/54/57|es|Sin F051/54/57" },
		{ 18, "No F072    |de|Ohne F072|es|Sin F072   " },
		{ 19, "4-20mA OK|de|4-20mA OK|es|4-20mA OK" },
		{ 20, "P0695 Value|de|P0695 Wert|es|ContenidoP0695" },
		{ 21, "Forward   |de|Rechtslauf|es|Sent. Horario" },
		{ 22, "Proc. V. > PVx|de|ProzVar>Pr.Vx|es|V. Proc. > VPx" },
		{ 23, "Proc. V. < PVy|de|ProzVar<Pr.Vy|es|V. Proc. < VPy" },
		{ 24, "Ride-Through|de|Durchlauf  |es|Ride-Through" },
		{ 25, "Pre-Charge OK |de|Vorladen OK |es|Precarga OK" },
		{ 26, "Fault|de|Mit Fehler|es|Con Falla" },
		{ 27, "Time Enab > Hx|de|Betriebsstd>Hx|es|Horas Hab > Hx" },
		{ 28, "SoftPLC|de|SoftPLC|es|SoftPLC" },
		{ 29, "Not Used  |de|Ohne Funktion|es|Sin Funcin " },
		{ 30, "N>Nx and Nt>Nx|de|N>Nx und Nt>Nx|es|N>Nx y Nt>Nx" },
		{ 31, "F > Fx (1)   |de|F > Fx (1)   |es|F > Fx (1)   " },
		{ 32, "F > Fx (2)   |de|F > Fx (2)   |es|F > Fx (2)   " },
		{ 33, "STO|de|STO|es|STO" },
		{ 34, "No F160    |de|Ohne F160|es|Sin F160   " },
		{ 35, "No Alarm|de|Ohne Alarm|es|Sin Alarma" },
		{ 36, "No Fault/Alarm|de|OhneFehler/Ala|es|SinFalla/Alarm" },
		{ 37, "PLC11|de|PLC11|es|PLC11" },
		{ 38, "No Fault IOE|de|Ohne FehlerIOE|es|Sin Falla IOE" },
		{ 39, "No Alarm IOE|de|Ohne Alarm IOE|es|Sin Alarma IOE" },
		{ 40, "No Cable IOE|de|Ohne Kabel IOE|es|Sin AlCableIOE" },
		{ 41, "No A/Cable IOE|de|Ohne A/Kab IOE|es|Sin A/CableIOE" },
		{ 42, "No F/Cable IOE|de|Ohne F/Kab IOE|es|Sin F/CableIOE" },
		{ 43, "Torque +/-|de|Mmt +/- |es|Torque +/-" },
		{ 44, "Torque -/+|de|Mmt -/+ |es|Torque -/+" }
		DEFAULT_VALUE 13;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0275
	}
}

COMMAND READ_P0275
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0275 }
	}
}

METHOD SET_PAR_NUMBER_0275
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 275;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0275 LIKE READ_P0275
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 19, P0275 }
		REPLY { }
	}
}

VARIABLE P0276
{
	LABEL "P0276 DO2 Function (RL2)|de|P0276 DO2 Funktion (RL2)|es|P0276 Funcin de DO2 (RL2)";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "Not Used  |de|Ohne Funktion|es|Sin Funcin " },
		{ 1, "N* > Nx   |de|N* > Nx|es|N* > Nx   " },
		{ 2, "N > Nx    |de|N > Nx|es|N > Nx    " },
		{ 3, "N < Ny    |de|N < Ny|es|N < Ny    " },
		{ 4, "N = N*    |de|N = N*|es|N = N*    " },
		{ 5, "Zero Speed|de|Stillstand|es|Veloc. Nula" },
		{ 6, "Is > Ix   |de|Is > Ix|es|Is > Ix   " },
		{ 7, "Is < Ix   |de|Is < Ix|es|Is < Ix   " },
		{ 8, "Torque > Tx |de|Moment > Mx|es|Torque > Tx " },
		{ 9, "Torque < Tx |de|Moment < Mx|es|Torque < Tx " },
		{ 10, "Remote    |de|REM|es|Remoto    " },
		{ 11, "Run       |de|Ein|es|Run       " },
		{ 12, "Ready     |de|Bereit|es|Ready     " },
		{ 13, "No Fault  |de|Ohne Fehler|es|Sin Falla " },
		{ 14, "No F070    |de|Ohne F070|es|Sin F070   " },
		{ 15, "No F071    |de|Ohne F071|es|Sin F071  " },
		{ 16, "No F006/21/22|de|OhneF006/21/22|es|Sin F006/21/22" },
		{ 17, "No F051/54/57|de|OhneF051/54/57|es|Sin F051/54/57" },
		{ 18, "No F072    |de|Ohne F072|es|Sin F072   " },
		{ 19, "4-20mA OK|de|4-20mA OK|es|4-20mA OK" },
		{ 20, "P0695 Value|de|P0695 Wert|es|ContenidoP0695" },
		{ 21, "Forward   |de|Rechtslauf|es|Sent. Horario" },
		{ 22, "Proc. V. > PVx|de|ProzVar>Pr.Vx|es|V. Proc. > VPx" },
		{ 23, "Proc. V. < PVy|de|ProzVar<Pr.Vy|es|V. Proc. < VPy" },
		{ 24, "Ride-Through|de|Durchlauf  |es|Ride-Through" },
		{ 25, "Pre-Charge OK |de|Vorladen OK |es|Precarga OK" },
		{ 26, "Fault|de|Mit Fehler|es|Con Falla" },
		{ 27, "Time Enab > Hx|de|Betriebsstd>Hx|es|Horas Hab > Hx" },
		{ 28, "SoftPLC|de|SoftPLC|es|SoftPLC" },
		{ 29, "Timer|de|Timer|es|Temporizador" },
		{ 30, "N>Nx and Nt>Nx|de|N>Nx und Nt>Nx|es|N>Nx y Nt>Nx" },
		{ 31, "F > Fx (1)   |de|F > Fx (1)   |es|F > Fx (1)   " },
		{ 32, "F > Fx (2)   |de|F > Fx (2)   |es|F > Fx (2)   " },
		{ 33, "STO|de|STO|es|STO" },
		{ 34, "No F160    |de|Ohne F160|es|Sin F160   " },
		{ 35, "No Alarm|de|Ohne Alarm|es|Sin Alarma" },
		{ 36, "No Fault/Alarm|de|OhneFehler/Ala|es|SinFalla/Alarm" },
		{ 37, "PLC11|de|PLC11|es|PLC11" },
		{ 38, "No Fault IOE|de|Ohne FehlerIOE|es|Sin Falla IOE" },
		{ 39, "No Alarm IOE|de|Ohne Alarm IOE|es|Sin Alarma IOE" },
		{ 40, "No Cable IOE|de|Ohne Kabel IOE|es|Sin AlCableIOE" },
		{ 41, "No A/Cable IOE|de|Ohne A/Kab IOE|es|Sin A/CableIOE" },
		{ 42, "No F/Cable IOE|de|Ohne F/Kab IOE|es|Sin F/CableIOE" },
		{ 43, "Torque +/-|de|Mmt +/- |es|Torque +/-" },
		{ 44, "Torque -/+|de|Mmt -/+ |es|Torque -/+" }
		DEFAULT_VALUE 2;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0276
	}
}

COMMAND READ_P0276
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0276 }
	}
}

METHOD SET_PAR_NUMBER_0276
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 276;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0276 LIKE READ_P0276
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 20, P0276 }
		REPLY { }
	}
}

VARIABLE P0277
{
	LABEL "P0277 DO3 Function (RL3)|de|P0277 DO3 Funktion (RL3)|es|P0277 Funcin de DO3 (RL3)";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "Not Used  |de|Ohne Funktion|es|Sin Funcin " },
		{ 1, "N* > Nx   |de|N* > Nx|es|N* > Nx   " },
		{ 2, "N > Nx    |de|N > Nx|es|N > Nx    " },
		{ 3, "N < Ny    |de|N < Ny|es|N < Ny    " },
		{ 4, "N = N*    |de|N = N*|es|N = N*    " },
		{ 5, "Zero Speed|de|Stillstand|es|Veloc. Nula" },
		{ 6, "Is > Ix   |de|Is > Ix|es|Is > Ix   " },
		{ 7, "Is < Ix   |de|Is < Ix|es|Is < Ix   " },
		{ 8, "Torque > Tx |de|Moment > Mx|es|Torque > Tx " },
		{ 9, "Torque < Tx |de|Moment < Mx|es|Torque < Tx " },
		{ 10, "Remote    |de|REM|es|Remoto    " },
		{ 11, "Run       |de|Ein|es|Run       " },
		{ 12, "Ready     |de|Bereit|es|Ready     " },
		{ 13, "No Fault  |de|Ohne Fehler|es|Sin Falla " },
		{ 14, "No F070    |de|Ohne F070|es|Sin F070   " },
		{ 15, "No F071    |de|Ohne F071|es|Sin F071  " },
		{ 16, "No F006/21/22|de|OhneF006/21/22|es|Sin F006/21/22" },
		{ 17, "No F051/54/57|de|OhneF051/54/57|es|Sin F051/54/57" },
		{ 18, "No F072    |de|Ohne F072|es|Sin F072   " },
		{ 19, "4-20mA OK|de|4-20mA OK|es|4-20mA OK" },
		{ 20, "P0695 Value|de|P0695 Wert|es|ContenidoP0695" },
		{ 21, "Forward   |de|Rechtslauf|es|Sent. Horario" },
		{ 22, "Proc. V. > PVx|de|ProzVar>Pr.Vx|es|V. Proc. > VPx" },
		{ 23, "Proc. V. < PVy|de|ProzVar<Pr.Vy|es|V. Proc. < VPy" },
		{ 24, "Ride-Through|de|Durchlauf  |es|Ride-Through" },
		{ 25, "Pre-Charge OK |de|Vorladen OK |es|Precarga OK" },
		{ 26, "Fault|de|Mit Fehler|es|Con Falla" },
		{ 27, "Time Enab > Hx|de|Betriebsstd>Hx|es|Horas Hab > Hx" },
		{ 28, "SoftPLC|de|SoftPLC|es|SoftPLC" },
		{ 29, "Timer|de|Timer|es|Temporizador" },
		{ 30, "N>Nx and Nt>Nx|de|N>Nx und Nt>Nx|es|N>Nx y Nt>Nx" },
		{ 31, "F > Fx (1)   |de|F > Fx (1)   |es|F > Fx (1)   " },
		{ 32, "F > Fx (2)   |de|F > Fx (2)   |es|F > Fx (2)   " },
		{ 33, "STO|de|STO|es|STO" },
		{ 34, "No F160    |de|Ohne F160|es|Sin F160   " },
		{ 35, "No Alarm|de|Ohne Alarm|es|Sin Alarma" },
		{ 36, "No Fault/Alarm|de|OhneFehler/Ala|es|SinFalla/Alarm" },
		{ 37, "PLC11|de|PLC11|es|PLC11" },
		{ 38, "No Fault IOE|de|Ohne FehlerIOE|es|Sin Falla IOE" },
		{ 39, "No Alarm IOE|de|Ohne Alarm IOE|es|Sin Alarma IOE" },
		{ 40, "No Cable IOE|de|Ohne Kabel IOE|es|Sin AlCableIOE" },
		{ 41, "No A/Cable IOE|de|Ohne A/Kab IOE|es|Sin A/CableIOE" },
		{ 42, "No F/Cable IOE|de|Ohne F/Kab IOE|es|Sin F/CableIOE" },
		{ 43, "Torque +/-|de|Mmt +/- |es|Torque +/-" },
		{ 44, "Torque -/+|de|Mmt -/+ |es|Torque -/+" }
		DEFAULT_VALUE 1;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0277
	}
}

COMMAND READ_P0277
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0277 }
	}
}

METHOD SET_PAR_NUMBER_0277
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 277;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0277 LIKE READ_P0277
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 21, P0277 }
		REPLY { }
	}
}

VARIABLE P0278
{
	LABEL "P0278 DO4 Function    |de|P0278 DO4 Funktion|es|P0278 Funcin de DO4";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "Not Used  |de|Ohne Funktion|es|Sin Funcin " },
		{ 1, "N* > Nx   |de|N* > Nx|es|N* > Nx   " },
		{ 2, "N > Nx    |de|N > Nx|es|N > Nx    " },
		{ 3, "N < Ny    |de|N < Ny|es|N < Ny    " },
		{ 4, "N = N*    |de|N = N*|es|N = N*    " },
		{ 5, "Zero Speed|de|Stillstand|es|Veloc. Nula" },
		{ 6, "Is > Ix   |de|Is > Ix|es|Is > Ix   " },
		{ 7, "Is < Ix   |de|Is < Ix|es|Is < Ix   " },
		{ 8, "Torque > Tx |de|Moment > Mx|es|Torque > Tx " },
		{ 9, "Torque < Tx |de|Moment < Mx|es|Torque < Tx " },
		{ 10, "Remote    |de|REM|es|Remoto    " },
		{ 11, "Run       |de|Ein|es|Run       " },
		{ 12, "Ready     |de|Bereit|es|Ready     " },
		{ 13, "No Fault  |de|Ohne Fehler|es|Sin Falla " },
		{ 14, "No F070    |de|Ohne F070|es|Sin F070   " },
		{ 15, "No F071    |de|Ohne F071|es|Sin F071  " },
		{ 16, "No F006/21/22|de|OhneF006/21/22|es|Sin F006/21/22" },
		{ 17, "No F051/54/57|de|OhneF051/54/57|es|Sin F051/54/57" },
		{ 18, "No F072    |de|Ohne F072|es|Sin F072   " },
		{ 19, "4-20mA OK|de|4-20mA OK|es|4-20mA OK" },
		{ 20, "P0695 Value|de|P0695 Wert|es|ContenidoP0695" },
		{ 21, "Forward   |de|Rechtslauf|es|Sent. Horario" },
		{ 22, "Proc. V. > PVx|de|ProzVar>Pr.Vx|es|V. Proc. > VPx" },
		{ 23, "Proc. V. < PVy|de|ProzVar<Pr.Vy|es|V. Proc. < VPy" },
		{ 24, "Ride-Through|de|Durchlauf  |es|Ride-Through" },
		{ 25, "Pre-Charge OK |de|Vorladen OK |es|Precarga OK" },
		{ 26, "Fault|de|Mit Fehler|es|Con Falla" },
		{ 27, "Time Enab > Hx|de|Betriebsstd>Hx|es|Horas Hab > Hx" },
		{ 28, "SoftPLC|de|SoftPLC|es|SoftPLC" },
		{ 29, "Not Used  |de|Ohne Funktion|es|Sin Funcin " },
		{ 30, "N>Nx and Nt>Nx|de|N>Nx und Nt>Nx|es|N>Nx y Nt>Nx" },
		{ 31, "F > Fx (1)   |de|F > Fx (1)   |es|F > Fx (1)   " },
		{ 32, "F > Fx (2)   |de|F > Fx (2)   |es|F > Fx (2)   " },
		{ 33, "STO|de|STO|es|STO" },
		{ 34, "No F160    |de|Ohne F160|es|Sin F160   " },
		{ 35, "No Alarm|de|Ohne Alarm|es|Sin Alarma" },
		{ 36, "No Fault/Alarm|de|OhneFehler/Ala|es|SinFalla/Alarm" },
		{ 37, "Not Used  |de|Ohne Funktion|es|Sin Funcin " },
		{ 38, "Not Used  |de|Ohne Funktion|es|Sin Funcin " },
		{ 39, "Not Used  |de|Ohne Funktion|es|Sin Funcin " },
		{ 40, "Not Used  |de|Ohne Funktion|es|Sin Funcin " },
		{ 41, "Not Used  |de|Ohne Funktion|es|Sin Funcin " },
		{ 42, "Not Used  |de|Ohne Funktion|es|Sin Funcin " },
		{ 43, "Torque +/-|de|Mmt +/- |es|Torque +/-" },
		{ 44, "Torque -/+|de|Mmt -/+ |es|Torque -/+" }
		DEFAULT_VALUE 0;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0278
	}
}

COMMAND READ_P0278
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0278 }
	}
}

METHOD SET_PAR_NUMBER_0278
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 278;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0278 LIKE READ_P0278
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 22, P0278 }
		REPLY { }
	}
}

VARIABLE P0279
{
	LABEL "P0279 DO5 Function    |de|P0279 DO5 Funktion|es|P0279 Funcin de DO5  ";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "Not Used  |de|Ohne Funktion|es|Sin Funcin " },
		{ 1, "N* > Nx   |de|N* > Nx|es|N* > Nx   " },
		{ 2, "N > Nx    |de|N > Nx|es|N > Nx    " },
		{ 3, "N < Ny    |de|N < Ny|es|N < Ny    " },
		{ 4, "N = N*    |de|N = N*|es|N = N*    " },
		{ 5, "Zero Speed|de|Stillstand|es|Veloc. Nula" },
		{ 6, "Is > Ix   |de|Is > Ix|es|Is > Ix   " },
		{ 7, "Is < Ix   |de|Is < Ix|es|Is < Ix   " },
		{ 8, "Torque > Tx |de|Moment > Mx|es|Torque > Tx " },
		{ 9, "Torque < Tx |de|Moment < Mx|es|Torque < Tx " },
		{ 10, "Remote    |de|REM|es|Remoto    " },
		{ 11, "Run       |de|Ein|es|Run       " },
		{ 12, "Ready     |de|Bereit|es|Ready     " },
		{ 13, "No Fault  |de|Ohne Fehler|es|Sin Falla " },
		{ 14, "No F070    |de|Ohne F070|es|Sin F070   " },
		{ 15, "No F071    |de|Ohne F071|es|Sin F071  " },
		{ 16, "No F006/21/22|de|OhneF006/21/22|es|Sin F006/21/22" },
		{ 17, "No F051/54/57|de|OhneF051/54/57|es|Sin F051/54/57" },
		{ 18, "No F072    |de|Ohne F072|es|Sin F072   " },
		{ 19, "4-20mA OK|de|4-20mA OK|es|4-20mA OK" },
		{ 20, "P0695 Value|de|P0695 Wert|es|ContenidoP0695" },
		{ 21, "Forward   |de|Rechtslauf|es|Sent. Horario" },
		{ 22, "Proc. V. > PVx|de|ProzVar>Pr.Vx|es|V. Proc. > VPx" },
		{ 23, "Proc. V. < PVy|de|ProzVar<Pr.Vy|es|V. Proc. < VPy" },
		{ 24, "Ride-Through|de|Durchlauf  |es|Ride-Through" },
		{ 25, "Pre-Charge OK |de|Vorladen OK |es|Precarga OK" },
		{ 26, "Fault|de|Mit Fehler|es|Con Falla" },
		{ 27, "Time Enab > Hx|de|Betriebsstd>Hx|es|Horas Hab > Hx" },
		{ 28, "SoftPLC|de|SoftPLC|es|SoftPLC" },
		{ 29, "Not Used  |de|Ohne Funktion|es|Sin Funcin " },
		{ 30, "N>Nx and Nt>Nx|de|N>Nx und Nt>Nx|es|N>Nx y Nt>Nx" },
		{ 31, "F > Fx (1)   |de|F > Fx (1)   |es|F > Fx (1)   " },
		{ 32, "F > Fx (2)   |de|F > Fx (2)   |es|F > Fx (2)   " },
		{ 33, "STO|de|STO|es|STO" },
		{ 34, "No F160    |de|Ohne F160|es|Sin F160   " },
		{ 35, "No Alarm|de|Ohne Alarm|es|Sin Alarma" },
		{ 36, "No Fault/Alarm|de|OhneFehler/Ala|es|SinFalla/Alarm" },
		{ 37, "Not Used  |de|Ohne Funktion|es|Sin Funcin " },
		{ 38, "Not Used  |de|Ohne Funktion|es|Sin Funcin " },
		{ 39, "Not Used  |de|Ohne Funktion|es|Sin Funcin " },
		{ 40, "Not Used  |de|Ohne Funktion|es|Sin Funcin " },
		{ 41, "Not Used  |de|Ohne Funktion|es|Sin Funcin " },
		{ 42, "Not Used  |de|Ohne Funktion|es|Sin Funcin " },
		{ 43, "Torque +/-|de|Mmt +/- |es|Torque +/-" },
		{ 44, "Torque -/+|de|Mmt -/+ |es|Torque -/+" }
		DEFAULT_VALUE 0;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0279
	}
}

COMMAND READ_P0279
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0279 }
	}
}

METHOD SET_PAR_NUMBER_0279
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 279;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0279 LIKE READ_P0279
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 23, P0279 }
		REPLY { }
	}
}

VARIABLE P0281
{
	LABEL "P0281 Fx Frequency |de|P0281 Frequenz Fx|es|P0281 Frecuencia Fx";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{
		SCALING_FACTOR 0.1;
	}
	CONSTANT_UNIT "Hz";
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0281
	}
}

COMMAND READ_P0281
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0281 }
	}
}

METHOD SET_PAR_NUMBER_0281
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 281;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0281 LIKE READ_P0281
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 25, P0281 }
		REPLY { }
	}
}

VARIABLE P0282
{
	LABEL "P0282 Fx Hysteresis|de|P0282 Fx Hysterese|es|P0282 Histresis Fx";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{
		SCALING_FACTOR 0.1;
	}
	CONSTANT_UNIT "Hz";
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0282
	}
}

COMMAND READ_P0282
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0282 }
	}
}

METHOD SET_PAR_NUMBER_0282
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 282;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0282 LIKE READ_P0282
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 26, P0282 }
		REPLY { }
	}
}

VARIABLE P0283
{
	LABEL "P0283 DO2 ON Time|de|P0283 DO2 Ein Zeit|es|P0283 Tiempo DO2 ON";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{
		SCALING_FACTOR 0.1;
	}
	CONSTANT_UNIT "s";
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0283
	}
}

COMMAND READ_P0283
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0283 }
	}
}

METHOD SET_PAR_NUMBER_0283
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 283;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0283 LIKE READ_P0283
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 27, P0283 }
		REPLY { }
	}
}

VARIABLE P0284
{
	LABEL "P0284 DO2 OFF Time|de|P0284 DO2 Aus Zeit|es|P0284 Tiempo DO2 OFF";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{
		SCALING_FACTOR 0.1;
	}
	CONSTANT_UNIT "s";
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0284
	}
}

COMMAND READ_P0284
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0284 }
	}
}

METHOD SET_PAR_NUMBER_0284
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 284;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0284 LIKE READ_P0284
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 28, P0284 }
		REPLY { }
	}
}

VARIABLE P0285
{
	LABEL "P0285 DO3 ON Time|de|P0285 DO3 Ein Zeit|es|P0285 Tiempo DO3 ON";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{
		SCALING_FACTOR 0.1;
	}
	CONSTANT_UNIT "s";
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0285
	}
}

COMMAND READ_P0285
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0285 }
	}
}

METHOD SET_PAR_NUMBER_0285
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 285;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0285 LIKE READ_P0285
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 29, P0285 }
		REPLY { }
	}
}

VARIABLE P0286
{
	LABEL "P0286 DO3 OFF Time|de|P0286 DO3 Aus Zeit|es|P0286 Tiempo DO3 OFF";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{
		SCALING_FACTOR 0.1;
	}
	CONSTANT_UNIT "s";
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0286
	}
}

COMMAND READ_P0286
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0286 }
	}
}

METHOD SET_PAR_NUMBER_0286
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 286;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0286 LIKE READ_P0286
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 30, P0286 }
		REPLY { }
	}
}

VARIABLE P0287
{
	LABEL "P0287 Nx/Ny Hysteresis|de|P0287 Nx / Ny Hysterese|es|P0287 Histresis Nx/Ny";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 18;
		MIN_VALUE 0;
		MAX_VALUE 900;
	}
	CONSTANT_UNIT "rpm";
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0287
	}
}

COMMAND READ_P0287
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0287 }
	}
}

METHOD SET_PAR_NUMBER_0287
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 287;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0287 LIKE READ_P0287
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 31, P0287 }
		REPLY { }
	}
}

VARIABLE P0288
{
	LABEL "P0288 Nx Speed        |de|P0288 Drehzahl Nx|es|P0288 Velocidad Nx    ";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 120;
		MIN_VALUE 0;
		MAX_VALUE 18000;
	}
	CONSTANT_UNIT "rpm";
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0288
	}
}

COMMAND READ_P0288
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0288 }
	}
}

METHOD SET_PAR_NUMBER_0288
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 288;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0288 LIKE READ_P0288
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 32, P0288 }
		REPLY { }
	}
}

VARIABLE P0289
{
	LABEL "P0289 Ny Speed        |de|P0289 Drehzahl Ny|es|P0289 Velocidad Ny    ";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 1800;
		MIN_VALUE 0;
		MAX_VALUE 18000;
	}
	CONSTANT_UNIT "rpm";
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0289
	}
}

COMMAND READ_P0289
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0289 }
	}
}

METHOD SET_PAR_NUMBER_0289
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 289;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0289 LIKE READ_P0289
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 33, P0289 }
		REPLY { }
	}
}

VARIABLE P0290
{
	LABEL "P0290 Ix Current      |de|P0290 Strom Ix|es|P0290 Corriente Ix    ";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{
		SCALING_FACTOR 0.1;
	}
	CONSTANT_UNIT "A";
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0290
	}
}

COMMAND READ_P0290
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0290 }
	}
}

METHOD SET_PAR_NUMBER_0290
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 290;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0290 LIKE READ_P0290
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 34, P0290 }
		REPLY { }
	}
}

VARIABLE P0291
{
	LABEL "P0291 Zero Speed Zone |de|P0291 Stillstand|es|P0291 Velocidad Nula  ";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 18;
		MIN_VALUE 0;
		MAX_VALUE 18000;
	}
	CONSTANT_UNIT "rpm";
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0291
	}
}

COMMAND READ_P0291
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0291 }
	}
}

METHOD SET_PAR_NUMBER_0291
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 291;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0291 LIKE READ_P0291
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 35, P0291 }
		REPLY { }
	}
}

VARIABLE P0292
{
	LABEL "P0292 N = N* Band       |de|P0292 N = N* Bereich|es|P0292 Rango para N = N* ";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 18;
		MIN_VALUE 0;
		MAX_VALUE 18000;
	}
	CONSTANT_UNIT "rpm";
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0292
	}
}

COMMAND READ_P0292
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0292 }
	}
}

METHOD SET_PAR_NUMBER_0292
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 292;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0292 LIKE READ_P0292
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 36, P0292 }
		REPLY { }
	}
}

VARIABLE P0293
{
	LABEL "P0293 Tx Torque       |de|P0293 Moment Tx|es|P0293 Torque Tx       ";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 100;
		MIN_VALUE 0;
		MAX_VALUE 200;
	}
	CONSTANT_UNIT "%";
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0293
	}
}

COMMAND READ_P0293
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0293 }
	}
}

METHOD SET_PAR_NUMBER_0293
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 293;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0293 LIKE READ_P0293
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 37, P0293 }
		REPLY { }
	}
}

VARIABLE P0294
{
	LABEL "P0294 Hx Time|de|P0294 Hx Stunden|es|P0294 Horas Hx";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 4320;
		MIN_VALUE 0;
		MAX_VALUE 6553;
	}
	CONSTANT_UNIT "h";
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0294
	}
}

COMMAND READ_P0294
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0294 }
	}
}

METHOD SET_PAR_NUMBER_0294
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 294;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0294 LIKE READ_P0294
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 38, P0294 }
		REPLY { }
	}
}

VARIABLE P0295
{
	LABEL "P0295 ND/HD VFD Rated Curr.|de|P0295 FU Nennstrom ND/HD|es|P0295 Corr.Nomin.ND/HD Conv";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE ENUMERATED(2)
	{
		{ 0, "3.6A / 3.6A|de|3.6A / 3.6A|es|3.6A / 3.6A" },
		{ 1, "5A / 5A|de|5A / 5A|es|5A / 5A" },
		{ 2, "6A / 5A|de|6A / 5A|es|6A / 5A" },
		{ 3, "7A / 5.5A|de|7A / 5.5A|es|7A / 5.5A" },
		{ 4, "7A / 7A|de|7A / 7A|es|7A / 7A" },
		{ 5, "10A / 8A|de|10A / 8A|es|10A / 8A" },
		{ 6, "10A / 10A|de|10A / 10A|es|10A / 10A" },
		{ 7, "13A / 11A|de|13A / 11A|es|13A / 11A" },
		{ 8, "13.5A / 11A|de|13.5A / 11A|es|13.5A / 11A" },
		{ 9, "16A / 13A|de|16A / 13A|es|16A / 13A" },
		{ 10, "17A / 13.5A|de|17A / 13.5A|es|17A / 13.5A" },
		{ 11, "24A / 19A|de|24A / 19A|es|24A / 19A" },
		{ 12, "24A / 20A|de|24A / 20A|es|24A / 20A" },
		{ 13, "28A / 24A|de|28A / 24A|es|28A / 24A" },
		{ 14, "31A / 25A|de|31A / 25A|es|31A / 25A" },
		{ 15, "33.5A / 28A|de|33.5A / 28A|es|33.5A / 28A" },
		{ 16, "38A / 33A|de|38A / 33A|es|38A / 33A" },
		{ 17, "45A / 36A|de|45A / 36A|es|45A / 36A" },
		{ 18, "45A / 38A|de|45A / 38A|es|45A / 38A" },
		{ 19, "54A / 45A|de|54A / 45A|es|54A / 45A" },
		{ 20, "58.5A / 47A|de|58.5A / 47A|es|58.5A / 47A" },
		{ 21, "70A / 56A|de|70A / 56A|es|70A / 56A" },
		{ 22, "70.5A / 61A|de|70.5A / 61A|es|70.5A / 61A" },
		{ 23, "86A / 70A|de|86A / 70A|es|86A / 70A" },
		{ 24, "88A / 73A|de|88A / 73A|es|88A / 73A" },
		{ 25, "105A / 86A|de|105A / 86A|es|105A / 86A" },
		{ 26, "427A / 340A|de|427A / 340A|es|427A / 340A" },
		{ 27, "470A / 380A|de|470A / 380A|es|470A / 380A" },
		{ 28, "811A / 646A|de|811A / 646A|es|811A / 646A" },
		{ 29, "893A / 722A|de|893A / 722A|es|893A / 722A" },
		{ 30, "1217A / 969A|de|1217A / 969A|es|1217A / 969A" },
		{ 31, "1340A / 1083A|de|1340A / 1083A|es|1340A / 1083A" },
		{ 32, "1622A / 1292A|de|1622A / 1292A|es|1622A / 1292A" },
		{ 33, "1786A / 1444A|de|1786A / 1444A|es|1786A / 1444A" },
		{ 34, "2028A / 1615A|de|2028A / 1615A|es|2028A / 1615A" },
		{ 35, "2232A / 1805A|de|2232A / 1805A|es|2232A / 1805A" },
		{ 36, "2A / 2A|de|2A / 2A|es|2A / 2A" },
		{ 37, "640A / 515A|de|640A / 515A|es|640A / 515A" },
		{ 38, "1216A / 979A|de|1216A / 979A|es|1216A / 979A" },
		{ 39, "1824A / 1468A|de|1824A / 1468A|es|1824A / 1468A" },
		{ 40, "2432A / 1957A|de|2432A / 1957A|es|2432A / 1957A" },
		{ 41, "3040A / 2446A|de|3040A / 2446A|es|3040A / 2446A" },
		{ 42, "600A / 515A|de|600A / 515A|es|600A / 515A" },
		{ 43, "1140A / 979A|de|1140A / 979A|es|1140A / 979A" },
		{ 44, "1710A / 1468A|de|1710A / 1468A|es|1710A / 1468A" },
		{ 45, "2280A / 1957A|de|2280A / 1957A|es|2280A / 1957A" },
		{ 46, "2850A / 2446A|de|2850A / 2446A|es|2850A / 2446A" },
		{ 47, "105A / 88A|de|105A / 88A|es|105A / 88A" },
		{ 48, "142A / 115A|de|142A / 115A|es|142A / 115A" },
		{ 49, "180A / 142A|de|180A / 142A|es|180A / 142A" },
		{ 50, "211A / 180A|de|211A / 180A|es|211A / 180A" },
		{ 51, "242A / 211A|de|242A / 211A|es|242A / 211A" },
		{ 52, "312A / 242A|de|312A / 242A|es|312A / 242A" },
		{ 53, "370A / 312A|de|370A / 312A|es|370A / 312A" },
		{ 54, "477A / 370A|de|477A / 370A|es|477A / 370A" },
		{ 55, "515A / 477A|de|515A / 477A|es|515A / 477A" },
		{ 56, "601A / 515A|de|601A / 515A|es|601A / 515A" },
		{ 57, "720A / 560A|de|720A / 560A|es|720A / 560A" },
		{ 58, "2.9A / 2.7A|de|2.9A / 2.7A|es|2.9A / 2.7A" },
		{ 59, "4.2A / 3.8A|de|4.2A / 3.8A|es|4.2A / 3.8A" },
		{ 60, "7A / 6.5A|de|7A / 6.5A|es|7A / 6.5A" },
		{ 61, "8.5A / 7A|de|8.5A / 7A|es|8.5A / 7A" },
		{ 62, "10A / 9A|de|10A / 9A|es|10A / 9A" },
		{ 63, "11A / 9A|de|11A / 9A|es|11A / 9A" },
		{ 64, "12A / 10A|de|12A / 10A|es|12A / 10A" },
		{ 65, "15A / 13A|de|15A / 13A|es|15A / 13A" },
		{ 66, "17A / 17A|de|17A / 17A|es|17A / 17A" },
		{ 67, "20A / 17A|de|20A / 17A|es|20A / 17A" },
		{ 68, "22A / 19A|de|22A / 19A|es|22A / 19A" },
		{ 69, "24A / 21A|de|24A / 21A|es|24A / 21A" },
		{ 70, "27A / 22A|de|27A / 22A|es|27A / 22A" },
		{ 71, "30A / 24A|de|30A / 24A|es|30A / 24A" },
		{ 72, "32A / 27A|de|32A / 27A|es|32A / 27A" },
		{ 73, "35A / 30A|de|35A / 30A|es|35A / 30A" },
		{ 74, "44A / 36A|de|44A / 36A|es|44A / 36A" },
		{ 75, "46A / 39A|de|46A / 39A|es|46A / 39A" },
		{ 76, "53A / 44A|de|53A / 44A|es|53A / 44A" },
		{ 77, "54A / 46A|de|54A / 46A|es|54A / 46A" },
		{ 78, "63A / 53A|de|63A / 53A|es|63A / 53A" },
		{ 79, "73A / 61A|de|73A / 61A|es|73A / 61A" },
		{ 80, "80A / 66A|de|80A / 66A|es|80A / 66A" },
		{ 81, "100A / 85A|de|100A / 85A|es|100A / 85A" },
		{ 82, "107A / 90A|de|107A / 90A|es|107A / 90A" },
		{ 83, "108A / 95A|de|108A / 95A|es|108A / 95A" },
		{ 84, "125A / 107A|de|125A / 107A|es|125A / 107A" },
		{ 85, "130A / 108A|de|130A / 108A|es|130A / 108A" },
		{ 86, "150A / 122A|de|150A / 122A|es|150A / 122A" },
		{ 87, "147A / 127A|de|147A / 127A|es|147A / 127A" },
		{ 88, "170A / 150A|de|170A / 150A|es|170A / 150A" },
		{ 89, "195A / 165A|de|195A / 165A|es|195A / 165A" },
		{ 90, "216A / 180A|de|216A / 180A|es|216A / 180A" },
		{ 91, "289A / 240A|de|289A / 240A|es|289A / 240A" },
		{ 92, "259A / 225A|de|259A / 225A|es|259A / 225A" },
		{ 93, "315A / 289A|de|315A / 289A|es|315A / 289A" },
		{ 94, "312A / 259A|de|312A / 259A|es|312A / 259A" },
		{ 95, "365A / 315A|de|365A / 315A|es|365A / 315A" },
		{ 96, "365A / 312A|de|365A / 312A|es|365A / 312A" },
		{ 97, "435A / 357A|de|435A / 357A|es|435A / 357A" },
		{ 98, "427A / 365A|de|427A / 365A|es|427A / 365A" },
		{ 99, "472A / 418A|de|472A / 418A|es|472A / 418A" },
		{ 100, "700A / 515A|de|700A / 515A|es|700A / 515A" },
		{ 101, "1330A / 979A|de|1330A / 979A|es|1330A / 979A" },
		{ 102, "1995A / 1468A|de|1995A / 1468A|es|1995A / 1468A" },
		{ 103, "2660A / 1957A|de|2660A / 1957A|es|2660A / 1957A" },
		{ 104, "3325A / 2446A|de|3325A / 2446A|es|3325A / 2446A" },
		{ 105, "760A / 600A|de|760A / 600A|es|760A / 600A" },
		{ 106, "760A / 560A|de|760A / 560A|es|760A / 560A" },
		{ 107, "226A / 180A|de|226A / 180A|es|226A / 180A" }
		DEFAULT_VALUE 2;
	}
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0295
	}
}

COMMAND READ_P0295
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0295 }
	}
}

METHOD SET_PAR_NUMBER_0295
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 295;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0296
{
	LABEL "P0296 Line Rated Voltage |de|P0296 FU Nennspannung|es|P0296 Tensin Nominal Red";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "200 - 240 V |de|200 - 240 V |es|200 - 240 V " },
		{ 1, "380 V|de|380 V|es|380 V" },
		{ 2, "400 - 415 V |de|400 - 415 V |es|400 - 415 V " },
		{ 3, "440 - 460 V|de|440 - 460 V|es|440 - 460 V" },
		{ 4, "480 V|de|480 V|es|480 V" },
		{ 5, "500 - 525 V |de|500 - 525 V |es|500 - 525 V " },
		{ 6, "550 - 575 V |de|550 - 575 V |es|550 - 575 V " },
		{ 7, "600 V |de|600 V |es|600 V " },
		{ 8, "660 - 690 V |de|660 - 690 V |es|660 - 690 V " }
		DEFAULT_VALUE 3;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0296
	}
}

COMMAND READ_P0296
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0296 }
	}
}

METHOD SET_PAR_NUMBER_0296
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 296;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0296 LIKE READ_P0296
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 40, P0296 }
		REPLY { }
	}
}

VARIABLE P0297
{
	LABEL "P0297 Switching Frequency|de|P0297 Taktfrequenz|es|P0297 Frec. Conmutacin";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, " 1.25 kHz |de| 1.25 kHz |es| 1.25 kHz " },
		{ 1, " 2.5 kHz  |de| 2.5 kHz  |es| 2.5 kHz  " },
		{ 2, " 5.0 kHz  |de| 5.0 kHz  |es| 5.0 kHz  " },
		{ 3, "10.0 kHz  |de|10.0 kHz  |es|10.0 kHz  " },
		{ 4, " 2.0 kHz|de| 2.0 kHz|es| 2.0 kHz" }
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0297
	}
}

COMMAND READ_P0297
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0297 }
	}
}

METHOD SET_PAR_NUMBER_0297
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 297;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0297 LIKE READ_P0297
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 41, P0297 }
		REPLY { }
	}
}

VARIABLE P0298
{
	LABEL "P0298 Application|de|P0298 Anwendung|es|P0298 Aplicacin";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "Normal Duty|de|Normal Duty|es|Normal Duty" },
		{ 1, "Heavy Duty|de|Heavy Duty|es|Heavy Duty" }
		DEFAULT_VALUE 0;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0298
	}
}

COMMAND READ_P0298
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0298 }
	}
}

METHOD SET_PAR_NUMBER_0298
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 298;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0298 LIKE READ_P0298
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 42, P0298 }
		REPLY { }
	}
}

VARIABLE P0299
{
	LABEL "P0299 DC-Braking Start Time|de|P0299 Bremszeit Start|es|P0299 Tiempo Fren. Partida ";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{
		SCALING_FACTOR 0.1;
	}
	CONSTANT_UNIT "s";
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0299
	}
}

COMMAND READ_P0299
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0299 }
	}
}

METHOD SET_PAR_NUMBER_0299
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 299;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0299 LIKE READ_P0299
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 43, P0299 }
		REPLY { }
	}
}

VARIABLE P0300
{
	LABEL "P0300 DC-Braking Stop Time|de|P0300 Bremszeit Stop|es|P0300 Tiempo Fren. Parada ";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{
		SCALING_FACTOR 0.1;
	}
	CONSTANT_UNIT "s";
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0300
	}
}

COMMAND READ_P0300
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0300 }
	}
}

METHOD SET_PAR_NUMBER_0300
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 300;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0300 LIKE READ_P0300
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 44, P0300 }
		REPLY { }
	}
}

VARIABLE P0301
{
	LABEL "P0301 DC-Braking Speed  |de|P0301 Bremsdrehzahl|es|P0301 Velocidad de Inicio";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 30;
		MIN_VALUE 0;
		MAX_VALUE 450;
	}
	CONSTANT_UNIT "rpm";
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0301
	}
}

COMMAND READ_P0301
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0301 }
	}
}

METHOD SET_PAR_NUMBER_0301
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 301;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0301 LIKE READ_P0301
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 45, P0301 }
		REPLY { }
	}
}

VARIABLE P0302
{
	LABEL "P0302 DC-Braking Voltage|de|P0302 Bremsspannung|es|P0302 Tensin CC Frenado";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{
		SCALING_FACTOR 0.1;
	}
	CONSTANT_UNIT "%";
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0302
	}
}

COMMAND READ_P0302
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0302 }
	}
}

METHOD SET_PAR_NUMBER_0302
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 302;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0302 LIKE READ_P0302
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 46, P0302 }
		REPLY { }
	}
}

VARIABLE P0303
{
	LABEL "P0303 Skip Speed 1    |de|P0303 1.berspr.Drehzahl|es|P0303 Velocidad Rechazada 1";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 600;
		MIN_VALUE 0;
		MAX_VALUE 18000;
	}
	CONSTANT_UNIT "rpm";
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0303
	}
}

COMMAND READ_P0303
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0303 }
	}
}

METHOD SET_PAR_NUMBER_0303
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 303;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0303 LIKE READ_P0303
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 47, P0303 }
		REPLY { }
	}
}

VARIABLE P0304
{
	LABEL "P0304 Skip Speed 2    |de|P0304 2.berspr.Drehzahl|es|P0304 Velocidad Rechazada 2";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 900;
		MIN_VALUE 0;
		MAX_VALUE 18000;
	}
	CONSTANT_UNIT "rpm";
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0304
	}
}

COMMAND READ_P0304
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0304 }
	}
}

METHOD SET_PAR_NUMBER_0304
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 304;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0304 LIKE READ_P0304
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 48, P0304 }
		REPLY { }
	}
}

VARIABLE P0305
{
	LABEL "P0305 Skip Speed 3    |de|P0305 3.berspr.Drehzahl|es|P0305 Velocidad Rechazada 3";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 1200;
		MIN_VALUE 0;
		MAX_VALUE 18000;
	}
	CONSTANT_UNIT "rpm";
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0305
	}
}

COMMAND READ_P0305
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0305 }
	}
}

METHOD SET_PAR_NUMBER_0305
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 305;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0305 LIKE READ_P0305
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 49, P0305 }
		REPLY { }
	}
}

VARIABLE P0306
{
	LABEL "P0306 Skip Band       |de|P0306 bersprung Bereich|es|P0306 Rango Rechazado ";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 750;
	}
	CONSTANT_UNIT "rpm";
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0306
	}
}

COMMAND READ_P0306
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0306 }
	}
}

METHOD SET_PAR_NUMBER_0306
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 306;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0306 LIKE READ_P0306
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 50, P0306 }
		REPLY { }
	}
}

VARIABLE P0308
{
	LABEL "P0308 Serial Address     |de|P0308 Serielle Adresse|es|P0308 Direccin Serie";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 1;
		MIN_VALUE 1;
		MAX_VALUE 247;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0308
	}
}

COMMAND READ_P0308
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0308 }
	}
}

METHOD SET_PAR_NUMBER_0308
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 308;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0308 LIKE READ_P0308
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 52, P0308 }
		REPLY { }
	}
}

VARIABLE P0310
{
	LABEL "P0310 Serial Baud Rate|de|P0310 Seriella Baud Rate|es|P0310 Tasa Comunic. Serie";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "9600 bits/s|de|9600 bits/s|es|9600 bits/s" },
		{ 1, "19200 bits/s|de|19200 bits/s|es|19200 bits/s" },
		{ 2, "38400 bits/s|de|38400 bits/s|es|38400 bits/s" },
		{ 3, "57600 bits/s|de|57600 bits/s|es|57600 bits/s" }
		DEFAULT_VALUE 0;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0310
	}
}

COMMAND READ_P0310
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0310 }
	}
}

METHOD SET_PAR_NUMBER_0310
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 310;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0310 LIKE READ_P0310
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 54, P0310 }
		REPLY { }
	}
}

VARIABLE P0311
{
	LABEL "P0311 Serial Bytes Config.|de|P0311 Serielle Byte Konfig.|es|P0311 Config. Bytes Serie";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "8 bits, no, 1|de|8 bits/ohne/1|es|8 bits, sin, 1" },
		{ 1, "8 bits, even,1|de|8 bits/gerad/1|es|8 bits, par, 1" },
		{ 2, "8 bits, odd, 1|de|8 bits/ung./1|es|8 bits, imp, 1" },
		{ 3, "8 bits, no, 2|de|8 bits/ohne/2|es|8 bits, sin, 2" },
		{ 4, "8 bits, even,2|de|8 bits/gerad/2|es|8 bits, par, 2" },
		{ 5, "8 bits, odd, 2|de|8 bits/ung./2|es|8 bits, imp, 2" }
		DEFAULT_VALUE 3;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0311
	}
}

COMMAND READ_P0311
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0311 }
	}
}

METHOD SET_PAR_NUMBER_0311
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 311;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0311 LIKE READ_P0311
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 55, P0311 }
		REPLY { }
	}
}

VARIABLE P0312
{
	LABEL "P0312 Serial Protocol|de|P0312 Serielles Protokoll|es|P0312 Protocolo Serie";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 1, "TP|de|TP|es|TP" },
		{ 2, "Modbus RTU|de|Modbus RTU|es|Modbus RTU" }
		DEFAULT_VALUE 2;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0312
	}
}

COMMAND READ_P0312
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0312 }
	}
}

METHOD SET_PAR_NUMBER_0312
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 312;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0312 LIKE READ_P0312
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 56, P0312 }
		REPLY { }
	}
}

VARIABLE P0313
{
	LABEL "P0313 Comm. Error Action|de|P0313 Kom. Fehler Aktion|es|P0313 Accin p/Erro Comunic";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "Off|de|Aus|es|Inactivo" },
		{ 1, "Ramp Stop|de|Rampenstop|es|Para por Rampa" },
		{ 2, "General Disab.|de|Gen. Abschalt.|es|Deshab.General" },
		{ 3, "Go to LOC|de|Gehe zu LOC|es|Ir p/ LOC" },
		{ 4, "LOC Keep Enab.|de|L bleibt Freig|es|LOC Mantie.Hab" },
		{ 5, "Cause Fault|de|Fehlerausls.|es|Causa Falla" }
		DEFAULT_VALUE 1;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0313
	}
}

COMMAND READ_P0313
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0313 }
	}
}

METHOD SET_PAR_NUMBER_0313
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 313;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0313 LIKE READ_P0313
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 57, P0313 }
		REPLY { }
	}
}

VARIABLE P0314
{
	LABEL "P0314 Serial Watchdog|de|P0314 Serieller-Watchdog|es|P0314 Watchdog Serie";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{
		SCALING_FACTOR 0.1;
	}
	CONSTANT_UNIT "s";
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0314
	}
}

COMMAND READ_P0314
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0314 }
	}
}

METHOD SET_PAR_NUMBER_0314
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 314;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0314 LIKE READ_P0314
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 58, P0314 }
		REPLY { }
	}
}

VARIABLE P0316
{
	LABEL "P0316 Serial Interf. Status|de|P0316 Schnittstellenstatus|es|P0316 Estado Interf. Serie";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE ENUMERATED(2)
	{
		{ 0, "Off|de|Aus|es|Inactivo" },
		{ 1, "On        |de|Ein|es|Activo" },
		{ 2, "Watchdog Error|de|Watchdog Feh.|es|Error Watchdog" }
		DEFAULT_VALUE 0;
	}
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0316
	}
}

COMMAND READ_P0316
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0316 }
	}
}

METHOD SET_PAR_NUMBER_0316
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 316;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0320
{
	LABEL "P0320 FlyStart/Ride-Through|de|P0320 FliegStart/Durchlauf|es|P0320 FlyStart/Ride-Through";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "Off       |de|Aus|es|Inactivas  " },
		{ 1, "Flying Start |de|Fliegend Start|es|Flying Start " },
		{ 2, "FS / RT   |de|FS / DL|es|FS / RT    " },
		{ 3, "Ride-Through |de|Durchlauf  |es|Ride-Through " }
		DEFAULT_VALUE 0;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0320
	}
}

COMMAND READ_P0320
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0320 }
	}
}

METHOD SET_PAR_NUMBER_0320
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 320;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0320 LIKE READ_P0320
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 64, P0320 }
		REPLY { }
	}
}

VARIABLE P0321
{
	LABEL "P0321 DC Link Power Loss|de|P0321 ZwKrSpg Abfallpegel|es|P0321 Ud Falta de Red";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{

	}
	CONSTANT_UNIT "V";
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0321
	}
}

COMMAND READ_P0321
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0321 }
	}
}

METHOD SET_PAR_NUMBER_0321
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 321;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0321 LIKE READ_P0321
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 65, P0321 }
		REPLY { }
	}
}

VARIABLE P0322
{
	LABEL "P0322 DC Link Ride-Through|de|P0322 ZwKrSpg Durchlauf|es|P0322 Ud Ride-Through";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{

	}
	CONSTANT_UNIT "V";
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0322
	}
}

COMMAND READ_P0322
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0322 }
	}
}

METHOD SET_PAR_NUMBER_0322
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 322;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0322 LIKE READ_P0322
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 66, P0322 }
		REPLY { }
	}
}

VARIABLE P0323
{
	LABEL "P0323 DC Link Power Back|de|P0323 ZwKrSpg Rckkehrp.|es|P0323 Ud Retorno Red";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{

	}
	CONSTANT_UNIT "V";
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0323
	}
}

COMMAND READ_P0323
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0323 }
	}
}

METHOD SET_PAR_NUMBER_0323
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 323;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0323 LIKE READ_P0323
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 67, P0323 }
		REPLY { }
	}
}

VARIABLE P0325
{
	LABEL "P0325 Ride-Through P Gain|de|P0325 Durchl. P-Verstrkung|es|P0325 Ganancia Prop. RT";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{
		SCALING_FACTOR 0.1;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0325
	}
}

COMMAND READ_P0325
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0325 }
	}
}

METHOD SET_PAR_NUMBER_0325
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 325;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0325 LIKE READ_P0325
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 69, P0325 }
		REPLY { }
	}
}

VARIABLE P0326
{
	LABEL "P0326 Ride-Through I Gain|de|P0326 Durchl. I-Verstrkung|es|P0326 Ganancia Integr. RT";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{
		SCALING_FACTOR 0.001;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0326
	}
}

COMMAND READ_P0326
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0326 }
	}
}

METHOD SET_PAR_NUMBER_0326
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 326;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0326 LIKE READ_P0326
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 70, P0326 }
		REPLY { }
	}
}

VARIABLE P0327
{
	LABEL "P0327 F.S. Current Ramp I/f|de|P0327 FS Stromrampe I/f|es|P0327 Rampa Corr. I/f F.S.";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{
		SCALING_FACTOR 0.001;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0327
	}
}

COMMAND READ_P0327
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0327 }
	}
}

METHOD SET_PAR_NUMBER_0327
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 327;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0327 LIKE READ_P0327
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 71, P0327 }
		REPLY { }
	}
}

VARIABLE P0328
{
	LABEL "P0328 Flying Start Filter|de|P0328 FS Filter|es|P0328 Filtro Flying Start";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{
		SCALING_FACTOR 0.001;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0328
	}
}

COMMAND READ_P0328
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0328 }
	}
}

METHOD SET_PAR_NUMBER_0328
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 328;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0328 LIKE READ_P0328
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 72, P0328 }
		REPLY { }
	}
}

VARIABLE P0329
{
	LABEL "P0329 Frequency Ramp F.S.|de|P0329 FS Frequenzrampe I/f|es|P0329 Rampa Frec. I/f F.S.";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{
		SCALING_FACTOR 0.1;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0329
	}
}

COMMAND READ_P0329
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0329 }
	}
}

METHOD SET_PAR_NUMBER_0329
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 329;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0329 LIKE READ_P0329
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 73, P0329 }
		REPLY { }
	}
}

VARIABLE P0331
{
	LABEL "P0331 Voltage Ramp|de|P0331 Spannungsrampe|es|P0331 Rampa de Tensin";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{
		SCALING_FACTOR 0.1;
	}
	CONSTANT_UNIT "s";
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0331
	}
}

COMMAND READ_P0331
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0331 }
	}
}

METHOD SET_PAR_NUMBER_0331
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 331;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0331 LIKE READ_P0331
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 75, P0331 }
		REPLY { }
	}
}

VARIABLE P0332
{
	LABEL "P0332 Dead Time|de|P0332 Totzeit|es|P0332 Tiempo Muerto";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{
		SCALING_FACTOR 0.1;
	}
	CONSTANT_UNIT "s";
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0332
	}
}

COMMAND READ_P0332
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0332 }
	}
}

METHOD SET_PAR_NUMBER_0332
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 332;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0332 LIKE READ_P0332
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 76, P0332 }
		REPLY { }
	}
}

VARIABLE P0340
{
	LABEL "P0340 Auto-Reset Time |de|P0340 Autoreset Zeit|es|P0340 Tiempo AutoReset";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 3600;
	}
	CONSTANT_UNIT "s";
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0340
	}
}

COMMAND READ_P0340
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0340 }
	}
}

METHOD SET_PAR_NUMBER_0340
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 340;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0340 LIKE READ_P0340
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 84, P0340 }
		REPLY { }
	}
}

VARIABLE P0342
{
	LABEL "P0342 Motor Unbal.Curr.Conf|de|P0342 Unsym.Motorstrom Konf|es|P0342 Conf.Corr.Deseq.Motor";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "Off       |de|Aus|es|Inactiva  " },
		{ 1, "On        |de|Ein|es|Activa    " }
		DEFAULT_VALUE 0;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0342
	}
}

COMMAND READ_P0342
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0342 }
	}
}

METHOD SET_PAR_NUMBER_0342
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 342;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0342 LIKE READ_P0342
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 86, P0342 }
		REPLY { }
	}
}

VARIABLE P0343
{
	LABEL "P0343 Ground Fault Config.|de|P0343 Erdfehler Konfig.|es|P0343 Config.Falla a Tierra";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "Off       |de|Aus|es|Inactiva  " },
		{ 1, "On        |de|Ein|es|Activa    " }
		DEFAULT_VALUE 1;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0343
	}
}

COMMAND READ_P0343
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0343 }
	}
}

METHOD SET_PAR_NUMBER_0343
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 343;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0343 LIKE READ_P0343
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 87, P0343 }
		REPLY { }
	}
}

VARIABLE P0344
{
	LABEL "P0344 Current Lim. Conf.|de|P0344 Strombegrenzung Kon.|es|P0344 Conf. Lim. Corriente";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "Hold - FL ON|de|Hold - SB ON|es|Hold - LR ON" },
		{ 1, "Decel. - FL ON|de|Brems. - SB ON|es|Desac. - LR ON" },
		{ 2, "Hold - FL OFF|de|Hold - SB OFF|es|Hold - LR OFF" },
		{ 3, "Decel.- FL OFF|de|Brems.- SB OFF|es|Desac.- LR OFF" }
		DEFAULT_VALUE 3;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0344
	}
}

COMMAND READ_P0344
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0344 }
	}
}

METHOD SET_PAR_NUMBER_0344
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 344;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0344 LIKE READ_P0344
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 88, P0344 }
		REPLY { }
	}
}

VARIABLE P0348
{
	LABEL "P0348 Motor Overload Conf.|de|P0348 Motorberlastkonfig.|es|P0348 Conf.Sobrecarga Motor";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "Off|de|Aus|es|Inactiva" },
		{ 1, "Fault/Alarm|de|Fehler / Alarm|es|Falla/Alarma" },
		{ 2, "Fault|de|Fehler|es|Falla" },
		{ 3, "Alarm|de|Alarm|es|Alarma" }
		DEFAULT_VALUE 1;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0348
	}
}

COMMAND READ_P0348
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0348 }
	}
}

METHOD SET_PAR_NUMBER_0348
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 348;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0348 LIKE READ_P0348
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 92, P0348 }
		REPLY { }
	}
}

VARIABLE P0349
{
	LABEL "P0349 Ixt Alarm Level|de|P0349 Niveau I x t Alarm|es|P0349 Nivel para Alarma Ixt";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 85;
		MIN_VALUE 70;
		MAX_VALUE 100;
	}
	CONSTANT_UNIT "%";
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0349
	}
}

COMMAND READ_P0349
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0349 }
	}
}

METHOD SET_PAR_NUMBER_0349
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 349;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0349 LIKE READ_P0349
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 93, P0349 }
		REPLY { }
	}
}

VARIABLE P0350
{
	LABEL "P0350 IGBTs Overload Conf.|de|P0350 IGBT berlast Konfig.|es|P0350 Conf.Sobrecarga IGBTs";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "F,   w/ SF rd.|de|F. mit red. SF|es|F   c/red. Fs" },
		{ 1, "F/A, w/ SF rd.|de|F/A m. red. SF|es|F/A c/red. Fs" },
		{ 2, "F,   no SF rd.|de|F ohne red. SF|es|F   s/red. Fs" },
		{ 3, "F/A, no SF rd.|de|F/A o. red. SF|es|F/A s/red. Fs" }
		DEFAULT_VALUE 1;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0350
	}
}

COMMAND READ_P0350
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0350 }
	}
}

METHOD SET_PAR_NUMBER_0350
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 350;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0350 LIKE READ_P0350
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 94, P0350 }
		REPLY { }
	}
}

VARIABLE P0351
{
	LABEL "P0351 Motor Overtemp. Conf.|de|P0351 Motorbertemperatur|es|P0351 Conf. Sobretemp.Motor";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "Off|de|Aus|es|Inactiva" },
		{ 1, "Fault/Alarm|de|Fehler / Alarm|es|Falla/Alarma" },
		{ 2, "Fault|de|Fehler|es|Falla" },
		{ 3, "Alarm|de|Alarm|es|Alarma" }
		DEFAULT_VALUE 1;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0351
	}
}

COMMAND READ_P0351
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0351 }
	}
}

METHOD SET_PAR_NUMBER_0351
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 351;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0351 LIKE READ_P0351
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 95, P0351 }
		REPLY { }
	}
}

VARIABLE P0352
{
	LABEL "P0352 Fan Control Config.|de|P0352 Lfter Konfiguration|es|P0352 Config. Ventiladores";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "HS-OFF,Int-OFF|de|K-AUS, In-AUS|es|VD-OFF,VI-OFF" },
		{ 1, "HS-ON,Int-ON|de|K-EIN, In-EIN|es|VD-ON,VI-ON" },
		{ 2, "HS-CT,Int-CT|de|K-Ges, In-Ges|es|VD-CT,VI-CT" },
		{ 3, "HS-CT,Int-OFF|de|K-Ges, In-AUS|es|VD-CT,VI-OFF" },
		{ 4, "HS-CT,Int-ON|de|K-Ges, In-EIN|es|VD-CT,VI-ON" },
		{ 5, "HS-ON,Int-OFF|de|K-EIN, In-AUS|es|VD-ON,VI-OFF" },
		{ 6, "HS-ON,Int-CT|de|K-EIN, In-Ges|es|VD-ON,VI-CT" },
		{ 7, "HS-OFF,Int-ON|de|K-AUS, In-EIN|es|VD-OFF,VI-ON" },
		{ 8, "HS-OFF,Int-CT|de|K-AUS, In-Ges|es|VD-OFF,VI-CT" },
		{ 9, "HS-CT,Int-CT *|de|K-Ges,In-Ges*|es|VD-CT,VI-CT *" },
		{ 10, "HS-CT,Int-OFF*|de|K-Ges,In-AUS*|es|VD-CT,VI-OFF*" },
		{ 11, "HS-CT,Int-ON *|de|K-Ges,In-EIN*|es|VD-CT,VI-ON *" },
		{ 12, "HS-ON,Int-CT *|de|K-EIN,In-Ges*|es|VD-ON,VI-CT *" },
		{ 13, "HS-OFF,Int-CT*|de|K-AUS,In-Ges*|es|VD-OFF,VI-CT*" }
		DEFAULT_VALUE 2;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0352
	}
}

COMMAND READ_P0352
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0352 }
	}
}

METHOD SET_PAR_NUMBER_0352
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 352;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0352 LIKE READ_P0352
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 96, P0352 }
		REPLY { }
	}
}

VARIABLE P0353
{
	LABEL "P0353 IGBTs/Air Overtmp.Cfg|de|P0353 bertemp. IGBTs/Luft|es|P0353 Cfg.Sobrtmp.IGBT/Aire";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "HS-F/A,Air-F/A|de|KK-F/A, Lu-F/A|es|D-F/A,Aire-F/A" },
		{ 1, "HS-F/A, Air-F|de|KK-F/A, Luft-F|es|D-F/A, Aire-F" },
		{ 2, "HS-F, Air-F/A|de|KK-F, Luft-F/A|es|D-F, Aire-F/A" },
		{ 3, "HS-F, Air-F|de|KK-F, Luft-F|es|D-F, Aire-F" },
		{ 4, "HS-F/A,A-F/A *|de|KK-F/A,Lu-F/A*|es|D-F/A,Ai-F/A *" },
		{ 5, "HS-F/A,Air-F *|de|KK-F/A,Luft-F*|es|D-F/A,Aire-F *" },
		{ 6, "HS-F,Air-F/A *|de|KK-F,Luft-F/A*|es|D-F,Aire-F/A *" },
		{ 7, "HS-F, Air-F  *|de|KK-F, Luft-F *|es|D-F, Aire-F  *" }
		DEFAULT_VALUE 0;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0353
	}
}

COMMAND READ_P0353
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0353 }
	}
}

METHOD SET_PAR_NUMBER_0353
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 353;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0353 LIKE READ_P0353
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 97, P0353 }
		REPLY { }
	}
}

VARIABLE P0354
{
	LABEL "P0354 Fan Speed Config.|de|P0354 Lftergeschw. Konfig.|es|P0354 Conf. Veloc. Ventil.";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "Alarm|de|Alarm|es|Alarma" },
		{ 1, "Fault|de|Fehler|es|Falla" }
		DEFAULT_VALUE 1;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0354
	}
}

COMMAND READ_P0354
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0354 }
	}
}

METHOD SET_PAR_NUMBER_0354
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 354;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0354 LIKE READ_P0354
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 98, P0354 }
		REPLY { }
	}
}

VARIABLE P0355
{
	LABEL "P0355 F185 Fault Config.|de|P0355 F185 Fehler Konfig.|es|P0355 Conf. Falla F185";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "Off|de|Aus|es|Inactiva" },
		{ 1, "On        |de|Ein|es|Activa" }
		DEFAULT_VALUE 1;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0355
	}
}

COMMAND READ_P0355
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0355 }
	}
}

METHOD SET_PAR_NUMBER_0355
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 355;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0355 LIKE READ_P0355
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 99, P0355 }
		REPLY { }
	}
}

VARIABLE P0356
{
	LABEL "P0356 Dead Time Compens.|de|P0356 Totzeit Kompensation|es|P0356 Compens.Tiempo Muerto";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "Off       |de|Aus|es|Inactiva  " },
		{ 1, "On        |de|Ein|es|Activa    " }
		DEFAULT_VALUE 1;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0356
	}
}

COMMAND READ_P0356
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0356 }
	}
}

METHOD SET_PAR_NUMBER_0356
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 356;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0356 LIKE READ_P0356
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 100, P0356 }
		REPLY { }
	}
}

VARIABLE P0357
{
	LABEL "P0357 Line Phase Loss Time|de|P0357 Zeit Phasenverlust|es|P0357 Tiempo Ausencia Fase";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 3;
		MIN_VALUE 0;
		MAX_VALUE 60;
	}
	CONSTANT_UNIT "s";
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0357
	}
}

COMMAND READ_P0357
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0357 }
	}
}

METHOD SET_PAR_NUMBER_0357
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 357;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0357 LIKE READ_P0357
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 101, P0357 }
		REPLY { }
	}
}

VARIABLE P0358
{
	LABEL "P0358 Encoder Fault Config.|de|P0358 Drehgeber Fehler Konf|es|P0358 Conf. Falla Encoder";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "Off|de|Aus|es|Inactivas  " },
		{ 1, "F67 ON|de|F67 EIN|es|F67 activa" },
		{ 2, "F65,F66 ON|de|F65,F66 EIN|es|F65,F66 activa" },
		{ 3, "All |de|Alle|es|Todas Activas" }
		DEFAULT_VALUE 3;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0358
	}
}

COMMAND READ_P0358
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0358 }
	}
}

METHOD SET_PAR_NUMBER_0358
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 358;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0358 LIKE READ_P0358
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 102, P0358 }
		REPLY { }
	}
}

VARIABLE P0359
{
	LABEL "P0359 Motor Current Stabil.|de|P0359 Motorstrom Stabil.|es|P0359 Estab.Corriente Motor";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "Off|de|Aus|es|Inactiva" },
		{ 1, "On        |de|Ein|es|Activa    " }
		DEFAULT_VALUE 0;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0359
	}
}

COMMAND READ_P0359
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0359 }
	}
}

METHOD SET_PAR_NUMBER_0359
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 359;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0359 LIKE READ_P0359
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 103, P0359 }
		REPLY { }
	}
}

VARIABLE P0372
{
	LABEL "P0372 DC-Braking Curr Sless|de|P0372 Bremsstrom Sensorless|es|P0372 Corr. Fren. CC Sless";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{
		SCALING_FACTOR 0.1;
	}
	CONSTANT_UNIT "%";
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0372
	}
}

COMMAND READ_P0372
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0372 }
	}
}

METHOD SET_PAR_NUMBER_0372
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 372;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0372 LIKE READ_P0372
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 116, P0372 }
		REPLY { }
	}
}

VARIABLE P0373
{
	LABEL "P0373 PTC1 Type Sensor|de|P0373 PTC1 Sensor Typ|es|P0373 Tipo de Sensor PTC1";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "PTC Simple|de|Einfach PTC|es|PTC Simple" },
		{ 1, "PTC Triple|de|Dreifach PTC|es|PTC Triple" }
		DEFAULT_VALUE 1;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0373
	}
}

COMMAND READ_P0373
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0373 }
	}
}

METHOD SET_PAR_NUMBER_0373
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 373;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0373 LIKE READ_P0373
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 117, P0373 }
		REPLY { }
	}
}

VARIABLE P0374
{
	LABEL "P0374 Sensor 1 F/A Conf.|de|P0374 Sensor 1 F/A Konf.|es|P0374 Conf. F/A Sensor 1";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "Off|de|Aus|es|Inactiva" },
		{ 1, "Fault/Al./Cab.|de|Fehler/Al./Kab|es|Falla/Al./Cabo" },
		{ 2, "Fault/Cable|de|Fehler/Kabel|es|Falla/Cabo" },
		{ 3, "Alarm/Cable|de|Alarm/Kabel|es|Alarma/Cabo" },
		{ 4, "Fault/Alarm|de|Fehler/Alarm|es|Falla/Alarma" },
		{ 5, "Fault|de|Fehler|es|Falla" },
		{ 6, "Alarm|de|Alarm|es|Alarma" },
		{ 7, "Alarm Cable|de|Kabel Alarm|es|Alarma Cabo" }
		DEFAULT_VALUE 1;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0374
	}
}

COMMAND READ_P0374
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0374 }
	}
}

METHOD SET_PAR_NUMBER_0374
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 374;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0374 LIKE READ_P0374
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 118, P0374 }
		REPLY { }
	}
}

VARIABLE P0375
{
	LABEL "P0375 Temper. F/A Sensor 1|de|P0375 Temper. F/A Sensor 1|es|P0375 Temper. F/A Sensor 1";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 130;
		MIN_VALUE -20;
		MAX_VALUE 200;
	}
	CONSTANT_UNIT "C";
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0375
	}
}

COMMAND READ_P0375
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0375 }
	}
}

METHOD SET_PAR_NUMBER_0375
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 375;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0375 LIKE READ_P0375
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 119, P0375 }
		REPLY { }
	}
}

VARIABLE P0376
{
	LABEL "P0376 PTC2 Type Sensor|de|P0376 PTC2 Sensor Typ|es|P0376 Tipo do Sensor PTC2";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "PTC Simple|de|Einfach PTC|es|PTC Simple" },
		{ 1, "PTC Triple|de|Dreifach PTC|es|PTC Triple" }
		DEFAULT_VALUE 1;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0376
	}
}

COMMAND READ_P0376
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0376 }
	}
}

METHOD SET_PAR_NUMBER_0376
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 376;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0376 LIKE READ_P0376
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 120, P0376 }
		REPLY { }
	}
}

VARIABLE P0377
{
	LABEL "P0377 Sensor 2 F/A Conf.|de|P0377 Sensor 2 F/A Konf.|es|P0377 Conf. F/A Sensor 2";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "Off|de|Aus|es|Inactiva" },
		{ 1, "Fault/Al./Cab.|de|Fehler/Al./Kab|es|Falla/Al./Cabo" },
		{ 2, "Fault/Cable|de|Fehler/Kabel|es|Falla/Cabo" },
		{ 3, "Alarm/Cable|de|Alarm/Kabel|es|Alarma/Cabo" },
		{ 4, "Fault/Alarm|de|Fehler/Alarm|es|Falla/Alarma" },
		{ 5, "Fault|de|Fehler|es|Falla" },
		{ 6, "Alarm|de|Alarm|es|Alarma" },
		{ 7, "Alarm Cable|de|Kabel Alarm|es|Alarma Cabo" }
		DEFAULT_VALUE 1;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0377
	}
}

COMMAND READ_P0377
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0377 }
	}
}

METHOD SET_PAR_NUMBER_0377
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 377;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0377 LIKE READ_P0377
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 121, P0377 }
		REPLY { }
	}
}

VARIABLE P0378
{
	LABEL "P0378 Temper. F/A Sensor 2|de|P0378 Temper. F/A Sensor 2|es|P0378 Temper. F/A Sensor 2";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 130;
		MIN_VALUE -20;
		MAX_VALUE 200;
	}
	CONSTANT_UNIT "C";
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0378
	}
}

COMMAND READ_P0378
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0378 }
	}
}

METHOD SET_PAR_NUMBER_0378
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 378;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0378 LIKE READ_P0378
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 122, P0378 }
		REPLY { }
	}
}

VARIABLE P0379
{
	LABEL "P0379 PTC3 Type Sensor|de|P0379 PTC3 Sensor Typ|es|P0379 Tipo do Sensor PTC3";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "PTC Simple|de|Einfach PTC|es|PTC Simple" },
		{ 1, "PTC Triple|de|Dreifach PTC|es|PTC Triple" }
		DEFAULT_VALUE 1;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0379
	}
}

COMMAND READ_P0379
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0379 }
	}
}

METHOD SET_PAR_NUMBER_0379
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 379;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0379 LIKE READ_P0379
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 123, P0379 }
		REPLY { }
	}
}

VARIABLE P0380
{
	LABEL "P0380 Sensor 3 F/A Conf.|de|P0380 Sensor 3 F/A Konf.|es|P0380 Conf. F/A Sensor 3";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "Off|de|Aus|es|Inactiva" },
		{ 1, "Fault/Al./Cab.|de|Fehler/Al./Kab|es|Falla/Al./Cabo" },
		{ 2, "Fault/Cable|de|Fehler/Kabel|es|Falla/Cabo" },
		{ 3, "Alarm/Cable|de|Alarm/Kabel|es|Alarma/Cabo" },
		{ 4, "Fault/Alarm|de|Fehler/Alarm|es|Falla/Alarma" },
		{ 5, "Fault|de|Fehler|es|Falla" },
		{ 6, "Alarm|de|Alarm|es|Alarma" },
		{ 7, "Alarm Cable|de|Kabel Alarm|es|Alarma Cabo" }
		DEFAULT_VALUE 1;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0380
	}
}

COMMAND READ_P0380
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0380 }
	}
}

METHOD SET_PAR_NUMBER_0380
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 380;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0380 LIKE READ_P0380
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 124, P0380 }
		REPLY { }
	}
}

VARIABLE P0381
{
	LABEL "P0381 Temper. F/A Sensor 3|de|P0381 Temper. F/A Sensor 3|es|P0381 Temper. F/A Sensor 3";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 130;
		MIN_VALUE -20;
		MAX_VALUE 200;
	}
	CONSTANT_UNIT "C";
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0381
	}
}

COMMAND READ_P0381
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0381 }
	}
}

METHOD SET_PAR_NUMBER_0381
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 381;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0381 LIKE READ_P0381
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 125, P0381 }
		REPLY { }
	}
}

VARIABLE P0382
{
	LABEL "P0382 PTC4 Type Sensor|de|P0382 PTC4 Sensor Typ|es|P0382 Tipo do Sensor PTC4";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "PTC Simple|de|Einfach PTC|es|PTC Simple" },
		{ 1, "PTC Triple|de|Dreifach PTC|es|PTC Triple" }
		DEFAULT_VALUE 1;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0382
	}
}

COMMAND READ_P0382
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0382 }
	}
}

METHOD SET_PAR_NUMBER_0382
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 382;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0382 LIKE READ_P0382
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 126, P0382 }
		REPLY { }
	}
}

VARIABLE P0383
{
	LABEL "P0383 Sensor 4 F/A Conf.|de|P0383 Sensor 4 F/A Konf.|es|P0383 Conf. F/A Sensor 4";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "Off|de|Aus|es|Inactiva" },
		{ 1, "Fault/Al./Cab.|de|Fehler/Al./Kab|es|Falla/Al./Cabo" },
		{ 2, "Fault/Cable|de|Fehler/Kabel|es|Falla/Cabo" },
		{ 3, "Alarm/Cable|de|Alarm/Kabel|es|Alarma/Cabo" },
		{ 4, "Fault/Alarm|de|Fehler/Alarm|es|Falla/Alarma" },
		{ 5, "Fault|de|Fehler|es|Falla" },
		{ 6, "Alarm|de|Alarm|es|Alarma" },
		{ 7, "Alarm Cable|de|Kabel Alarm|es|Alarma Cabo" }
		DEFAULT_VALUE 1;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0383
	}
}

COMMAND READ_P0383
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0383 }
	}
}

METHOD SET_PAR_NUMBER_0383
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 383;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0383 LIKE READ_P0383
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 127, P0383 }
		REPLY { }
	}
}

VARIABLE P0384
{
	LABEL "P0384 Temper. F/A Sensor 4|de|P0384 Temper. F/A Sensor 4|es|P0384 Temper. F/A Sensor 4";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 130;
		MIN_VALUE -20;
		MAX_VALUE 200;
	}
	CONSTANT_UNIT "C";
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0384
	}
}

COMMAND READ_P0384
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0384 }
	}
}

METHOD SET_PAR_NUMBER_0384
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 384;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0384 LIKE READ_P0384
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 128, P0384 }
		REPLY { }
	}
}

VARIABLE P0385
{
	LABEL "P0385 PTC5 Type Sensor|de|P0385 PTC5 Sensor Typ|es|P0385 Tipo do Sensor PTC5";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "PTC Simple|de|Einfach PTC|es|PTC Simple" },
		{ 1, "PTC Triple|de|Dreifach PTC|es|PTC Triple" }
		DEFAULT_VALUE 1;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0385
	}
}

COMMAND READ_P0385
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0385 }
	}
}

METHOD SET_PAR_NUMBER_0385
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 385;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0385 LIKE READ_P0385
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 129, P0385 }
		REPLY { }
	}
}

VARIABLE P0386
{
	LABEL "P0386 Sensor 5 F/A Conf.|de|P0386 Sensor 5 F/A Konf.|es|P0386 Conf. F/A Sensor 5";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "Off|de|Aus|es|Inactiva" },
		{ 1, "Fault/Al./Cab.|de|Fehler/Al./Kab|es|Falla/Al./Cabo" },
		{ 2, "Fault/Cable|de|Fehler/Kabel|es|Falla/Cabo" },
		{ 3, "Alarm/Cable|de|Alarm/Kabel|es|Alarma/Cabo" },
		{ 4, "Fault/Alarm|de|Fehler/Alarm|es|Falla/Alarma" },
		{ 5, "Fault|de|Fehler|es|Falla" },
		{ 6, "Alarm|de|Alarm|es|Alarma" },
		{ 7, "Alarm Cable|de|Kabel Alarm|es|Alarma Cabo" }
		DEFAULT_VALUE 1;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0386
	}
}

COMMAND READ_P0386
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0386 }
	}
}

METHOD SET_PAR_NUMBER_0386
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 386;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0386 LIKE READ_P0386
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 130, P0386 }
		REPLY { }
	}
}

VARIABLE P0387
{
	LABEL "P0387 Temper. F/A Sensor 5|de|P0387 Temper. F/A Sensor 5|es|P0387 Temper. F/A Sensor 5";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 130;
		MIN_VALUE -20;
		MAX_VALUE 200;
	}
	CONSTANT_UNIT "C";
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0387
	}
}

COMMAND READ_P0387
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0387 }
	}
}

METHOD SET_PAR_NUMBER_0387
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 387;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0387 LIKE READ_P0387
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 131, P0387 }
		REPLY { }
	}
}

VARIABLE P0388
{
	LABEL "P0388 Temperature Sensor 1 |de|P0388 Temperatur Sensor 1|es|P0388 Temperatura Sensor 1";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -20;
		MAX_VALUE 200;
	}
	CONSTANT_UNIT "C";
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0388
	}
}

COMMAND READ_P0388
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0388 }
	}
}

METHOD SET_PAR_NUMBER_0388
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 388;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0389
{
	LABEL "P0389 Temperature Sensor 2|de|P0389 Temperatur Sensor 2|es|P0389 Temperatura Sensor 2";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -20;
		MAX_VALUE 200;
	}
	CONSTANT_UNIT "C";
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0389
	}
}

COMMAND READ_P0389
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0389 }
	}
}

METHOD SET_PAR_NUMBER_0389
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 389;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0390
{
	LABEL "P0390 Temperature Sensor 3|de|P0390 Temperatur Sensor 3|es|P0390 Temperatura Sensor 3";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -20;
		MAX_VALUE 200;
	}
	CONSTANT_UNIT "C";
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0390
	}
}

COMMAND READ_P0390
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0390 }
	}
}

METHOD SET_PAR_NUMBER_0390
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 390;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0391
{
	LABEL "P0391 Temperature Sensor 4|de|P0391 Temperatur Sensor 4|es|P0391 Temperatura Sensor 4";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -20;
		MAX_VALUE 200;
	}
	CONSTANT_UNIT "C";
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0391
	}
}

COMMAND READ_P0391
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0391 }
	}
}

METHOD SET_PAR_NUMBER_0391
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 391;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0392
{
	LABEL "P0392 Temperature Sensor 5|de|P0392 Temperatur Sensor 5|es|P0392 Temperatura Sensor 5";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -20;
		MAX_VALUE 200;
	}
	CONSTANT_UNIT "C";
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0392
	}
}

COMMAND READ_P0392
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0392 }
	}
}

METHOD SET_PAR_NUMBER_0392
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 392;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0393
{
	LABEL "P0393 Highest Temp. Sens.|de|P0393 Hchste Temperatur|es|P0393 Major Temp. Sensores";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -20;
		MAX_VALUE 200;
	}
	CONSTANT_UNIT "C";
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0393
	}
}

COMMAND READ_P0393
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0393 }
	}
}

METHOD SET_PAR_NUMBER_0393
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 393;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0397
{
	LABEL "P0397 Slip Compens.|de|P0397 Schlupfkompensation|es|P0397 Compens.Desliz.";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "Off|de|Aus|es|Inactiva " },
		{ 1, "On  Mot/Reg|de|Ein Mot/Reg|es|Activa Mot/Reg" },
		{ 2, "On Motor|de|Ein Motor|es|Activa Motor" },
		{ 3, "On  Regen|de|Ein Regen|es|Activa Regen" }
		DEFAULT_VALUE 1;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0397
	}
}

COMMAND READ_P0397
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0397 }
	}
}

METHOD SET_PAR_NUMBER_0397
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 397;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0397 LIKE READ_P0397
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 141, P0397 }
		REPLY { }
	}
}

VARIABLE P0398
{
	LABEL "P0398 Motor Service Factor|de|P0398 Motor berlastfaktor|es|P0398 Factor Servicio Motor";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{
		SCALING_FACTOR 0.01;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0398
	}
}

COMMAND READ_P0398
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0398 }
	}
}

METHOD SET_PAR_NUMBER_0398
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 398;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0398 LIKE READ_P0398
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 142, P0398 }
		REPLY { }
	}
}

VARIABLE P0399
{
	LABEL "P0399 Motor Rated Eff.|de|P0399 Motor Effizienz|es|P0399 Rendimiento Nom.Motor";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{
		SCALING_FACTOR 0.1;
	}
	CONSTANT_UNIT "%";
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0399
	}
}

COMMAND READ_P0399
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0399 }
	}
}

METHOD SET_PAR_NUMBER_0399
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 399;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0399 LIKE READ_P0399
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 143, P0399 }
		REPLY { }
	}
}

VARIABLE P0400
{
	LABEL "P0400 Motor Rated Voltage|de|P0400 Motor Nennspannung|es|P0400 Tensin Nominal Motor";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{

	}
	CONSTANT_UNIT "V";
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0400
	}
}

COMMAND READ_P0400
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0400 }
	}
}

METHOD SET_PAR_NUMBER_0400
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 400;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0400 LIKE READ_P0400
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 144, P0400 }
		REPLY { }
	}
}

VARIABLE P0401
{
	LABEL "P0401 Motor Rated Current|de|P0401 Motor Nennstrom|es|P0401 Corriente Nom. Motor";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{
		SCALING_FACTOR 0.1;
	}
	CONSTANT_UNIT "A";
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0401
	}
}

COMMAND READ_P0401
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0401 }
	}
}

METHOD SET_PAR_NUMBER_0401
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 401;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0401 LIKE READ_P0401
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 145, P0401 }
		REPLY { }
	}
}

VARIABLE P0402
{
	LABEL "P0402 Motor Rated Speed |de|P0402 Motor Nenndrehzahl|es|P0402 Rotacin Nom. Motor";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 1750;
		MIN_VALUE 0;
		MAX_VALUE 18000;
	}
	CONSTANT_UNIT "rpm";
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0402
	}
}

COMMAND READ_P0402
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0402 }
	}
}

METHOD SET_PAR_NUMBER_0402
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 402;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0402 LIKE READ_P0402
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 146, P0402 }
		REPLY { }
	}
}

VARIABLE P0403
{
	LABEL "P0403 Motor Rated Frequency|de|P0403 Motor Nennfrequenz|es|P0403 Frecuencia Nom. Motor";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 60;
		MIN_VALUE 0;
		MAX_VALUE 300;
	}
	CONSTANT_UNIT "Hz";
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0403
	}
}

COMMAND READ_P0403
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0403 }
	}
}

METHOD SET_PAR_NUMBER_0403
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 403;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0403 LIKE READ_P0403
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 147, P0403 }
		REPLY { }
	}
}

VARIABLE P0404
{
	LABEL "P0404 Motor Rated Power|de|P0404 Motor Nennleistung|es|P0404 Potencia Nom. Motor ";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "0.33hp 0.25kW|de|  0.25 kW|es|  0.33 HP " },
		{ 1, "0.5hp 0.37kW|de|  0.37 kW|es|  0.50 HP" },
		{ 2, "0.75hp 0.55kW|de|  0.55 kW|es|  0.75 HP " },
		{ 3, "1hp 0.75kW|de|  0.75 kW|es|   1.0 HP  " },
		{ 4, "1.5hp 1.1kW|de|   1.1 kW|es|   1.5 HP " },
		{ 5, "2hp 1.5kW |de|   1.5 kW|es|   2.0 HP " },
		{ 6, "3hp 2.2kW|de|   2.2 kW|es|   3.0 HP " },
		{ 7, "4hp 3kW|de|   3.0 kW|es|   4.0 HP " },
		{ 8, "5hp 3.7kW|de|   3.7 kW|es|   5.0 HP " },
		{ 9, "5.5hp 4kW |de|   4.0 kW |es|   5.5 HP" },
		{ 10, "6hp 4.5kW|de|   4.5 kW|es|   6.0 HP " },
		{ 11, "7.5hp 5.5kW|de|   5.5 kW|es|   7.5 HP " },
		{ 12, "10hp 7.5kW|de|   7.5 kW|es|  10.0 HP " },
		{ 13, "12.5hp 9kW|de|   9.2 kW|es|  12.5 HP" },
		{ 14, "15hp 11kW|de|  11.0 kW|es|  15.0 HP " },
		{ 15, "20hp 15kW|de|  15.0 kW|es|  20.0 HP " },
		{ 16, "25hp 18.5kW|de|  18.5 kW|es|  25.0 HP " },
		{ 17, "30hp 22kW|de|  22.0 kW|es|  30.0 HP " },
		{ 18, "40hp 30kW|de|  30.0 kW|es|  40.0 HP " },
		{ 19, "50hp 37kW|de|  37.0 kW|es|  50.0 HP " },
		{ 20, "60hp 45kW|de|  45.0 kW|es|  60.0 HP " },
		{ 21, "75hp 55kW|de|  55.0 kW|es|  75.0 HP " },
		{ 22, "100hp 75kW|de|  75.0 kW|es| 100.0 HP " },
		{ 23, "125hp 90kW|de|  90.0 kW|es| 125.0 HP " },
		{ 24, "150hp 110kW|de| 110.0 kW|es| 150.0 HP " },
		{ 25, "175hp 130kW|de| 130.0 kW|es| 175.0 HP " },
		{ 26, "180hp 132kW |de| 132.0 kW |es| 180.0 HP" },
		{ 27, "200hp 150kW|de| 150.0 kW|es| 200.0 HP " },
		{ 28, "220hp 160kW|de| 160.0 kW |es| 220.0 HP " },
		{ 29, "250hp 185kW|de| 185.0 kW|es| 250.0 HP " },
		{ 30, "270hp 200kW|de| 200.0 kW|es| 270.0 HP " },
		{ 31, "300hp 220kW|de| 220.0 kW|es| 300.0 HP " },
		{ 32, "350hp 260kW|de| 260.0 kW|es| 350.0 HP " },
		{ 33, "380hp 280kW|de| 280.0 kW|es| 380.0 HP " },
		{ 34, "400hp 300kW|de| 300.0 kW|es| 400.0 HP " },
		{ 35, "430hp 315kW|de| 315.0 kW |es| 430.0 HP" },
		{ 36, "440hp 330kW|de| 330.0 kW |es| 440.0 HP" },
		{ 37, "450hp 335kW|de| 335.0 kW|es| 450.0 HP " },
		{ 38, "475hp 355kW|de| 355.0 kW |es| 475.0 HP" },
		{ 39, "500hp 375kW|de| 375.0 kW|es| 500.0 HP " },
		{ 40, "540hp 400kW|de| 400.0 kW|es| 540.0 HP " },
		{ 41, "600hp 450kW|de| 450.0 kW|es| 600.0 HP " },
		{ 42, "620hp 460kW|de| 460.0 kW|es| 620.0 HP " },
		{ 43, "670hp 500kW|de| 500.0 kW|es| 670.0 HP " },
		{ 44, "700hp 525kW|de| 525.0 kW|es| 700.0 HP " },
		{ 45, "760hp 570kW|de| 570.0 kW|es| 760.0 HP " },
		{ 46, "800hp 600kW|de| 600.0 kW|es| 800.0 HP " },
		{ 47, "850hp 630kW|de| 630.0 kW|es| 850.0 HP " },
		{ 48, "900hp 670kW|de| 670.0 kW|es| 900.0 HP " },
		{ 49, "1000hp 736kW|de| 736.0 kW |es| 1000.0 HP " },
		{ 50, "1100hp 810kW|de| 810.0 kW |es| 1100.0 HP " },
		{ 51, "1250hp 920kW|de| 920.0 kW |es| 1250.0 HP " },
		{ 52, "1400hp 1030kW|de|1030.0 kW |es| 1400.0 HP " },
		{ 53, "1500hp 1110kW|de|1110.0 kW |es| 1500.0 HP " },
		{ 54, "1600hp 1180kW |de|1180.0 kW |es| 1600.0 HP" },
		{ 55, "1800hp 1330kW|de|1330.0 kW |es| 1800.0 HP " },
		{ 56, "2000hp 1480kW|de|1480.0 kW |es| 2000.0 HP " },
		{ 57, "2300hp 1700kW|de|1700.0 kW |es| 2300.0 HP " },
		{ 58, "2500hp 1840kW |de|1840.0 kW |es| 2500.0 HP" },
		{ 59, "2900hp 2140kW |de|2140.0 kW |es| 2900.0 HP" },
		{ 60, "3400hp 2500kW |de|2500.0 kW |es| 3400.0 HP" }
		DEFAULT_VALUE 4;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0404
	}
}

COMMAND READ_P0404
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0404 }
	}
}

METHOD SET_PAR_NUMBER_0404
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 404;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0404 LIKE READ_P0404
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 148, P0404 }
		REPLY { }
	}
}

VARIABLE P0405
{
	LABEL "P0405 Encoder Pulses Number|de|P0405 Drehgeber PPR|es|P0405 Nmero Pulsos Encoder";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 1024;
		MIN_VALUE 100;
		MAX_VALUE 9999;
	}
	CONSTANT_UNIT "ppr";
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0405
	}
}

COMMAND READ_P0405
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0405 }
	}
}

METHOD SET_PAR_NUMBER_0405
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 405;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0405 LIKE READ_P0405
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 149, P0405 }
		REPLY { }
	}
}

VARIABLE P0406
{
	LABEL "P0406 Motor Ventilation|de|P0406 Motor Lfter|es|P0406 Tipo Ventilacin";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "Self-Vent.|de|Eigenlfter|es|Autoventilado" },
		{ 1, "Separate Vent.|de|Fremdlfter|es|Independiente" },
		{ 2, "Optimal Flux|de|Optimalfluss|es|Flujo ptimo" },
		{ 3, "Ext.Protection|de|Erw. Schutz|es|ProtProlongada" }
		DEFAULT_VALUE 0;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0406
	}
}

COMMAND READ_P0406
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0406 }
	}
}

METHOD SET_PAR_NUMBER_0406
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 406;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0406 LIKE READ_P0406
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 150, P0406 }
		REPLY { }
	}
}

VARIABLE P0407
{
	LABEL "P0407 Motor Rated Power Fac|de|P0407 Motor Leistungsfaktor|es|P0407 Factor Pot.Nom. Motor";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{
		SCALING_FACTOR 0.01;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0407
	}
}

COMMAND READ_P0407
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0407 }
	}
}

METHOD SET_PAR_NUMBER_0407
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 407;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0407 LIKE READ_P0407
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 151, P0407 }
		REPLY { }
	}
}

VARIABLE P0409
{
	LABEL "P0409 Stator Resistance    |de|P0409 Statorwiderstand|es|P0409 Resistencia Estator";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{
		SCALING_FACTOR 0.001;
	}
	CONSTANT_UNIT "ohm";
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0409
	}
}

COMMAND READ_P0409
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0409 }
	}
}

METHOD SET_PAR_NUMBER_0409
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 409;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0409 LIKE READ_P0409
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 153, P0409 }
		REPLY { }
	}
}

VARIABLE P0410
{
	LABEL "P0410 Magnetization Current|de|P0410 Magnetisierungsstrom|es|P0410 Corr. Magnetizacin ";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{
		SCALING_FACTOR 0.1;
	}
	CONSTANT_UNIT "A";
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0410
	}
}

COMMAND READ_P0410
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0410 }
	}
}

METHOD SET_PAR_NUMBER_0410
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 410;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0410 LIKE READ_P0410
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 154, P0410 }
		REPLY { }
	}
}

VARIABLE P0411
{
	LABEL "P0411 Leakage Inductance|de|P0411 Streuinduktivitt|es|P0411 Induct. Dispersin";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{
		SCALING_FACTOR 0.01;
	}
	CONSTANT_UNIT "mH";
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0411
	}
}

COMMAND READ_P0411
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0411 }
	}
}

METHOD SET_PAR_NUMBER_0411
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 411;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0411 LIKE READ_P0411
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 155, P0411 }
		REPLY { }
	}
}

VARIABLE P0412
{
	LABEL "P0412 Tr Time Constant  |de|P0412 Tr Zeitkonstante|es|P0412 Constante Tr ";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{
		SCALING_FACTOR 0.001;
	}
	CONSTANT_UNIT "s";
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0412
	}
}

COMMAND READ_P0412
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0412 }
	}
}

METHOD SET_PAR_NUMBER_0412
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 412;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0412 LIKE READ_P0412
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 156, P0412 }
		REPLY { }
	}
}

VARIABLE P0413
{
	LABEL "P0413 Tm Time Constant|de|P0413 Tm Zeitkonstante|es|P0413 Constante Tm    ";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{
		SCALING_FACTOR 0.01;
	}
	CONSTANT_UNIT "s";
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0413
	}
}

COMMAND READ_P0413
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0413 }
	}
}

METHOD SET_PAR_NUMBER_0413
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 413;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0413 LIKE READ_P0413
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 157, P0413 }
		REPLY { }
	}
}

VARIABLE P0414
{
	LABEL "P0414 Magnetization Time|de|P0414 Magnetisierungszeit|es|P0414 Tiempo Magnetizacin";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{
		SCALING_FACTOR 0.001;
	}
	CONSTANT_UNIT "s";
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0414
	}
}

COMMAND READ_P0414
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0414 }
	}
}

METHOD SET_PAR_NUMBER_0414
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 414;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0414 LIKE READ_P0414
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 158, P0414 }
		REPLY { }
	}
}

VARIABLE P0430
{
	LABEL "P0430 PM Type|de|P0430 PM Type|es|P0430 Tipo PM";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "Standard|de|Standard|es|Padrn" },
		{ 1, "Cooling Tower|de|Cooling Tower|es|Cooling Tower" }
		DEFAULT_VALUE 0;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0430
	}
}

COMMAND READ_P0430
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0430 }
	}
}

METHOD SET_PAR_NUMBER_0430
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 430;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0430 LIKE READ_P0430
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 174, P0430 }
		REPLY { }
	}
}

VARIABLE P0431
{
	LABEL "P0431 Pole Number|de|P0431 Polzahl|es|P0431 Nmero de Plos";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 6;
		MIN_VALUE 2;
		MAX_VALUE 24;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0431
	}
}

COMMAND READ_P0431
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0431 }
	}
}

METHOD SET_PAR_NUMBER_0431
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 431;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0431 LIKE READ_P0431
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 175, P0431 }
		REPLY { }
	}
}

VARIABLE P0433
{
	LABEL "P0433 Lq Inductance|de|P0433 Induktivitt Lq|es|P0433 Inductancia Lq";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{
		SCALING_FACTOR 0.01;
	}
	CONSTANT_UNIT "mH";
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0433
	}
}

COMMAND READ_P0433
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0433 }
	}
}

METHOD SET_PAR_NUMBER_0433
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 433;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0433 LIKE READ_P0433
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 177, P0433 }
		REPLY { }
	}
}

VARIABLE P0434
{
	LABEL "P0434 Ld Inductance|de|P0434 Induktivitt Ld|es|P0434 Inductancia Ld";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{
		SCALING_FACTOR 0.01;
	}
	CONSTANT_UNIT "mH";
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0434
	}
}

COMMAND READ_P0434
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0434 }
	}
}

METHOD SET_PAR_NUMBER_0434
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 434;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0434 LIKE READ_P0434
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 178, P0434 }
		REPLY { }
	}
}

VARIABLE P0435
{
	LABEL "P0435 Ke Constant|de|P0435 Konstante Ke|es|P0435 Constante Ke";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{
		SCALING_FACTOR 0.1;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0435
	}
}

COMMAND READ_P0435
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0435 }
	}
}

METHOD SET_PAR_NUMBER_0435
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 435;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0435 LIKE READ_P0435
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 179, P0435 }
		REPLY { }
	}
}

VARIABLE P0438
{
	LABEL "P0438 Iq Prop. Gain|de|P0438 Iq P Verstrkung|es|P0438 Ganancia Prop. Iq";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{
		SCALING_FACTOR 0.01;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0438
	}
}

COMMAND READ_P0438
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0438 }
	}
}

METHOD SET_PAR_NUMBER_0438
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 438;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0438 LIKE READ_P0438
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 182, P0438 }
		REPLY { }
	}
}

VARIABLE P0439
{
	LABEL "P0439 Iq Integral Gain|de|P0439 Iq I Verstrkung|es|P0439 Ganancia Integral Iq";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{
		SCALING_FACTOR 0.001;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0439
	}
}

COMMAND READ_P0439
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0439 }
	}
}

METHOD SET_PAR_NUMBER_0439
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 439;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0439 LIKE READ_P0439
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 183, P0439 }
		REPLY { }
	}
}

VARIABLE P0440
{
	LABEL "P0440 Id Prop. Gain|de|P0440 Id P Verstrkung|es|P0440 Ganancia Prop. Id";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{
		SCALING_FACTOR 0.01;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0440
	}
}

COMMAND READ_P0440
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0440 }
	}
}

METHOD SET_PAR_NUMBER_0440
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 440;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0440 LIKE READ_P0440
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 184, P0440 }
		REPLY { }
	}
}

VARIABLE P0441
{
	LABEL "P0441 Id Integral Gain|de|P0441 Id I Verstrkung|es|P0441 Ganancia Integral Id";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{
		SCALING_FACTOR 0.001;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0441
	}
}

COMMAND READ_P0441
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0441 }
	}
}

METHOD SET_PAR_NUMBER_0441
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 441;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0441 LIKE READ_P0441
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 185, P0441 }
		REPLY { }
	}
}

VARIABLE P0442
{
	LABEL "P0442 Lq Inductance - CT|de|P0442 Induktivitt Lq - CT|es|P0442 Inductancia Lq - CT";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{
		SCALING_FACTOR 0.1;
	}
	CONSTANT_UNIT "mH";
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0442
	}
}

COMMAND READ_P0442
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0442 }
	}
}

METHOD SET_PAR_NUMBER_0442
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 442;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0442 LIKE READ_P0442
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 186, P0442 }
		REPLY { }
	}
}

VARIABLE P0443
{
	LABEL "P0443 Ld Inductance - CT|de|P0443 Induktivitt Ld - CT|es|P0443 Inductancia Ld - CT";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{
		SCALING_FACTOR 0.1;
	}
	CONSTANT_UNIT "mH";
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0443
	}
}

COMMAND READ_P0443
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0443 }
	}
}

METHOD SET_PAR_NUMBER_0443
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 443;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0443 LIKE READ_P0443
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 187, P0443 }
		REPLY { }
	}
}

VARIABLE P0444
{
	LABEL "P0444 Ke Constant - CT|de|P0444 Konstante Ke - CT|es|P0444 Constante Ke - CT";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 100;
		MIN_VALUE 0;
		MAX_VALUE 3000;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0444
	}
}

COMMAND READ_P0444
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0444 }
	}
}

METHOD SET_PAR_NUMBER_0444
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 444;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0444 LIKE READ_P0444
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 188, P0444 }
		REPLY { }
	}
}

VARIABLE P0520
{
	LABEL "P0520 PID Proportional Gain|de|P0520 PID P Verstrkung|es|P0520 Ganancia Prop. PID";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{
		SCALING_FACTOR 0.001;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0520
	}
}

COMMAND READ_P0520
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0520 }
	}
}

METHOD SET_PAR_NUMBER_0520
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 520;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0520 LIKE READ_P0520
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 2, 8, P0520 }
		REPLY { }
	}
}

VARIABLE P0521
{
	LABEL "P0521 PID Integral Gain|de|P0521 PID I Verstrkung|es|P0521 Ganancia Integral PID";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{
		SCALING_FACTOR 0.001;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0521
	}
}

COMMAND READ_P0521
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0521 }
	}
}

METHOD SET_PAR_NUMBER_0521
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 521;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0521 LIKE READ_P0521
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 2, 9, P0521 }
		REPLY { }
	}
}

VARIABLE P0522
{
	LABEL "P0522 PID Differential Gain|de|P0522 PID D Verstrkung|es|P0522 Ganancia Diferenc.PID";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{
		SCALING_FACTOR 0.001;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0522
	}
}

COMMAND READ_P0522
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0522 }
	}
}

METHOD SET_PAR_NUMBER_0522
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 522;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0522 LIKE READ_P0522
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 2, 10, P0522 }
		REPLY { }
	}
}

VARIABLE P0523
{
	LABEL "P0523 PID Ramp Time|de|P0523 PID Rampenzeit|es|P0523 Tiempo Rampa PID";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{
		SCALING_FACTOR 0.1;
	}
	CONSTANT_UNIT "s";
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0523
	}
}

COMMAND READ_P0523
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0523 }
	}
}

METHOD SET_PAR_NUMBER_0523
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 523;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0523 LIKE READ_P0523
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 2, 11, P0523 }
		REPLY { }
	}
}

VARIABLE P0524
{
	LABEL "P0524 PID Feedback Sel.|de|P0524 PID Feedback Ausw.|es|P0524 Sel. Realim. PID";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "AI1 (P0231)|de|AI1 (P0231)|es|AI1 (P0231)" },
		{ 1, "AI2 (P0236)|de|AI2 (P0236)|es|AI2 (P0236)" },
		{ 2, "AI3 (P0241)|de|AI3 (P0241)|es|AI3 (P0241)" },
		{ 3, "AI4 (P0246)|de|AI4 (P0246)|es|AI4 (P0246)" }
		DEFAULT_VALUE 1;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0524
	}
}

COMMAND READ_P0524
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0524 }
	}
}

METHOD SET_PAR_NUMBER_0524
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 524;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0524 LIKE READ_P0524
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 2, 12, P0524 }
		REPLY { }
	}
}

VARIABLE P0525
{
	LABEL "P0525 Keypad PID Setpoint|de|P0525 PID Sollwert FB|es|P0525 Setpoint PID por HMI";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{
		SCALING_FACTOR 0.1;
	}
	CONSTANT_UNIT "%";
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0525
	}
}

COMMAND READ_P0525
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0525 }
	}
}

METHOD SET_PAR_NUMBER_0525
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 525;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0525 LIKE READ_P0525
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 2, 13, P0525 }
		REPLY { }
	}
}

VARIABLE P0527
{
	LABEL "P0527 PID Action Type|de|P0527 PID Regelkreis|es|P0527 Tipo de Accin  ";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "Direct|de|Direkt|es|Directo   " },
		{ 1, "Reverse|de|Invers|es|Reverso   " }
		DEFAULT_VALUE 0;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0527
	}
}

COMMAND READ_P0527
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0527 }
	}
}

METHOD SET_PAR_NUMBER_0527
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 527;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0527 LIKE READ_P0527
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 2, 15, P0527 }
		REPLY { }
	}
}

VARIABLE P0528
{
	LABEL "P0528 Proc. V. Scale Factor|de|P0528 Proz.Var. Skalafaktor|es|P0528 Factor Escala VP";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 1000;
		MIN_VALUE 1;
		MAX_VALUE 9999;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0528
	}
}

COMMAND READ_P0528
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0528 }
	}
}

METHOD SET_PAR_NUMBER_0528
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 528;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0528 LIKE READ_P0528
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 2, 16, P0528 }
		REPLY { }
	}
}

VARIABLE P0529
{
	LABEL "P0529 Proc.V. Decimal Point|de|P0529 Proz.Var. Dezimalpkt.|es|P0529 Modo de Indicacin VP";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "wxyz|de|wxyz|es|wxyz" },
		{ 1, "wxy.z|de|wxy.z|es|wxy.z" },
		{ 2, "wx.yz|de|wx.yz|es|wx.yz" },
		{ 3, "w.xyz|de|w.xyz|es|w.xyz" }
		DEFAULT_VALUE 1;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0529
	}
}

COMMAND READ_P0529
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0529 }
	}
}

METHOD SET_PAR_NUMBER_0529
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 529;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0529 LIKE READ_P0529
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 2, 17, P0529 }
		REPLY { }
	}
}

VARIABLE P0530
{
	LABEL "P0530 Proc. V. Eng. Unit 1|de|P0530 1. Einheit Proz. Var.|es|P0530 Unidad Ing. VP1";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 37;
		MIN_VALUE 32;
		MAX_VALUE 127;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0530
	}
}

COMMAND READ_P0530
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0530 }
	}
}

METHOD SET_PAR_NUMBER_0530
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 530;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0530 LIKE READ_P0530
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 2, 18, P0530 }
		REPLY { }
	}
}

VARIABLE P0531
{
	LABEL "P0531 Proc. V. Eng. Unit 2|de|P0531 2. Einheit Proz. Var.|es|P0531 Unidad Ing. VP2";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 32;
		MIN_VALUE 32;
		MAX_VALUE 127;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0531
	}
}

COMMAND READ_P0531
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0531 }
	}
}

METHOD SET_PAR_NUMBER_0531
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 531;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0531 LIKE READ_P0531
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 2, 19, P0531 }
		REPLY { }
	}
}

VARIABLE P0532
{
	LABEL "P0532 Proc. V. Eng. Unit 3|de|P0532 3. Einheit Proz. Var.|es|P0532 Unidad Ing. VP3";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 32;
		MIN_VALUE 32;
		MAX_VALUE 127;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0532
	}
}

COMMAND READ_P0532
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0532 }
	}
}

METHOD SET_PAR_NUMBER_0532
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 532;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0532 LIKE READ_P0532
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 2, 20, P0532 }
		REPLY { }
	}
}

VARIABLE P0533
{
	LABEL "P0533 PVx Value|de|P0533 PVx Wert|es|P0533 Valor VPx";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{
		SCALING_FACTOR 0.1;
	}
	CONSTANT_UNIT "%";
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0533
	}
}

COMMAND READ_P0533
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0533 }
	}
}

METHOD SET_PAR_NUMBER_0533
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 533;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0533 LIKE READ_P0533
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 2, 21, P0533 }
		REPLY { }
	}
}

VARIABLE P0534
{
	LABEL "P0534 PVy Value|de|P0534 PVy Wert|es|P0534 Valor Vpy";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{
		SCALING_FACTOR 0.1;
	}
	CONSTANT_UNIT "%";
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0534
	}
}

COMMAND READ_P0534
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0534 }
	}
}

METHOD SET_PAR_NUMBER_0534
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 534;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0534 LIKE READ_P0534
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 2, 22, P0534 }
		REPLY { }
	}
}

VARIABLE P0535
{
	LABEL "P0535 Wake Up Band|de|P0535 Ausgang N=0 PID|es|P0535 Salida N=0 PID";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 100;
	}
	CONSTANT_UNIT "%";
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0535
	}
}

COMMAND READ_P0535
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0535 }
	}
}

METHOD SET_PAR_NUMBER_0535
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 535;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0535 LIKE READ_P0535
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 2, 23, P0535 }
		REPLY { }
	}
}

VARIABLE P0536
{
	LABEL "P0536 P0525 Autom. Setting|de|P0536 P0525 autom. Einst.|es|P0536 Ajuste autom. P0525";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "Off       |de|Aus|es|Inactivo  " },
		{ 1, "On        |de|Ein|es|Activo    " }
		DEFAULT_VALUE 1;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0536
	}
}

COMMAND READ_P0536
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0536 }
	}
}

METHOD SET_PAR_NUMBER_0536
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 536;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0536 LIKE READ_P0536
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 2, 24, P0536 }
		REPLY { }
	}
}

VARIABLE P0538
{
	LABEL "P0538 PVx/PVy Hysteresis|de|P0538 PVx/PVy Hysterese|es|P0538 Histresis VPx/VPy";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{
		SCALING_FACTOR 0.1;
	}
	CONSTANT_UNIT "%";
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0538
	}
}

COMMAND READ_P0538
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0538 }
	}
}

METHOD SET_PAR_NUMBER_0538
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 538;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0538 LIKE READ_P0538
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 2, 26, P0538 }
		REPLY { }
	}
}

VARIABLE P0550
{
	LABEL "P0550 Trigger Signal Source|de|P0550 Triggerquelle|es|P0550 Fuente Trigger Trace";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "Not selected|de|Aus|es|Inactivo  " },
		{ 1, "Speed Refer.|de|Drehz.Sollw.|es|Ref. Veloc." },
		{ 2, "Motor Speed|de|Motordrehz.|es|Veloc. Motor" },
		{ 3, "Motor Current|de|Motorstrom|es|Corr. Motor" },
		{ 4, "DC Link Volt.|de|ZwischenkrSpg.|es|Tensin CC" },
		{ 5, "Motor Freq.|de|Motorfrequenz|es|Frec. Motor" },
		{ 6, "Motor Voltage|de|Motorspg.|es|Tensin Salida" },
		{ 7, "Motor Torque|de|Motormoment|es|Torque Motor" },
		{ 8, "Process Var.|de|Prozessvar.|es|Var. Proceso" },
		{ 9, "Setpoint PID|de|PID Sollwert|es|Setpoint PID" },
		{ 10, "AI1 |de|AI1 |es|AI1 " },
		{ 11, "AI2 |de|AI2 |es|AI2 " },
		{ 12, "AI3|de|AI3|es|AI3" },
		{ 13, "AI4|de|AI4|es|AI4" }
		DEFAULT_VALUE 0;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0550
	}
}

COMMAND READ_P0550
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0550 }
	}
}

METHOD SET_PAR_NUMBER_0550
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 550;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0550 LIKE READ_P0550
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 2, 38, P0550 }
		REPLY { }
	}
}

VARIABLE P0551
{
	LABEL "P0551 Trigger Level|de|P0551 Triggerlevel|es|P0551 Valor Trigger";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{
		SCALING_FACTOR 0.1;
	}
	CONSTANT_UNIT "%";
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0551
	}
}

COMMAND READ_P0551
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0551 }
	}
}

METHOD SET_PAR_NUMBER_0551
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 551;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0551 LIKE READ_P0551
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 2, 39, P0551 }
		REPLY { }
	}
}

VARIABLE P0552
{
	LABEL "P0552 Trigger Condition|de|P0552 Triggerbedingung|es|P0552 Condicin Trigger";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "P0550* = P0551|de|P0550* = P0551|es|P0550* = P0551" },
		{ 1, "P0550* <>P0551|de|P0550* <>P0551|es|P0550* <>P0551" },
		{ 2, "P0550* > P0551|de|P0550* > P0551|es|P0550* > P0551" },
		{ 3, "P0550* < P0551|de|P0550* < P0551|es|P0550* < P0551" },
		{ 4, "Alarm|de|Alarm |es|Alarma" },
		{ 5, "Fault|de|Fehler|es|Falla" },
		{ 6, "DIx|de|DIx |es|DIx" }
		DEFAULT_VALUE 5;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0552
	}
}

COMMAND READ_P0552
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0552 }
	}
}

METHOD SET_PAR_NUMBER_0552
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 552;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0552 LIKE READ_P0552
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 2, 40, P0552 }
		REPLY { }
	}
}

VARIABLE P0553
{
	LABEL "P0553 Trace Sampling Period|de|P0553 Trace Abtastzeit|es|P0553 Periodo MuestreoTrace";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 1;
		MIN_VALUE 1;
		MAX_VALUE 65535;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0553
	}
}

COMMAND READ_P0553
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0553 }
	}
}

METHOD SET_PAR_NUMBER_0553
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 553;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0553 LIKE READ_P0553
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 2, 41, P0553 }
		REPLY { }
	}
}

VARIABLE P0554
{
	LABEL "P0554 Trace Pre-Trigger|de|P0554 Trace Vortrigger|es|P0554 Pretrigger Trace";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 100;
	}
	CONSTANT_UNIT "%";
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0554
	}
}

COMMAND READ_P0554
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0554 }
	}
}

METHOD SET_PAR_NUMBER_0554
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 554;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0554 LIKE READ_P0554
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 2, 42, P0554 }
		REPLY { }
	}
}

VARIABLE P0559
{
	LABEL "P0559 Trace Max. Memory|de|P0559 Trace max. Speicher|es|P0559 Memoria Mxima Trace";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 100;
	}
	CONSTANT_UNIT "%";
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0559
	}
}

COMMAND READ_P0559
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0559 }
	}
}

METHOD SET_PAR_NUMBER_0559
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 559;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0559 LIKE READ_P0559
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 2, 47, P0559 }
		REPLY { }
	}
}

VARIABLE P0560
{
	LABEL "P0560 Trace Avail. Memory|de|P0560 Trace verfg.Speicher|es|P0560 Memoria Dispon. Trace";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 100;
	}
	CONSTANT_UNIT "%";
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0560
	}
}

COMMAND READ_P0560
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0560 }
	}
}

METHOD SET_PAR_NUMBER_0560
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 560;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0561
{
	LABEL "P0561 Trace Channel 1 (CH1)|de|P0561 Trace Kanal 1 (CH1)|es|P0561 CH1: Canal 1 Trace";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "Not selected|de|Aus|es|Inactivo  " },
		{ 1, "Speed Refer.|de|Drehz.Sollw.|es|Ref. Veloc." },
		{ 2, "Motor Speed|de|Motordrehz.|es|Veloc. Motor" },
		{ 3, "Motor Current|de|Motorstrom|es|Corr. Motor" },
		{ 4, "DC Link Volt.|de|ZwischenkrSpg.|es|Tensin CC" },
		{ 5, "Motor Freq.|de|Motorfrequenz|es|Frec. Motor" },
		{ 6, "Motor Voltage|de|Motorspg.|es|Tensin Salida" },
		{ 7, "Motor Torque|de|Motormoment|es|Torque Motor" },
		{ 8, "Process Var.|de|Prozessvar.|es|Var. Proceso" },
		{ 9, "Setpoint PID|de|PID Sollwert|es|Setpoint PID" },
		{ 10, "AI1 |de|AI1 |es|AI1 " },
		{ 11, "AI2 |de|AI2 |es|AI2 " },
		{ 12, "AI3|de|AI3|es|AI3" },
		{ 13, "AI4|de|AI4|es|AI4" }
		DEFAULT_VALUE 1;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0561
	}
}

COMMAND READ_P0561
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0561 }
	}
}

METHOD SET_PAR_NUMBER_0561
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 561;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0561 LIKE READ_P0561
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 2, 49, P0561 }
		REPLY { }
	}
}

VARIABLE P0562
{
	LABEL "P0562 Trace Channel 2 (CH2)|de|P0562 Trace Kanal 2 (CH2)|es|P0562 CH2: Canal 2 Trace";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "Not selected|de|Aus|es|Inactivo  " },
		{ 1, "Speed Refer.|de|Drehz.Sollw.|es|Ref. Veloc." },
		{ 2, "Motor Speed|de|Motordrehz.|es|Veloc. Motor" },
		{ 3, "Motor Current|de|Motorstrom|es|Corr. Motor" },
		{ 4, "DC Link Volt.|de|ZwischenkrSpg.|es|Tensin CC" },
		{ 5, "Motor Freq.|de|Motorfrequenz|es|Frec. Motor" },
		{ 6, "Motor Voltage|de|Motorspg.|es|Tensin Salida" },
		{ 7, "Motor Torque|de|Motormoment|es|Torque Motor" },
		{ 8, "Process Var.|de|Prozessvar.|es|Var. Proceso" },
		{ 9, "Setpoint PID|de|PID Sollwert|es|Setpoint PID" },
		{ 10, "AI1 |de|AI1 |es|AI1 " },
		{ 11, "AI2 |de|AI2 |es|AI2 " },
		{ 12, "AI3|de|AI3|es|AI3" },
		{ 13, "AI4|de|AI4|es|AI4" }
		DEFAULT_VALUE 2;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0562
	}
}

COMMAND READ_P0562
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0562 }
	}
}

METHOD SET_PAR_NUMBER_0562
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 562;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0562 LIKE READ_P0562
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 2, 50, P0562 }
		REPLY { }
	}
}

VARIABLE P0563
{
	LABEL "P0563 Trace Channel 3 (CH3)|de|P0563 Trace Kanal 3 (CH3)|es|P0563 CH3: Canal 3 Trace";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "Not selected|de|Aus|es|Inactivo  " },
		{ 1, "Speed Refer.|de|Drehz.Sollw.|es|Ref. Veloc." },
		{ 2, "Motor Speed|de|Motordrehz.|es|Veloc. Motor" },
		{ 3, "Motor Current|de|Motorstrom|es|Corr. Motor" },
		{ 4, "DC Link Volt.|de|ZwischenkrSpg.|es|Tensin CC" },
		{ 5, "Motor Freq.|de|Motorfrequenz|es|Frec. Motor" },
		{ 6, "Motor Voltage|de|Motorspg.|es|Tensin Salida" },
		{ 7, "Motor Torque|de|Motormoment|es|Torque Motor" },
		{ 8, "Process Var.|de|Prozessvar.|es|Var. Proceso" },
		{ 9, "Setpoint PID|de|PID Sollwert|es|Setpoint PID" },
		{ 10, "AI1 |de|AI1 |es|AI1 " },
		{ 11, "AI2 |de|AI2 |es|AI2 " },
		{ 12, "AI3|de|AI3|es|AI3" },
		{ 13, "AI4|de|AI4|es|AI4" }
		DEFAULT_VALUE 3;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0563
	}
}

COMMAND READ_P0563
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0563 }
	}
}

METHOD SET_PAR_NUMBER_0563
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 563;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0563 LIKE READ_P0563
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 2, 51, P0563 }
		REPLY { }
	}
}

VARIABLE P0564
{
	LABEL "P0564 Trace Channel 4 (CH4)|de|P0564 Trace Kanal 4 (CH4)|es|P0564 CH4: Canal 4 Trace";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "Not selected|de|Aus|es|Inactivo  " },
		{ 1, "Speed Refer.|de|Drehz.Sollw.|es|Ref. Veloc." },
		{ 2, "Motor Speed|de|Motordrehz.|es|Veloc. Motor" },
		{ 3, "Motor Current|de|Motorstrom|es|Corr. Motor" },
		{ 4, "DC Link Volt.|de|ZwischenkrSpg.|es|Tensin CC" },
		{ 5, "Motor Freq.|de|Motorfrequenz|es|Frec. Motor" },
		{ 6, "Motor Voltage|de|Motorspg.|es|Tensin Salida" },
		{ 7, "Motor Torque|de|Motormoment|es|Torque Motor" },
		{ 8, "Process Var.|de|Prozessvar.|es|Var. Proceso" },
		{ 9, "Setpoint PID|de|PID Sollwert|es|Setpoint PID" },
		{ 10, "AI1 |de|AI1 |es|AI1 " },
		{ 11, "AI2 |de|AI2 |es|AI2 " },
		{ 12, "AI3|de|AI3|es|AI3" },
		{ 13, "AI4|de|AI4|es|AI4" }
		DEFAULT_VALUE 0;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0564
	}
}

COMMAND READ_P0564
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0564 }
	}
}

METHOD SET_PAR_NUMBER_0564
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 564;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0564 LIKE READ_P0564
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 2, 52, P0564 }
		REPLY { }
	}
}

VARIABLE P0571
{
	LABEL "P0571 Start Trace Function|de|P0571 Start Trace-Funktion|es|P0571 Inicia Funcion Trace";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "Off       |de|Aus|es|Inactivo  " },
		{ 1, "On        |de|Ein|es|Activo    " }
		DEFAULT_VALUE 0;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0571
	}
}

COMMAND READ_P0571
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0571 }
	}
}

METHOD SET_PAR_NUMBER_0571
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 571;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0571 LIKE READ_P0571
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 2, 59, P0571 }
		REPLY { }
	}
}

VARIABLE P0572
{
	LABEL "P0572 Trace Trig. Day/Month|de|P0572 Trace Trig. Tag/Monat|es|P0572 Da/Mes Disparo Trace";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE UNSIGNED_INTEGER(2)
	{

	}
	POST_READ_ACTIONS { ConvertToDateTimeP0572 }
	HELP [DATE_TIME_HELP];
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0572
	}
}

METHOD ConvertToDateTimeP0572
{
	LABEL "Convert to day/month or hour/minute";
	DEFINITION { P0572 = (P0572&0x00FF) + (P0572>>8)*100; }
}

COMMAND READ_P0572
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0572 }
	}
}

METHOD SET_PAR_NUMBER_0572
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 572;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0573
{
	LABEL "P0573 Trace Trig. Year|de|P0573 Trace Trig. Jahr|es|P0573 Ao Disparo Trace";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 99;
	}
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0573
	}
}

COMMAND READ_P0573
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0573 }
	}
}

METHOD SET_PAR_NUMBER_0573
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 573;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0574
{
	LABEL "P0574 Trace Trig. Time|de|P0574 Trace Trig. Zeit|es|P0574 Hora Disparo Trace";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE UNSIGNED_INTEGER(2)
	{

	}
	POST_READ_ACTIONS { ConvertToDateTimeP0574 }
	HELP [DATE_TIME_HELP];
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0574
	}
}

METHOD ConvertToDateTimeP0574
{
	LABEL "Convert to day/month or hour/minute";
	DEFINITION { P0574 = (P0574&0x00FF) + (P0574>>8)*100; }
}

COMMAND READ_P0574
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0574 }
	}
}

METHOD SET_PAR_NUMBER_0574
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 574;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0575
{
	LABEL "P0575 Trace Trig. Seconds|de|P0575 Trace Trig. Sekunden|es|P0575 Seg. Disparo Trace";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 59;
	}
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0575
	}
}

COMMAND READ_P0575
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0575 }
	}
}

METHOD SET_PAR_NUMBER_0575
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 575;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0576
{
	LABEL "P0576 Trace Function Status|de|P0576 Trace Status|es|P0576 Estado Funcin Trace";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE ENUMERATED(2)
	{
		{ 0, "Off       |de|Aus|es|Inactivo  " },
		{ 1, "Waiting|de|Warten|es|Aguardando" },
		{ 2, "Trigger|de|Triggern|es|Trigger" },
		{ 3, "Concluded|de|Fertig|es|Concluido" }
		DEFAULT_VALUE 0;
	}
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0576
	}
}

COMMAND READ_P0576
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0576 }
	}
}

METHOD SET_PAR_NUMBER_0576
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 576;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0613
{
	LABEL "P0613 Firmware Revision|de|P0613 Firmware Revision|es|P0613 Firmware Revision";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0613
	}
}

COMMAND READ_P0613
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0613 }
	}
}

METHOD SET_PAR_NUMBER_0613
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 613;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0614
{
	LABEL "P0614 PLD Revision|de|P0614 PLD Revision|es|P0614 PLD Revision";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0614
	}
}

COMMAND READ_P0614
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0614 }
	}
}

METHOD SET_PAR_NUMBER_0614
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 614;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0680
{
	LABEL "P0680 Logical Status|de|P0680 Logischer Status|es|P0680 Estado Lgico";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE BIT_ENUMERATED(2)
	{
		{ 0x000F, "Not Used  |de|Reserviert|es|Reservado" },
		{ 0x0010, "Quick Stop ON|de|Schnellstop an|es|En Parada Rp." },
		{ 0x0020, "2nd Ramp|de|2. Rampe|es|2a Rampa" },
		{ 0x0040, "Config. Mode|de|Konfig. Modus|es|Modo Config." },
		{ 0x0080, "Alarm|de|Alarm|es|Alarma" },
		{ 0x0100, "Running|de|Running|es|Girando" },
		{ 0x0200, "Enabled|de|Enabled|es|Habilitado" },
		{ 0x0400, "Forward|de|Rechtslauf|es|Horario" },
		{ 0x0800, "JOG|de|JOG|es|JOG" },
		{ 0x1000, "Remote|de|REM|es|Remoto" },
		{ 0x2000, "Subvoltage|de|Unterspannung|es|Subtensin" },
		{ 0x4000, "Automatic(PID)|de|Automatisch|es|Automtico" },
		{ 0x8000, "Fault|de|Fehler|es|Falla" }
		DEFAULT_VALUE 0;
	}
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0680
	}
}

COMMAND READ_P0680
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0680 }
	}
}

METHOD SET_PAR_NUMBER_0680
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 680;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0681
{
	LABEL "P0681 Speed in 13 bits|de|P0681 Drehzahl in 13 bits|es|P0681 Velocidad 13 bits";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0681
	}
}

COMMAND READ_P0681
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0681 }
	}
}

METHOD SET_PAR_NUMBER_0681
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 681;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0682
{
	LABEL "P0682 Serial/USB Control|de|P0682 Serielle/USB Kontr.|es|P0682 Control Serie/USB";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE BIT_ENUMERATED(2)
	{
		{ 0x0001, "Ramp Enable|de|Rampenfreigabe|es|Habilita Rampa" },
		{ 0x0002, "General Enable|de|Freigabe|es|Hab. General" },
		{ 0x0004, "Run Forward|de|Run Forward|es|Girar Horario" },
		{ 0x0008, "JOG Enable|de|JOG Enable|es|Habilita JOG" },
		{ 0x0010, "Remote|de|REM|es|Remoto" },
		{ 0x0020, "2nd Ramp|de|2. Rampe|es|2a Rampa" },
		{ 0x0040, "Quick Stop|de|Schnellstop|es|Parada Rpida" },
		{ 0x0080, "Fault Reset|de|Fehler Reset|es|Reset de Falla" },
		{ 0xFF00, "Reserved|de|Reserviert|es|Reservado" }
		DEFAULT_VALUE 0;
	}
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0682
	}
}

COMMAND READ_P0682
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0682 }
	}
}

METHOD SET_PAR_NUMBER_0682
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 682;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0683
{
	LABEL "P0683 Serial/USB Speed Ref.|de|P0683 Ser/USB Drehz Sollw.|es|P0683 Ref. Vel. Serie/USB";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0683
	}
}

COMMAND READ_P0683
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0683 }
	}
}

METHOD SET_PAR_NUMBER_0683
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 683;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0684
{
	LABEL "P0684 CO/DN/DP Control|de|P0684 CO/DN/DP Kontrolle]|es|P0684 Control CO/DN/DP";
	CLASS CONTAINED;
	TYPE BIT_ENUMERATED(2)
	{
		{ 0x0001, "Ramp Enable|de|Rampenfreigabe|es|Habilita Rampa" },
		{ 0x0002, "General Enable|de|Freigabe|es|Hab. General" },
		{ 0x0004, "Run Forward|de|Run Forward|es|Girar Horario" },
		{ 0x0008, "JOG Enable|de|JOG Enable|es|Habilita JOG" },
		{ 0x0010, "Remote|de|REM|es|Remoto" },
		{ 0x0020, "2nd Ramp|de|2. Rampe|es|2a Rampa" },
		{ 0x0040, "Quick Stop|de|Schnellstop|es|Parada Rpida" },
		{ 0x0080, "Fault Reset|de|Fehler Reset|es|Reset de Falla" },
		{ 0xFF00, "Reserved|de|Reserviert|es|Reservado" }
		DEFAULT_VALUE 0;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0684
	}
}

COMMAND READ_P0684
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0684 }
	}
}

METHOD SET_PAR_NUMBER_0684
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 684;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0684 LIKE READ_P0684
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 2, 172, P0684 }
		REPLY { }
	}
}

VARIABLE P0685
{
	LABEL "P0685 CO/DN/DP Speed Ref|de|P0685 CO/DN/DP DrehzSollw|es|P0685 Ref. Vel. CO/DN/DP";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0685
	}
}

COMMAND READ_P0685
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0685 }
	}
}

METHOD SET_PAR_NUMBER_0685
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 685;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0685 LIKE READ_P0685
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 2, 173, P0685 }
		REPLY { }
	}
}

VARIABLE P0686
{
	LABEL "P0686 Anybus-CC Control|de|P0686 Anybus-CC Kontrolle|es|P0686 Control Anybus-CC";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE BIT_ENUMERATED(2)
	{
		{ 0x0001, "Ramp Enable|de|Rampenfreigabe|es|Habilita Rampa" },
		{ 0x0002, "General Enable|de|Freigabe|es|Hab. General" },
		{ 0x0004, "Run Forward|de|Run Forward|es|Girar Horario" },
		{ 0x0008, "JOG Enable|de|JOG Enable|es|Habilita JOG" },
		{ 0x0010, "Remote|de|REM|es|Remoto" },
		{ 0x0020, "2nd Ramp|de|2. Rampe|es|2a Rampa" },
		{ 0x0040, "Quick Stop|de|Schnellstop|es|Parada Rpida" },
		{ 0x0080, "Fault Reset|de|Fehler Reset|es|Reset de Falla" },
		{ 0xFF00, "Reserved|de|Reserviert|es|Reservado" }
		DEFAULT_VALUE 0;
	}
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0686
	}
}

COMMAND READ_P0686
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0686 }
	}
}

METHOD SET_PAR_NUMBER_0686
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 686;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0687
{
	LABEL "P0687 Anybus-CC Speed Ref.|de|P0687 Anybus-CC Drehz Sollw|es|P0687 Ref. Vel. Anybus-CC";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0687
	}
}

COMMAND READ_P0687
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0687 }
	}
}

METHOD SET_PAR_NUMBER_0687
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 687;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0692
{
	LABEL "P0692 Operation Mode Status|de|P0692 Operationsmod. Status|es|P0692 Estados Modo.Operac.";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE BIT_ENUMERATED(2)
	{
		{ 0x0001, "Orient.Startup|de|Gefhrter Start-up|es|Startup Orient" },
		{ 0x0002, "Not Used  |de|Reserviert|es|Reservado" },
		{ 0x0004, "Self Tuning|de|Selbstabgleich|es|Autoajuste" },
		{ 0x0008, "AutoGuidedP318|de|AutoGuidedP318|es|AutoGuiadaP318" },
		{ 0x0010, "Copy Function|de|Kopierfunktion|es|Funcin Copy" },
		{ 0x0020, "Copying MMF|de|Kopier MMF|es|Copia MMF" },
		{ 0x0040, "Reprogram.Inv.|de|Neuprog. Umr.|es|Conv.Reprogram" },
		{ 0x0080, "Aux Supply 24V|de|24V Versorgung|es|Fuente Aux 24V" },
		{ 0x0100, "Incomp. Param.|de|Param. Inkomp.|es|Parm. Incomp." },
		{ 0xFE00, "Incomp. Code|de|Inkomp. Code|es|Cdigo Imcomp." }
		DEFAULT_VALUE 0;
	}
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0692
	}
}

COMMAND READ_P0692
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0692 }
	}
}

METHOD SET_PAR_NUMBER_0692
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 692;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0693
{
	LABEL "P0693 Operation ModeCommand|de|P0693 Operationsmod. Komm.|es|P0693 Comandos Modo Oper.";
	CLASS CONTAINED;
	TYPE BIT_ENUMERATED(2)
	{
		{ 0x0001, "Abort Startup|de|Startup verl.|es|Aborta Startup" },
		{ 0x0002, "Not Used  |de|Reserviert|es|Reservado" },
		{ 0x0004, "Abort SelfTun.|de|SelfTun. verl.|es|Aborta Aajuste" },
		{ 0x0008, "Abort P0318|de|P0318 verl.|es|Aborta P0318" },
		{ 0x0010, "Reserved|de|Reserviert|es|Reservado" },
		{ 0x0020, "Abort MMF Copy|de|MMF Copy verl.|es|AbortaCopiaMMF" },
		{ 0x00C0, "Reserved|de|Reserviert|es|Reservado" },
		{ 0x0100, "Update Depend.|de|Update Abhng.|es|AtualizaDepend" },
		{ 0xFE00, "Reserved|de|Reserviert|es|Reservado" }
		DEFAULT_VALUE 0;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0693
	}
}

COMMAND READ_P0693
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0693 }
	}
}

METHOD SET_PAR_NUMBER_0693
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 693;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0693 LIKE READ_P0693
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 2, 181, P0693 }
		REPLY { }
	}
}

VARIABLE P0695
{
	LABEL "P0695 DOx Value|de|P0695 DOx Wert|es|P0695 Valor para DOx";
	CLASS CONTAINED;
	TYPE BIT_ENUMERATED(2)
	{
		{ 0x0001, "DO1|de|DO1|es|DO1" },
		{ 0x0002, "DO2|de|DO2|es|DO2" },
		{ 0x0004, "DO3|de|DO3|es|DO3" },
		{ 0x0008, "DO4|de|DO4|es|DO4" },
		{ 0x0010, "DO5|de|DO5|es|DO5" }
		DEFAULT_VALUE 0;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0695
	}
}

COMMAND READ_P0695
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0695 }
	}
}

METHOD SET_PAR_NUMBER_0695
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 695;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0695 LIKE READ_P0695
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 2, 183, P0695 }
		REPLY { }
	}
}

VARIABLE P0696
{
	LABEL "P0696 AOx Value 1|de|P0696 1. AOx Wert|es|P0696 Valor 1 para AOx";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0696
	}
}

COMMAND READ_P0696
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0696 }
	}
}

METHOD SET_PAR_NUMBER_0696
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 696;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0696 LIKE READ_P0696
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 2, 184, P0696 }
		REPLY { }
	}
}

VARIABLE P0697
{
	LABEL "P0697 AOx Value 2|de|P0697 2. AOx Wert|es|P0697 Valor 2 para AOx";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0697
	}
}

COMMAND READ_P0697
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0697 }
	}
}

METHOD SET_PAR_NUMBER_0697
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 697;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0697 LIKE READ_P0697
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 2, 185, P0697 }
		REPLY { }
	}
}

VARIABLE P0698
{
	LABEL "P0698 AOx Value 3|de|P0698 3. AOx Wert|es|P0698 Valor 3 para AOx";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0698
	}
}

COMMAND READ_P0698
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0698 }
	}
}

METHOD SET_PAR_NUMBER_0698
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 698;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0698 LIKE READ_P0698
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 2, 186, P0698 }
		REPLY { }
	}
}

VARIABLE P0699
{
	LABEL "P0699 AOx Value 4|de|P0699 4. AOx Wert|es|P0699 Valor 4 para AOx";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0699
	}
}

COMMAND READ_P0699
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0699 }
	}
}

METHOD SET_PAR_NUMBER_0699
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 699;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0699 LIKE READ_P0699
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 2, 187, P0699 }
		REPLY { }
	}
}

VARIABLE P0700
{
	LABEL "P0700 CAN Protocol|de|P0700 CAN Protokoll|es|P0700 Protocolo CAN";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 1, "CANopen|de|CANopen|es|CANopen" },
		{ 2, "DeviceNet|de|DeviceNet|es|DeviceNet" }
		DEFAULT_VALUE 2;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0700
	}
}

COMMAND READ_P0700
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0700 }
	}
}

METHOD SET_PAR_NUMBER_0700
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 700;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0700 LIKE READ_P0700
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 2, 188, P0700 }
		REPLY { }
	}
}

VARIABLE P0701
{
	LABEL "P0701 CAN Address|de|P0701 CAN Adresse|es|P0701 Direccin CAN";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 63;
		MIN_VALUE 0;
		MAX_VALUE 127;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0701
	}
}

COMMAND READ_P0701
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0701 }
	}
}

METHOD SET_PAR_NUMBER_0701
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 701;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0701 LIKE READ_P0701
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 2, 189, P0701 }
		REPLY { }
	}
}

VARIABLE P0702
{
	LABEL "P0702 CAN Baud Rate|de|P0702 CAN Baudrate|es|P0702 Tasa Comunicacin CAN";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "1 Mbps/Auto|de|1 Mbps/Auto|es|1 Mbps/Auto" },
		{ 1, "Reserved/Auto|de|Reserv./Auto|es|Reservado/Auto" },
		{ 2, "500 Kbps|de|500 Kbps|es|500 Kbps" },
		{ 3, "250 Kbps|de|250 Kbps|es|250 Kbps" },
		{ 4, "125 Kbps|de|125 Kbps|es|125 Kbps" },
		{ 5, "100 Kbps/Auto|de|100 Kbps/Auto|es|100 Kbps/Auto" },
		{ 6, "50 Kbps/Auto|de|50 Kbps/Auto|es|50 Kbps/Auto" },
		{ 7, "20 Kbps/Auto|de|20 Kbps/Auto|es|20 Kbps/Auto" },
		{ 8, "10 Kbps/Auto|de|10 Kbps/Auto|es|10 Kbps/Auto" }
		DEFAULT_VALUE 0;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0702
	}
}

COMMAND READ_P0702
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0702 }
	}
}

METHOD SET_PAR_NUMBER_0702
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 702;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0702 LIKE READ_P0702
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 2, 190, P0702 }
		REPLY { }
	}
}

VARIABLE P0703
{
	LABEL "P0703 Bus Off Reset|de|P0703 Bus Off Reset|es|P0703 Reset de Bus Off";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "Manual|de|Manual|es|Manual" },
		{ 1, "Automatic|de|Automatisch|es|Automtico" }
		DEFAULT_VALUE 1;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0703
	}
}

COMMAND READ_P0703
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0703 }
	}
}

METHOD SET_PAR_NUMBER_0703
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 703;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0703 LIKE READ_P0703
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 2, 191, P0703 }
		REPLY { }
	}
}

VARIABLE P0705
{
	LABEL "P0705 CAN Controller Status|de|P0705 CAN Controller Status|es|P0705 Estado ControladorCAN";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE ENUMERATED(2)
	{
		{ 0, "Disabled|de|Aus|es|Deshabilitado" },
		{ 1, "Auto-baud|de|Auto-Baud|es|Auto-baud" },
		{ 2, "CAN Enabled|de|CAN aktiv|es|CAN Activo" },
		{ 3, "Warning|de|Warnung|es|Warning" },
		{ 4, "Error Passive|de|Passiv. Fehler|es|Error Passive" },
		{ 5, "Bus Off|de|Bus Off|es|Bus Off" },
		{ 6, "No Bus Power|de|Ohne Busvers.|es|No Alimentado" }
		DEFAULT_VALUE 0;
	}
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0705
	}
}

COMMAND READ_P0705
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0705 }
	}
}

METHOD SET_PAR_NUMBER_0705
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 705;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0706
{
	LABEL "P0706 RX CAN Telegrams|de|P0706 RX CAN Telegramme|es|P0706 Telegramas CAN RX";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 65535;
	}
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0706
	}
}

COMMAND READ_P0706
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0706 }
	}
}

METHOD SET_PAR_NUMBER_0706
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 706;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0707
{
	LABEL "P0707 TX CAN Telegrams|de|P0707 TX CAN Telegramme|es|P0707 Telegramas CAN TX";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 65535;
	}
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0707
	}
}

COMMAND READ_P0707
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0707 }
	}
}

METHOD SET_PAR_NUMBER_0707
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 707;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0708
{
	LABEL "P0708 Bus Off Counter|de|P0708 Bus Off Zhler|es|P0708 Contador de Bus Off";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 65535;
	}
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0708
	}
}

COMMAND READ_P0708
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0708 }
	}
}

METHOD SET_PAR_NUMBER_0708
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 708;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0709
{
	LABEL "P0709 CAN Lost Messages|de|P0709 CAN verl. Telegramme|es|P0709 Mensajes CAN Perdidas";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 65535;
	}
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0709
	}
}

COMMAND READ_P0709
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0709 }
	}
}

METHOD SET_PAR_NUMBER_0709
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 709;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0710
{
	LABEL "P0710 DNet I/O instances|de|P0710 DNet I/O Instanzen|es|P0710 Instancias I/O DNet";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "ODVA Basic 2W|de|ODVA Basic 2W|es|ODVA Basic 2W" },
		{ 1, "ODVA Extend 2W|de|ODVA Extend 2W|es|ODVA Extend 2W" },
		{ 2, "Manuf.Spec. 2W|de|Herstel.Def.2W|es|Especif.Fab.2W" },
		{ 3, "Manuf.Spec. 3W|de|Herstel.Def.3W|es|Especif.Fab.3W" },
		{ 4, "Manuf.Spec. 4W|de|Herstel.Def.4W|es|Especif.Fab.4W" },
		{ 5, "Manuf.Spec. 5W|de|Herstel.Def.5W|es|Especif.Fab.5W" },
		{ 6, "Manuf.Spec. 6W|de|Herstel.Def.6W|es|Especif.Fab.6W" }
		DEFAULT_VALUE 0;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0710
	}
}

COMMAND READ_P0710
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0710 }
	}
}

METHOD SET_PAR_NUMBER_0710
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 710;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0710 LIKE READ_P0710
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 2, 198, P0710 }
		REPLY { }
	}
}

VARIABLE P0711
{
	LABEL "P0711 DNet Read Word #3|de|P0711 DNet Lese Wort #3|es|P0711 Lectura #3 DeviceNet";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE -1;
		MIN_VALUE -1;
		MAX_VALUE 1499;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0711
	}
}

COMMAND READ_P0711
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0711 }
	}
}

METHOD SET_PAR_NUMBER_0711
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 711;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0711 LIKE READ_P0711
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 2, 199, P0711 }
		REPLY { }
	}
}

VARIABLE P0712
{
	LABEL "P0712 DNet Read Word #4|de|P0712 DNet Lese Wort #4|es|P0712 Lectura #4 DeviceNet";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE -1;
		MIN_VALUE -1;
		MAX_VALUE 1499;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0712
	}
}

COMMAND READ_P0712
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0712 }
	}
}

METHOD SET_PAR_NUMBER_0712
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 712;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0712 LIKE READ_P0712
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 2, 200, P0712 }
		REPLY { }
	}
}

VARIABLE P0713
{
	LABEL "P0713 DNet Read Word #5|de|P0713 DNet Lese Wort #5|es|P0713 Lectura #5 DeviceNet";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE -1;
		MIN_VALUE -1;
		MAX_VALUE 1499;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0713
	}
}

COMMAND READ_P0713
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0713 }
	}
}

METHOD SET_PAR_NUMBER_0713
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 713;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0713 LIKE READ_P0713
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 2, 201, P0713 }
		REPLY { }
	}
}

VARIABLE P0714
{
	LABEL "P0714 DNet Read Word #6|de|P0714 DNet Lese Wort #6|es|P0714 Lectura #6 DeviceNet";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE -1;
		MIN_VALUE -1;
		MAX_VALUE 1499;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0714
	}
}

COMMAND READ_P0714
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0714 }
	}
}

METHOD SET_PAR_NUMBER_0714
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 714;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0714 LIKE READ_P0714
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 2, 202, P0714 }
		REPLY { }
	}
}

VARIABLE P0715
{
	LABEL "P0715 DNet Write Word #3|de|P0715 DNet Schreibe Wort #3|es|P0715 Escrita #3 DeviceNet";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE -1;
		MIN_VALUE -1;
		MAX_VALUE 1499;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0715
	}
}

COMMAND READ_P0715
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0715 }
	}
}

METHOD SET_PAR_NUMBER_0715
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 715;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0715 LIKE READ_P0715
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 2, 203, P0715 }
		REPLY { }
	}
}

VARIABLE P0716
{
	LABEL "P0716 DNet Write Word #4|de|P0716 DNet Schreibe Wort #4|es|P0716 Escrita #4 DeviceNet";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE -1;
		MIN_VALUE -1;
		MAX_VALUE 1499;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0716
	}
}

COMMAND READ_P0716
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0716 }
	}
}

METHOD SET_PAR_NUMBER_0716
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 716;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0716 LIKE READ_P0716
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 2, 204, P0716 }
		REPLY { }
	}
}

VARIABLE P0717
{
	LABEL "P0717 DNet Write Word #5|de|P0717 DNet Schreibe Wort #5|es|P0717 Escrita #5 DeviceNet";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE -1;
		MIN_VALUE -1;
		MAX_VALUE 1499;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0717
	}
}

COMMAND READ_P0717
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0717 }
	}
}

METHOD SET_PAR_NUMBER_0717
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 717;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0717 LIKE READ_P0717
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 2, 205, P0717 }
		REPLY { }
	}
}

VARIABLE P0718
{
	LABEL "P0718 DNet Write Word #6|de|P0718 DNet Schreibe Wort #6|es|P0718 Escrita #6 DeviceNet";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE -1;
		MIN_VALUE -1;
		MAX_VALUE 1499;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0718
	}
}

COMMAND READ_P0718
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0718 }
	}
}

METHOD SET_PAR_NUMBER_0718
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 718;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0718 LIKE READ_P0718
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 2, 206, P0718 }
		REPLY { }
	}
}

VARIABLE P0719
{
	LABEL "P0719 DNet Network Status|de|P0719 DNet Netzwerk Status|es|P0719 Estado Red DeviceNet";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE ENUMERATED(2)
	{
		{ 0, "Offline|de|Offline|es|Offline" },
		{ 1, "OnLine,NotConn|de|OnLine,o.Verb.|es|OnLine,No Con." },
		{ 2, "OnLine,Conn|de|OnLine, Verb.|es|OnLine Conect." },
		{ 3, "Conn.Timed-out|de|Verb. Timeout|es|ConexinExpir" },
		{ 4, "Link Failure|de|Verb. Fehler|es|Falla Conexin" },
		{ 5, "Auto-Baud|de|Auto-Baud|es|Auto-Baud" }
		DEFAULT_VALUE 0;
	}
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0719
	}
}

COMMAND READ_P0719
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0719 }
	}
}

METHOD SET_PAR_NUMBER_0719
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 719;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0720
{
	LABEL "P0720 DNet Master Status|de|P0720 DNet Master Status|es|P0720 Estado Maestro DNet";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE ENUMERATED(2)
	{
		{ 0, "Run|de|Run|es|Run" },
		{ 1, "Idle|de|Idle|es|Idle" }
		DEFAULT_VALUE 0;
	}
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0720
	}
}

COMMAND READ_P0720
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0720 }
	}
}

METHOD SET_PAR_NUMBER_0720
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 720;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0721
{
	LABEL "P0721 CANopen Comm. Status|de|P0721 CANopen Komm. Status|es|P0721 Estado Com. CANopen";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE ENUMERATED(2)
	{
		{ 0, "Disabled|de|Aus|es|Deshabilitado" },
		{ 1, "Reserved|de|Reserviert|es|Reservado" },
		{ 2, "Comm. Enabled|de|Komm. Ein|es|Comunic. Hab." },
		{ 3, "ErrorCtrl.Enab|de|ErrorCtrl.Enab|es|CtrlErroresHab" },
		{ 4, "Guarding Error|de|Guarding Error|es|Error Guarding" },
		{ 5, "HeartbeatError|de|HeartbeatError|es|ErrorHeartbeat" }
		DEFAULT_VALUE 0;
	}
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0721
	}
}

COMMAND READ_P0721
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0721 }
	}
}

METHOD SET_PAR_NUMBER_0721
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 721;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0722
{
	LABEL "P0722 CANopen Node State|de|P0722 CANopen Knoten Status|es|P0722 Estado Nudo CANopen";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE ENUMERATED(2)
	{
		{ 0, "Disabled|de|Aus|es|Deshabilitado" },
		{ 1, "Initialization|de|Initialisier.|es|Inicializacin" },
		{ 2, "Stopped|de|Stop|es|Parado" },
		{ 3, "Operational|de|Operational|es|Operacional" },
		{ 4, "PreOperational|de|Voroperational|es|Preoperacional" }
		DEFAULT_VALUE 0;
	}
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0722
	}
}

COMMAND READ_P0722
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0722 }
	}
}

METHOD SET_PAR_NUMBER_0722
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 722;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0723
{
	LABEL "P0723 Anybus Identification|de|P0723 Identifikation Anybus|es|P0723 Identificacin Anybus";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE ENUMERATED(2)
	{
		{ 0, "Disabled|de|Aus|es|Deshabilitado" },
		{ 1, "RS232|de|RS232|es|RS232" },
		{ 2, "RS422|de|RS422|es|RS422" },
		{ 3, "USB|de|USB|es|USB" },
		{ 4, "Serial Server|de|Seriel. Server|es|Serial Server" },
		{ 5, "Bluetooth|de|Bluetooth|es|Bluetooth" },
		{ 6, "Zigbee|de|Zigbee|es|Zigbee" },
		{ 7, "Reserved|de|Reserviert|es|Reservado" },
		{ 8, "Reserved|de|Reserviert|es|Reservado" },
		{ 9, "Reserved|de|Reserviert|es|Reservado" },
		{ 10, "RS485|de|RS485|es|RS485" },
		{ 11, "Reserved|de|Reserviert|es|Reservado" },
		{ 12, "Reserved|de|Reserviert|es|Reservado" },
		{ 13, "Reserved|de|Reserviert|es|Reservado" },
		{ 14, "Reserved|de|Reserviert|es|Reservado" },
		{ 15, "Reserved|de|Reserviert|es|Reservado" },
		{ 16, "Profibus DP|de|Profibus DP|es|Profibus DP" },
		{ 17, "DeviceNet|de|DeviceNet|es|DeviceNet" },
		{ 18, "CANopen|de|CANopen|es|CANopen" },
		{ 19, "EtherNet/IP|de|EtherNet/IP|es|EtherNet/IP" },
		{ 20, "CC-Link|de|CC-Link|es|CC-Link" },
		{ 21, "Modbus TCP|de|Modbus TCP|es|Modbus TCP" },
		{ 22, "Modbus RTU|de|Modbus RTU|es|Modbus RTU" },
		{ 23, "PROFINET IO|de|PROFINET IO|es|PROFINET IO" },
		{ 24, "PROFINET IRT|de|PROFINET IRT|es|PROFINET IRT" },
		{ 25, "Reserved|de|Reserviert|es|Reservado" }
		DEFAULT_VALUE 0;
	}
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0723
	}
}

COMMAND READ_P0723
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0723 }
	}
}

METHOD SET_PAR_NUMBER_0723
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 723;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0724
{
	LABEL "P0724 Anybus Comm. Status|de|P0724 Anybus Komm. Status|es|P0724 Estado Comunic.Anybus";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE ENUMERATED(2)
	{
		{ 0, "Disabled|de|Aus|es|Inactivo" },
		{ 1, "Not Supported|de|Nicht unterst|es|No Soportado" },
		{ 2, "Access Error|de|Zugriffsfehler|es|Error Acceso" },
		{ 3, "Offline|de|Offline|es|Offline" },
		{ 4, "Online|de|Online|es|Online" }
		DEFAULT_VALUE 0;
	}
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0724
	}
}

COMMAND READ_P0724
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0724 }
	}
}

METHOD SET_PAR_NUMBER_0724
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 724;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0725
{
	LABEL "P0725 Anybus Address|de|P0725 Anybus Adresse|es|P0725 Direccin Anybus";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 255;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0725
	}
}

COMMAND READ_P0725
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0725 }
	}
}

METHOD SET_PAR_NUMBER_0725
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 725;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0725 LIKE READ_P0725
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 2, 213, P0725 }
		REPLY { }
	}
}

VARIABLE P0726
{
	LABEL "P0726 Anybus Baud Rate|de|P0726 Anybus Baudrate|es|P0726 Tasa Comunic. Anybus";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 3;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0726
	}
}

COMMAND READ_P0726
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0726 }
	}
}

METHOD SET_PAR_NUMBER_0726
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 726;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0726 LIKE READ_P0726
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 2, 214, P0726 }
		REPLY { }
	}
}

VARIABLE P0727
{
	LABEL "P0727 Anybus I/O Words|de|P0727 Anybus I/O Worte|es|P0727 Palabras I/O Anybus";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 1, "Flexible|de|Flexibel|es|Flexible" },
		{ 2, "2 Words|de|2 Wrter|es|2 Palabras" },
		{ 3, "3 Words|de|3 Wrter|es|3 Palabras" },
		{ 4, "4 Words|de|4 Wrter|es|4 Palabras" },
		{ 5, "5 Words|de|5 Wrter|es|5 Palabras" },
		{ 6, "6 Words|de|6 Wrter|es|6 Palabras" },
		{ 7, "7 Words|de|7 Wrter|es|7 Palabras" },
		{ 8, "8 Words|de|8 Wrter|es|8 Palabras" },
		{ 9, "PLC11 Board|de|PLC11 Karte|es|Tarjeta PLC11" }
		DEFAULT_VALUE 2;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0727
	}
}

COMMAND READ_P0727
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0727 }
	}
}

METHOD SET_PAR_NUMBER_0727
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 727;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0727 LIKE READ_P0727
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 2, 215, P0727 }
		REPLY { }
	}
}

VARIABLE P0728
{
	LABEL "P0728 Anybus Read Word #3|de|P0728 Anybus Lese Wort #3|es|P0728 Lectura #3 Anybus";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 1499;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0728
	}
}

COMMAND READ_P0728
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0728 }
	}
}

METHOD SET_PAR_NUMBER_0728
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 728;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0728 LIKE READ_P0728
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 2, 216, P0728 }
		REPLY { }
	}
}

VARIABLE P0729
{
	LABEL "P0729 Anybus Read Word #4|de|P0729 Anybus Lese Wort #4|es|P0729 Lectura #4 Anybus";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 1499;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0729
	}
}

COMMAND READ_P0729
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0729 }
	}
}

METHOD SET_PAR_NUMBER_0729
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 729;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0729 LIKE READ_P0729
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 2, 217, P0729 }
		REPLY { }
	}
}

VARIABLE P0730
{
	LABEL "P0730 Anybus Read Word #5|de|P0730 Anybus Lese Wort #5|es|P0730 Lectura #5 Anybus";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 1499;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0730
	}
}

COMMAND READ_P0730
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0730 }
	}
}

METHOD SET_PAR_NUMBER_0730
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 730;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0730 LIKE READ_P0730
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 2, 218, P0730 }
		REPLY { }
	}
}

VARIABLE P0731
{
	LABEL "P0731 Anybus Read Word #6|de|P0731 Anybus Lese Wort #6|es|P0731 Lectura #6 Anybus";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 1499;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0731
	}
}

COMMAND READ_P0731
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0731 }
	}
}

METHOD SET_PAR_NUMBER_0731
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 731;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0731 LIKE READ_P0731
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 2, 219, P0731 }
		REPLY { }
	}
}

VARIABLE P0732
{
	LABEL "P0732 Anybus Read Word #7|de|P0732 Anybus Lese Wort #7|es|P0732 Lectura #7 Anybus";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 1499;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0732
	}
}

COMMAND READ_P0732
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0732 }
	}
}

METHOD SET_PAR_NUMBER_0732
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 732;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0732 LIKE READ_P0732
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 2, 220, P0732 }
		REPLY { }
	}
}

VARIABLE P0733
{
	LABEL "P0733 Anybus Read Word #8|de|P0733 Anybus Lese Wort #8|es|P0733 Lectura #8 Anybus";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 1499;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0733
	}
}

COMMAND READ_P0733
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0733 }
	}
}

METHOD SET_PAR_NUMBER_0733
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 733;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0733 LIKE READ_P0733
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 2, 221, P0733 }
		REPLY { }
	}
}

VARIABLE P0734
{
	LABEL "P0734 Anybus Write Word #3|de|P0734 Anybus Schr. Wort #3|es|P0734 Escrita #3 Anybus";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 1499;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0734
	}
}

COMMAND READ_P0734
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0734 }
	}
}

METHOD SET_PAR_NUMBER_0734
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 734;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0734 LIKE READ_P0734
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 2, 222, P0734 }
		REPLY { }
	}
}

VARIABLE P0735
{
	LABEL "P0735 Anybus Write Word #4|de|P0735 Anybus Schr. Wort #4|es|P0735 Escrita #4 Anybus";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 1499;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0735
	}
}

COMMAND READ_P0735
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0735 }
	}
}

METHOD SET_PAR_NUMBER_0735
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 735;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0735 LIKE READ_P0735
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 2, 223, P0735 }
		REPLY { }
	}
}

VARIABLE P0736
{
	LABEL "P0736 Anybus Write Word #5|de|P0736 Anybus Schr. Wort #5|es|P0736 Escrita #5 Anybus";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 1499;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0736
	}
}

COMMAND READ_P0736
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0736 }
	}
}

METHOD SET_PAR_NUMBER_0736
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 736;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0736 LIKE READ_P0736
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 2, 224, P0736 }
		REPLY { }
	}
}

VARIABLE P0737
{
	LABEL "P0737 Anybus Write Word #6|de|P0737 Anybus Schr. Wort #6|es|P0737 Escrita #6 Anybus";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 1499;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0737
	}
}

COMMAND READ_P0737
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0737 }
	}
}

METHOD SET_PAR_NUMBER_0737
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 737;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0737 LIKE READ_P0737
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 2, 225, P0737 }
		REPLY { }
	}
}

VARIABLE P0738
{
	LABEL "P0738 Anybus Write Word #7|de|P0738 Anybus Schr. Wort #7|es|P0738 Escrita #7 Anybus";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 1499;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0738
	}
}

COMMAND READ_P0738
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0738 }
	}
}

METHOD SET_PAR_NUMBER_0738
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 738;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0738 LIKE READ_P0738
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 2, 226, P0738 }
		REPLY { }
	}
}

VARIABLE P0739
{
	LABEL "P0739 Anybus Write Word #8|de|P0739 Anybus Schr. Wort #8|es|P0739 Escrita #8 Anybus";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 1499;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0739
	}
}

COMMAND READ_P0739
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0739 }
	}
}

METHOD SET_PAR_NUMBER_0739
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 739;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0739 LIKE READ_P0739
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 2, 227, P0739 }
		REPLY { }
	}
}

VARIABLE P0740
{
	LABEL "P0740 Profibus Comm. Status|de|P0740 Profibus Komm. Status|es|P0740 Estado Com. Profibus";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE ENUMERATED(2)
	{
		{ 0, "Disabled|de|Aus|es|Inactivo  " },
		{ 1, "Access Error|de|Zugriffsfehler|es|Error Acceso" },
		{ 2, "Offline|de|Offline|es|Offline" },
		{ 3, "Config. Error|de|Konfig. Fehler|es|Error Config." },
		{ 4, "Param. Error|de|Param. Fehler|es|Error Parm." },
		{ 5, "Clear Mode|de|Clear Modus|es|Modo Clear" },
		{ 6, "Online|de|Online|es|Online" }
		DEFAULT_VALUE 0;
	}
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0740
	}
}

COMMAND READ_P0740
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0740 }
	}
}

METHOD SET_PAR_NUMBER_0740
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 740;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0741
{
	LABEL "P0741 Profibus Data Profile|de|P0741 Profibus Datenprofil|es|P0741 Perfil Datos Profibus";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "PROFIdrive|de|PROFIdrive|es|PROFIdrive" },
		{ 1, "Manufacturer|de|Hersteller|es|Fabricante" }
		DEFAULT_VALUE 1;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0741
	}
}

COMMAND READ_P0741
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0741 }
	}
}

METHOD SET_PAR_NUMBER_0741
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 741;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0741 LIKE READ_P0741
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 2, 229, P0741 }
		REPLY { }
	}
}

VARIABLE P0742
{
	LABEL "P0742 Profibus Read Word #3|de|P0742 Profibus Lese Wort #3|es|P0742 Lectura #3 Profibus";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 1199;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0742
	}
}

COMMAND READ_P0742
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0742 }
	}
}

METHOD SET_PAR_NUMBER_0742
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 742;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0742 LIKE READ_P0742
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 2, 230, P0742 }
		REPLY { }
	}
}

VARIABLE P0743
{
	LABEL "P0743 Profibus Read Word #4|de|P0743 Profibus Lese Wort #4|es|P0743 Lectura #4 Profibus";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 1199;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0743
	}
}

COMMAND READ_P0743
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0743 }
	}
}

METHOD SET_PAR_NUMBER_0743
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 743;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0743 LIKE READ_P0743
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 2, 231, P0743 }
		REPLY { }
	}
}

VARIABLE P0744
{
	LABEL "P0744 Profibus Read Word #5|de|P0744 Profibus Lese Wort #5|es|P0744 Lectura #5 Profibus";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 1199;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0744
	}
}

COMMAND READ_P0744
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0744 }
	}
}

METHOD SET_PAR_NUMBER_0744
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 744;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0744 LIKE READ_P0744
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 2, 232, P0744 }
		REPLY { }
	}
}

VARIABLE P0745
{
	LABEL "P0745 Profibus Read Word #6|de|P0745 Profibus Lese Wort #6|es|P0745 Lectura #6 Profibus";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 1199;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0745
	}
}

COMMAND READ_P0745
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0745 }
	}
}

METHOD SET_PAR_NUMBER_0745
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 745;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0745 LIKE READ_P0745
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 2, 233, P0745 }
		REPLY { }
	}
}

VARIABLE P0746
{
	LABEL "P0746 Profibus Read Word #7|de|P0746 Profibus Lese Wort #7|es|P0746 Lectura #7 Profibus";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 1199;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0746
	}
}

COMMAND READ_P0746
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0746 }
	}
}

METHOD SET_PAR_NUMBER_0746
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 746;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0746 LIKE READ_P0746
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 2, 234, P0746 }
		REPLY { }
	}
}

VARIABLE P0747
{
	LABEL "P0747 Profibus Read Word #8|de|P0747 Profibus Lese Wort #8|es|P0747 Lectura #8 Profibus";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 1199;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0747
	}
}

COMMAND READ_P0747
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0747 }
	}
}

METHOD SET_PAR_NUMBER_0747
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 747;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0747 LIKE READ_P0747
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 2, 235, P0747 }
		REPLY { }
	}
}

VARIABLE P0748
{
	LABEL "P0748 Profibus Read Word #9|de|P0748 Profibus Lese Wort #9|es|P0748 Lectura #9 Profibus";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 1199;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0748
	}
}

COMMAND READ_P0748
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0748 }
	}
}

METHOD SET_PAR_NUMBER_0748
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 748;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0748 LIKE READ_P0748
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 2, 236, P0748 }
		REPLY { }
	}
}

VARIABLE P0749
{
	LABEL "P0749 Profibus Read Word#10|de|P0749 Profibus Lese Wort#10|es|P0749 Lectura #10 Profibus";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 1199;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0749
	}
}

COMMAND READ_P0749
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0749 }
	}
}

METHOD SET_PAR_NUMBER_0749
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 749;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0749 LIKE READ_P0749
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 2, 237, P0749 }
		REPLY { }
	}
}

VARIABLE P0750
{
	LABEL "P0750 Profibus Write Word#3|de|P0750 Profibus Schr. Wort#3|es|P0750 Escrita #3 Profibus";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 1199;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0750
	}
}

COMMAND READ_P0750
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0750 }
	}
}

METHOD SET_PAR_NUMBER_0750
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 750;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0750 LIKE READ_P0750
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 2, 238, P0750 }
		REPLY { }
	}
}

VARIABLE P0751
{
	LABEL "P0751 Profibus Write Word#4|de|P0751 Profibus Schr. Wort#4|es|P0751 Escrita #4 Profibus";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 1199;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0751
	}
}

COMMAND READ_P0751
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0751 }
	}
}

METHOD SET_PAR_NUMBER_0751
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 751;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0751 LIKE READ_P0751
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 2, 239, P0751 }
		REPLY { }
	}
}

VARIABLE P0752
{
	LABEL "P0752 Profibus Write Word#5|de|P0752 Profibus Schr. Wort#5|es|P0752 Escrita #5 Profibus";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 1199;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0752
	}
}

COMMAND READ_P0752
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0752 }
	}
}

METHOD SET_PAR_NUMBER_0752
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 752;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0752 LIKE READ_P0752
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 2, 240, P0752 }
		REPLY { }
	}
}

VARIABLE P0753
{
	LABEL "P0753 Profibus Write Word#6|de|P0753 Profibus Schr. Wort#6|es|P0753 Escrita #6 Profibus";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 1199;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0753
	}
}

COMMAND READ_P0753
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0753 }
	}
}

METHOD SET_PAR_NUMBER_0753
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 753;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0753 LIKE READ_P0753
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 2, 241, P0753 }
		REPLY { }
	}
}

VARIABLE P0754
{
	LABEL "P0754 Profibus Write Word#7|de|P0754 Profibus Schr. Wort#7|es|P0754 Escrita #7 Profibus";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 1199;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0754
	}
}

COMMAND READ_P0754
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0754 }
	}
}

METHOD SET_PAR_NUMBER_0754
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 754;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0754 LIKE READ_P0754
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 2, 242, P0754 }
		REPLY { }
	}
}

VARIABLE P0755
{
	LABEL "P0755 Profibus Write Word#8|de|P0755 Profibus Schr. Wort#8|es|P0755 Escrita #8 Profibus";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 1199;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0755
	}
}

COMMAND READ_P0755
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0755 }
	}
}

METHOD SET_PAR_NUMBER_0755
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 755;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0755 LIKE READ_P0755
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 2, 243, P0755 }
		REPLY { }
	}
}

VARIABLE P0756
{
	LABEL "P0756 Profibus Write Word#9|de|P0756 Profibus Schr. Wort#9|es|P0756 Escrita #9 Profibus";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 1199;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0756
	}
}

COMMAND READ_P0756
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0756 }
	}
}

METHOD SET_PAR_NUMBER_0756
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 756;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0756 LIKE READ_P0756
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 2, 244, P0756 }
		REPLY { }
	}
}

VARIABLE P0757
{
	LABEL "P0757 Profibus WriteWord#10|de|P0757 Profibus Schr.Wort#10|es|P0757 Escrita #10 Profibus";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 1199;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0757
	}
}

COMMAND READ_P0757
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0757 }
	}
}

METHOD SET_PAR_NUMBER_0757
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 757;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0757 LIKE READ_P0757
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 2, 245, P0757 }
		REPLY { }
	}
}

VARIABLE P0799
{
	LABEL "P0799 I/O Update delay |de|P0799 Update mit Versp.E/A |es|P0799 Atraso Atualiz. I/O";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{
		SCALING_FACTOR 0.1;
	}
	CONSTANT_UNIT "s";
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0799
	}
}

COMMAND READ_P0799
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0799 }
	}
}

METHOD SET_PAR_NUMBER_0799
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 799;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0799 LIKE READ_P0799
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 3, 31, P0799 }
		REPLY { }
	}
}

VARIABLE P0800
{
	LABEL "P0800 Phase U Book 1 Temper|de|P0800 Phase U Modul 1 Temp.|es|P0800 Temper. Fase U Book 1";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE INTEGER(2)
	{
		SCALING_FACTOR 0.1;
	}
	CONSTANT_UNIT "C";
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0800
	}
}

COMMAND READ_P0800
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0800 }
	}
}

METHOD SET_PAR_NUMBER_0800
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 800;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0801
{
	LABEL "P0801 Phase V Book 1 Temper|de|P0801 Phase V Modul 1 Temp.|es|P0801 Temper. Fase V Book 1";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE INTEGER(2)
	{
		SCALING_FACTOR 0.1;
	}
	CONSTANT_UNIT "C";
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0801
	}
}

COMMAND READ_P0801
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0801 }
	}
}

METHOD SET_PAR_NUMBER_0801
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 801;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0802
{
	LABEL "P0802 Phase W Book 1 Temper|de|P0802 Phase W Modul 1 Temp.|es|P0802 Temper. Fase W Book 1";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE INTEGER(2)
	{
		SCALING_FACTOR 0.1;
	}
	CONSTANT_UNIT "C";
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0802
	}
}

COMMAND READ_P0802
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0802 }
	}
}

METHOD SET_PAR_NUMBER_0802
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 802;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0803
{
	LABEL "P0803 Phase U Book 2 Temper|de|P0803 Phase U Modul 2 Temp.|es|P0803 Temper. Fase U Book 2";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE INTEGER(2)
	{
		SCALING_FACTOR 0.1;
	}
	CONSTANT_UNIT "C";
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0803
	}
}

COMMAND READ_P0803
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0803 }
	}
}

METHOD SET_PAR_NUMBER_0803
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 803;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0804
{
	LABEL "P0804 Phase V Book 2 Temper|de|P0804 Phase V Modul 2 Temp.|es|P0804 Temper. Fase V Book 2";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE INTEGER(2)
	{
		SCALING_FACTOR 0.1;
	}
	CONSTANT_UNIT "C";
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0804
	}
}

COMMAND READ_P0804
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0804 }
	}
}

METHOD SET_PAR_NUMBER_0804
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 804;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0805
{
	LABEL "P0805 Phase W Book 2 Temper|de|P0805 Phase W Modul 2 Temp.|es|P0805 Temper. Fase W Book 2";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE INTEGER(2)
	{
		SCALING_FACTOR 0.1;
	}
	CONSTANT_UNIT "C";
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0805
	}
}

COMMAND READ_P0805
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0805 }
	}
}

METHOD SET_PAR_NUMBER_0805
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 805;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0806
{
	LABEL "P0806 Phase U Book 3 Temper|de|P0806 Phase U Modul 3 Temp.|es|P0806 Temper. Fase U Book 3";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE INTEGER(2)
	{
		SCALING_FACTOR 0.1;
	}
	CONSTANT_UNIT "C";
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0806
	}
}

COMMAND READ_P0806
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0806 }
	}
}

METHOD SET_PAR_NUMBER_0806
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 806;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0807
{
	LABEL "P0807 Phase V Book 3 Temper|de|P0807 Phase V Modul 3 Temp.|es|P0807 Temper. Fase V Book 3";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE INTEGER(2)
	{
		SCALING_FACTOR 0.1;
	}
	CONSTANT_UNIT "C";
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0807
	}
}

COMMAND READ_P0807
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0807 }
	}
}

METHOD SET_PAR_NUMBER_0807
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 807;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0808
{
	LABEL "P0808 Phase W Book 3 Temper|de|P0808 Phase W Modul 3 Temp.|es|P0808 Temper. Fase W Book 3";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE INTEGER(2)
	{
		SCALING_FACTOR 0.1;
	}
	CONSTANT_UNIT "C";
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0808
	}
}

COMMAND READ_P0808
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0808 }
	}
}

METHOD SET_PAR_NUMBER_0808
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 808;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0809
{
	LABEL "P0809 Phase U Book 4 Temper|de|P0809 Phase U Modul 4 Temp.|es|P0809 Temper. Fase U Book 4";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE INTEGER(2)
	{
		SCALING_FACTOR 0.1;
	}
	CONSTANT_UNIT "C";
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0809
	}
}

COMMAND READ_P0809
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0809 }
	}
}

METHOD SET_PAR_NUMBER_0809
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 809;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0810
{
	LABEL "P0810 Phase V Book 4 Temper|de|P0810 Phase V Modul 4 Temp.|es|P0810 Temper. Fase V Book 4";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE INTEGER(2)
	{
		SCALING_FACTOR 0.1;
	}
	CONSTANT_UNIT "C";
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0810
	}
}

COMMAND READ_P0810
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0810 }
	}
}

METHOD SET_PAR_NUMBER_0810
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 810;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0811
{
	LABEL "P0811 Phase W Book 4 Temper|de|P0811 Phase W Modul 4 Temp.|es|P0811 Temper. Fase W Book 4";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE INTEGER(2)
	{
		SCALING_FACTOR 0.1;
	}
	CONSTANT_UNIT "C";
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0811
	}
}

COMMAND READ_P0811
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0811 }
	}
}

METHOD SET_PAR_NUMBER_0811
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 811;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0812
{
	LABEL "P0812 Phase U Book 5 Temper|de|P0812 Phase U Modul 5 Temp.|es|P0812 Temper. Fase U Book 5";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE INTEGER(2)
	{
		SCALING_FACTOR 0.1;
	}
	CONSTANT_UNIT "C";
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0812
	}
}

COMMAND READ_P0812
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0812 }
	}
}

METHOD SET_PAR_NUMBER_0812
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 812;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0813
{
	LABEL "P0813 Phase V Book 5 Temper|de|P0813 Phase V Modul 5 Temp.|es|P0813 Temper. Fase V Book 5";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE INTEGER(2)
	{
		SCALING_FACTOR 0.1;
	}
	CONSTANT_UNIT "C";
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0813
	}
}

COMMAND READ_P0813
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0813 }
	}
}

METHOD SET_PAR_NUMBER_0813
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 813;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0814
{
	LABEL "P0814 Phase W Book 5 Temper|de|P0814 Phase W Modul 5 Temp.|es|P0814 Temper. Fase W Book 5";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE INTEGER(2)
	{
		SCALING_FACTOR 0.1;
	}
	CONSTANT_UNIT "C";
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0814
	}
}

COMMAND READ_P0814
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0814 }
	}
}

METHOD SET_PAR_NUMBER_0814
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 814;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0832
{
	LABEL "P0832 DIM1 Function|de|P0832 Funktion DIM1 Eingang|es|P0832 Funcin Entrada DIM1";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "Not Used  |de|Ohne Funktion|es|Sin Funcin " },
		{ 1, "NoExt.FaultIPS|de|IPS Ext.Fehler|es|S/FallaExt.IPS" },
		{ 2, "NoRefrig.Fault|de|Fehler Khlung|es|S/Falla Refrig" },
		{ 3, "NoBrOvertFault|de|temp. Bremsen|es|S/Falla SobFre" },
		{ 4, "NoRect.Overt F|de|temp.Gleichr.|es|S/Falla SobRec" },
		{ 5, "NoRect.Temp.Al|de|Hohe Temp. GR|es|S/AlarmaTemRec" },
		{ 6, "No Rect. Fault|de|GR. Ext.Fehler|es|S/Falla RecExt" }
		DEFAULT_VALUE 0;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0832
	}
}

COMMAND READ_P0832
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0832 }
	}
}

METHOD SET_PAR_NUMBER_0832
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 832;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0832 LIKE READ_P0832
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 3, 64, P0832 }
		REPLY { }
	}
}

VARIABLE P0833
{
	LABEL "P0833 DIM2 Function|de|P0833 Funktion DIM2 Eingang|es|P0833 Funcin Entrada DIM2";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "Not Used  |de|Ohne Funktion|es|Sin Funcin " },
		{ 1, "NoExt.FaultIPS|de|IPS Ext.Fehler|es|S/FallaExt.IPS" },
		{ 2, "NoRefrig.Fault|de|Fehler Khlung|es|S/Falla Refrig" },
		{ 3, "NoBrOvertFault|de|temp. Bremsen|es|S/Falla SobFre" },
		{ 4, "NoRect.Overt F|de|temp.Gleichr.|es|S/Falla SobRec" },
		{ 5, "NoRect.Temp.Al|de|Hohe Temp. GR|es|S/AlarmaTemRec" },
		{ 6, "No Rect. Fault|de|GR. Ext.Fehler|es|S/Falla RecExt" }
		DEFAULT_VALUE 0;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0833
	}
}

COMMAND READ_P0833
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0833 }
	}
}

METHOD SET_PAR_NUMBER_0833
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 833;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0833 LIKE READ_P0833
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 3, 65, P0833 }
		REPLY { }
	}
}

VARIABLE P0834
{
	LABEL "P0834 DIM2 DIM1 Status|de|P0834 Status DIM2 DIM1|es|P0834 Estado DIM2 y DIM1";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE BIT_ENUMERATED(2)
	{
		{ 0x0001, "DIM1|de|DIM1|es|DIM1" },
		{ 0x0002, "DIM2|de|DIM2|es|DIM2" }
		DEFAULT_VALUE 0;
	}
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0834
	}
}

COMMAND READ_P0834
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0834 }
	}
}

METHOD SET_PAR_NUMBER_0834
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 834;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0918
{
	LABEL "P0918 Profibus Address|de|P0918 Profibus Adresse|es|P0918 Direccin Profibus";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 1;
		MIN_VALUE 1;
		MAX_VALUE 126;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0918
	}
}

COMMAND READ_P0918
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0918 }
	}
}

METHOD SET_PAR_NUMBER_0918
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 918;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0918 LIKE READ_P0918
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 3, 150, P0918 }
		REPLY { }
	}
}

VARIABLE P0922
{
	LABEL "P0922 Profibus Teleg. Sel.|de|P0922 Profibus Teleg. Wahl|es|P0922 Sel. Teleg. Profibus";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 1, "Std. Teleg. 1|de|Std. Teleg. 1|es|Teleg. Std. 1" },
		{ 2, "Telegram 100|de|Telegramm 100|es|Telegrama 100" },
		{ 3, "Telegram 101|de|Telegramm 101|es|Telegrama 101" },
		{ 4, "Telegram 102|de|Telegramm 102|es|Telegrama 102" },
		{ 5, "Telegram 103|de|Telegramm 103|es|Telegrama 103" },
		{ 6, "Telegram 104|de|Telegramm 104|es|Telegrama 104" },
		{ 7, "Telegram 105|de|Telegramm 105|es|Telegrama 105" },
		{ 8, "Telegram 106|de|Telegramm 106|es|Telegrama 106" },
		{ 9, "Telegram 107|de|Telegramm 107|es|Telegrama 107" }
		DEFAULT_VALUE 1;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0922
	}
}

COMMAND READ_P0922
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0922 }
	}
}

METHOD SET_PAR_NUMBER_0922
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 922;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0922 LIKE READ_P0922
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 3, 154, P0922 }
		REPLY { }
	}
}

VARIABLE P0944
{
	LABEL "P0944 Fault Message Counter|de|P0944 Fehlerzhler|es|P0944 Contador de Fallas";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 65535;
	}
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0944
	}
}

COMMAND READ_P0944
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0944 }
	}
}

METHOD SET_PAR_NUMBER_0944
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 944;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0947
{
	LABEL "P0947 Fault Number|de|P0947 Fehlernummer|es|P0947 Nmero de la Falla";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 65535;
	}
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0947
	}
}

COMMAND READ_P0947
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0947 }
	}
}

METHOD SET_PAR_NUMBER_0947
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 947;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0963
{
	LABEL "P0963 Profibus Baud Rate|de|P0963 Profibus Baud Rate|es|P0963 Tasa Comunic.Profibus";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE ENUMERATED(2)
	{
		{ 0, "9.6 kbit/s|de|9.6 kbit/s|es|9.6 kbit/s" },
		{ 1, "19.2 kbit/s|de|19.2 kbit/s|es|19.2 kbit/s" },
		{ 2, "93.75  kbit/s|de|93.75  kbit/s|es|93.75  kbit/s" },
		{ 3, "187.5  kbit/s|de|187.5  kbit/s|es|187.5  kbit/s" },
		{ 4, "500 kbit/s|de|500 kbit/s|es|500 kbit/s" },
		{ 5, "Not Detected|de|Nicht gefunden|es|No Detectada" },
		{ 6, "1500 kbit/s|de|1500 kbit/s|es|1500 kbit/s" },
		{ 7, "3000 kbit/s|de|3000 kbit/s|es|3000 kbit/s" },
		{ 8, "6000 kbit/s|de|6000 kbit/s|es|6000 kbit/s" },
		{ 9, "12000 kbit/s|de|12000 kbit/s|es|12000 kbit/s" },
		{ 10, "Reserved|de|Reserviert|es|Reservado" },
		{ 11, "45.45 kbit/s|de|45.45 kbit/s|es|45.45 kbit/s" }
		DEFAULT_VALUE 0;
	}
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0963
	}
}

COMMAND READ_P0963
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0963 }
	}
}

METHOD SET_PAR_NUMBER_0963
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 963;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0964
{
	LABEL "P0964 Drive Unit Ident.|de|P0964 Drive Identfikation|es|P0964 Identificacin Drive";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 65535;
	}
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0964
	}
}

COMMAND READ_P0964
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0964 }
	}
}

METHOD SET_PAR_NUMBER_0964
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 964;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0965
{
	LABEL "P0965 Profile Ident. Number|de|P0965 Profil Identifikation|es|P0965 Identificacin Perfil";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 65535;
	}
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0965
	}
}

COMMAND READ_P0965
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0965 }
	}
}

METHOD SET_PAR_NUMBER_0965
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 965;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0967
{
	LABEL "P0967 Control Word 1|de|P0967 Steuer word 1|es|P0967 Palabra de Control 1";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE BIT_ENUMERATED(2)
	{
		{ 0x0001, "ON|de|ON|es|ON" },
		{ 0x0002, "No Coast Stop|de|No Coast Stop|es|No Coast Stop" },
		{ 0x0004, "No Quick Stop|de|No Quick Stop|es|No Quick Stop" },
		{ 0x0008, "Enable Oper.|de|Enable Oper.|es|Enable Oper." },
		{ 0x0010, "Enable Ramp|de|Enable Ramp|es|Enable Ramp" },
		{ 0x0020, "Reserved|de|Reserviert|es|Reservado" },
		{ 0x0040, "Enable Setpt.|de|Enable Setpt.|es|Enable Setpt." },
		{ 0x0080, "Fault Ack.|de|Fault Ack.|es|Fault Ack." },
		{ 0x0100, "Jog 1|de|Jog 1|es|Jog 1" },
		{ 0x0200, "Reserved|de|Reserviert|es|Reservado" },
		{ 0x0400, "Control by PLC|de|Control by PLC|es|Control by PLC" },
		{ 0xF800, "Reserved|de|Reserviert|es|Reservado" }
		DEFAULT_VALUE 0;
	}
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0967
	}
}

COMMAND READ_P0967
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0967 }
	}
}

METHOD SET_PAR_NUMBER_0967
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 967;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0968
{
	LABEL "P0968 Status Word 1|de|P0968 Status Word 1|es|P0968 Palabra de Status 1";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE BIT_ENUMERATED(2)
	{
		{ 0x0001, "Rdy Switch On|de|Rdy Switch On|es|Rdy Switch On" },
		{ 0x0002, "Rdy to Operate|de|Rdy to Operate|es|Rdy to Operate" },
		{ 0x0004, "Oper. Enabled|de|Oper. Enabled|es|Oper. Enabled" },
		{ 0x0008, "Fault Present|de|Fault Present|es|Fault Present" },
		{ 0x0010, "Cst.Stop NotAct.|de|Cst.Stop NotAct.|es|Cst.Stop NotAct." },
		{ 0x0020, "Qck.Stop NotAct.|de|Qck.Stop NotAct.|es|Qck.Stop NotAct." },
		{ 0x0040, "SwitchOn Inhibit|de|SwitchOn Inhibit|es|SwitchOn Inhibit" },
		{ 0x0080, "Warning|de|Warning|es|Warning" },
		{ 0x0100, "Reserved|de|Reserviert|es|Reservado" },
		{ 0x0200, "Control by PLC|de|Control by PLC|es|Control by PLC" },
		{ 0xFC00, "Reserved|de|Reserviert|es|Reservado" }
		DEFAULT_VALUE 0;
	}
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0968
	}
}

COMMAND READ_P0968
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0968 }
	}
}

METHOD SET_PAR_NUMBER_0968
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 968;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P1000
{
	LABEL "P1000 SoftPLC Status|de|P1000 Status SoftPLC|es|P1000 Estado de la SoftPLC";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE ENUMERATED(2)
	{
		{ 0, "No Application|de|Ohne Anwendung|es|Sin Aplicacin" },
		{ 1, "Install. App.|de|Installiere|es|Instal. Aplic." },
		{ 2, "Incompat. App.|de|Inkompatibel|es|Aplic. Incomp." },
		{ 3, "App. Stopped|de|Gestoppt|es|Aplic. Parado" },
		{ 4, "App. Running|de|Anwend. Luft|es|Aplic." }
		DEFAULT_VALUE 0;
	}
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1000
	}
}

COMMAND READ_P1000
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1000 }
	}
}

METHOD SET_PAR_NUMBER_1000
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1000;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P1001
{
	LABEL "P1001 SoftPLC Command|de|P1001 SoftPLC Steuerung|es|P1001 Comando para SoftPLC";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "Stop Program|de|Progr. stoppen|es|Para Aplic." },
		{ 1, "Run Program|de|Progr. starten|es|Ejecuta Aplic." },
		{ 2, "Delete Program|de|Progr. lschen|es|Quitar Aplic." }
		DEFAULT_VALUE 0;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1001
	}
}

COMMAND READ_P1001
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1001 }
	}
}

METHOD SET_PAR_NUMBER_1001
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1001;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1001 LIKE READ_P1001
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 3, 233, P1001 }
		REPLY { }
	}
}

VARIABLE P1002
{
	LABEL "P1002 Scan Cycle Time|de|P1002 Zeit Scanzyklus|es|P1002 Tiempo Ciclo de Ejec.";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 65535;
	}
	CONSTANT_UNIT "ms";
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1002
	}
}

COMMAND READ_P1002
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1002 }
	}
}

METHOD SET_PAR_NUMBER_1002
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1002;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P1004
{
	LABEL "P1004 SoftPLC Monitoring|de|P1004 SoftPLC Steuerung|es|P1004 Supervisin  SoftPLC";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "Disabled|de|Aus|es|Inactivo  " },
		{ 1, "Alarm A708|de|Alarm A708|es|Alarma A708" },
		{ 2, "Fault F709|de|Fehler F709|es|Falla F709" }
		DEFAULT_VALUE 0;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1004
	}
}

COMMAND READ_P1004
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1004 }
	}
}

METHOD SET_PAR_NUMBER_1004
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1004;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1004 LIKE READ_P1004
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 3, 236, P1004 }
		REPLY { }
	}
}

VARIABLE P1010
{
	LABEL "P1010 SoftPLC Parameter 1|de|P1010 SoftPLC Parameter 1|es|P1010 Parmetro SoftPLC 1";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1010
	}
}

COMMAND READ_P1010
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1010 }
	}
}

METHOD SET_PAR_NUMBER_1010
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1010;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1010 LIKE READ_P1010
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 3, 242, P1010 }
		REPLY { }
	}
}

VARIABLE P1011
{
	LABEL "P1011 SoftPLC Parameter 2|de|P1011 SoftPLC Parameter 2|es|P1011 Parmetro SoftPLC 2";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1011
	}
}

COMMAND READ_P1011
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1011 }
	}
}

METHOD SET_PAR_NUMBER_1011
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1011;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1011 LIKE READ_P1011
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 3, 243, P1011 }
		REPLY { }
	}
}

VARIABLE P1012
{
	LABEL "P1012 SoftPLC Parameter 3|de|P1012 SoftPLC Parameter 3|es|P1012 Parmetro SoftPLC 3";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1012
	}
}

COMMAND READ_P1012
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1012 }
	}
}

METHOD SET_PAR_NUMBER_1012
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1012;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1012 LIKE READ_P1012
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 3, 244, P1012 }
		REPLY { }
	}
}

VARIABLE P1013
{
	LABEL "P1013 SoftPLC Parameter 4|de|P1013 SoftPLC Parameter 4|es|P1013 Parmetro SoftPLC 4";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1013
	}
}

COMMAND READ_P1013
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1013 }
	}
}

METHOD SET_PAR_NUMBER_1013
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1013;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1013 LIKE READ_P1013
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 3, 245, P1013 }
		REPLY { }
	}
}

VARIABLE P1014
{
	LABEL "P1014 SoftPLC Parameter 5|de|P1014 SoftPLC Parameter 5|es|P1014 Parmetro SoftPLC 5";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1014
	}
}

COMMAND READ_P1014
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1014 }
	}
}

METHOD SET_PAR_NUMBER_1014
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1014;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1014 LIKE READ_P1014
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 3, 246, P1014 }
		REPLY { }
	}
}

VARIABLE P1015
{
	LABEL "P1015 SoftPLC Parameter 6|de|P1015 SoftPLC Parameter 6|es|P1015 Parmetro SoftPLC 6";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1015
	}
}

COMMAND READ_P1015
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1015 }
	}
}

METHOD SET_PAR_NUMBER_1015
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1015;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1015 LIKE READ_P1015
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 3, 247, P1015 }
		REPLY { }
	}
}

VARIABLE P1016
{
	LABEL "P1016 SoftPLC Parameter 7|de|P1016 SoftPLC Parameter 7|es|P1016 Parmetro SoftPLC 7";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1016
	}
}

COMMAND READ_P1016
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1016 }
	}
}

METHOD SET_PAR_NUMBER_1016
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1016;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1016 LIKE READ_P1016
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 3, 248, P1016 }
		REPLY { }
	}
}

VARIABLE P1017
{
	LABEL "P1017 SoftPLC Parameter 8|de|P1017 SoftPLC Parameter 8|es|P1017 Parmetro SoftPLC 8";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1017
	}
}

COMMAND READ_P1017
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1017 }
	}
}

METHOD SET_PAR_NUMBER_1017
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1017;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1017 LIKE READ_P1017
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 3, 249, P1017 }
		REPLY { }
	}
}

VARIABLE P1018
{
	LABEL "P1018 SoftPLC Parameter 9|de|P1018 SoftPLC Parameter 9|es|P1018 Parmetro SoftPLC 9";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1018
	}
}

COMMAND READ_P1018
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1018 }
	}
}

METHOD SET_PAR_NUMBER_1018
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1018;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1018 LIKE READ_P1018
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 3, 250, P1018 }
		REPLY { }
	}
}

VARIABLE P1019
{
	LABEL "P1019 SoftPLC Parameter 10|de|P1019 SoftPLC Parameter 10|es|P1019 Parmetro SoftPLC 10";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1019
	}
}

COMMAND READ_P1019
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1019 }
	}
}

METHOD SET_PAR_NUMBER_1019
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1019;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1019 LIKE READ_P1019
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 3, 251, P1019 }
		REPLY { }
	}
}

VARIABLE P1020
{
	LABEL "P1020 SoftPLC Parameter 11|de|P1020 SoftPLC Parameter 11|es|P1020 Parmetro SoftPLC 11";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1020
	}
}

COMMAND READ_P1020
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1020 }
	}
}

METHOD SET_PAR_NUMBER_1020
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1020;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1020 LIKE READ_P1020
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 3, 252, P1020 }
		REPLY { }
	}
}

VARIABLE P1021
{
	LABEL "P1021 SoftPLC Parameter 12|de|P1021 SoftPLC Parameter 12|es|P1021 Parmetro SoftPLC 12";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1021
	}
}

COMMAND READ_P1021
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1021 }
	}
}

METHOD SET_PAR_NUMBER_1021
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1021;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1021 LIKE READ_P1021
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 3, 253, P1021 }
		REPLY { }
	}
}

VARIABLE P1022
{
	LABEL "P1022 SoftPLC Parameter 13|de|P1022 SoftPLC Parameter 13|es|P1022 Parmetro SoftPLC 13";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1022
	}
}

COMMAND READ_P1022
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1022 }
	}
}

METHOD SET_PAR_NUMBER_1022
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1022;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1022 LIKE READ_P1022
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 3, 254, P1022 }
		REPLY { }
	}
}

VARIABLE P1023
{
	LABEL "P1023 SoftPLC Parameter 14|de|P1023 SoftPLC Parameter 14|es|P1023 Parmetro SoftPLC 14";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1023
	}
}

COMMAND READ_P1023
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1023 }
	}
}

METHOD SET_PAR_NUMBER_1023
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1023;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1023 LIKE READ_P1023
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 3, 255, P1023 }
		REPLY { }
	}
}

VARIABLE P1024
{
	LABEL "P1024 SoftPLC Parameter 15|de|P1024 SoftPLC Parameter 15|es|P1024 Parmetro SoftPLC 15";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1024
	}
}

COMMAND READ_P1024
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1024 }
	}
}

METHOD SET_PAR_NUMBER_1024
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1024;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1024 LIKE READ_P1024
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 0, P1024 }
		REPLY { }
	}
}

VARIABLE P1025
{
	LABEL "P1025 SoftPLC Parameter 16|de|P1025 SoftPLC Parameter 16|es|P1025 Parmetro SoftPLC 16";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1025
	}
}

COMMAND READ_P1025
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1025 }
	}
}

METHOD SET_PAR_NUMBER_1025
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1025;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1025 LIKE READ_P1025
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 1, P1025 }
		REPLY { }
	}
}

VARIABLE P1026
{
	LABEL "P1026 SoftPLC Parameter 17|de|P1026 SoftPLC Parameter 17|es|P1026 Parmetro SoftPLC 17";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1026
	}
}

COMMAND READ_P1026
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1026 }
	}
}

METHOD SET_PAR_NUMBER_1026
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1026;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1026 LIKE READ_P1026
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 2, P1026 }
		REPLY { }
	}
}

VARIABLE P1027
{
	LABEL "P1027 SoftPLC Parameter 18|de|P1027 SoftPLC Parameter 18|es|P1027 Parmetro SoftPLC 18";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1027
	}
}

COMMAND READ_P1027
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1027 }
	}
}

METHOD SET_PAR_NUMBER_1027
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1027;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1027 LIKE READ_P1027
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 3, P1027 }
		REPLY { }
	}
}

VARIABLE P1028
{
	LABEL "P1028 SoftPLC Parameter 19|de|P1028 SoftPLC Parameter 19|es|P1028 Parmetro SoftPLC 19";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1028
	}
}

COMMAND READ_P1028
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1028 }
	}
}

METHOD SET_PAR_NUMBER_1028
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1028;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1028 LIKE READ_P1028
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 4, P1028 }
		REPLY { }
	}
}

VARIABLE P1029
{
	LABEL "P1029 SoftPLC Parameter 20|de|P1029 SoftPLC Parameter 20|es|P1029 Parmetro SoftPLC 20";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1029
	}
}

COMMAND READ_P1029
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1029 }
	}
}

METHOD SET_PAR_NUMBER_1029
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1029;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1029 LIKE READ_P1029
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 5, P1029 }
		REPLY { }
	}
}

VARIABLE P1030
{
	LABEL "P1030 SoftPLC Parameter 21|de|P1030 SoftPLC Parameter 21|es|P1030 Parmetro SoftPLC 21";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1030
	}
}

COMMAND READ_P1030
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1030 }
	}
}

METHOD SET_PAR_NUMBER_1030
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1030;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1030 LIKE READ_P1030
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 6, P1030 }
		REPLY { }
	}
}

VARIABLE P1031
{
	LABEL "P1031 SoftPLC Parameter 22|de|P1031 SoftPLC Parameter 22|es|P1031 Parmetro SoftPLC 22";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1031
	}
}

COMMAND READ_P1031
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1031 }
	}
}

METHOD SET_PAR_NUMBER_1031
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1031;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1031 LIKE READ_P1031
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 7, P1031 }
		REPLY { }
	}
}

VARIABLE P1032
{
	LABEL "P1032 SoftPLC Parameter 23|de|P1032 SoftPLC Parameter 23|es|P1032 Parmetro SoftPLC 23";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1032
	}
}

COMMAND READ_P1032
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1032 }
	}
}

METHOD SET_PAR_NUMBER_1032
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1032;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1032 LIKE READ_P1032
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 8, P1032 }
		REPLY { }
	}
}

VARIABLE P1033
{
	LABEL "P1033 SoftPLC Parameter 24|de|P1033 SoftPLC Parameter 24|es|P1033 Parmetro SoftPLC 24";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1033
	}
}

COMMAND READ_P1033
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1033 }
	}
}

METHOD SET_PAR_NUMBER_1033
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1033;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1033 LIKE READ_P1033
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 9, P1033 }
		REPLY { }
	}
}

VARIABLE P1034
{
	LABEL "P1034 SoftPLC Parameter 25|de|P1034 SoftPLC Parameter 25|es|P1034 Parmetro SoftPLC 25";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1034
	}
}

COMMAND READ_P1034
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1034 }
	}
}

METHOD SET_PAR_NUMBER_1034
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1034;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1034 LIKE READ_P1034
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 10, P1034 }
		REPLY { }
	}
}

VARIABLE P1035
{
	LABEL "P1035 SoftPLC Parameter 26|de|P1035 SoftPLC Parameter 26|es|P1035 Parmetro SoftPLC 26";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1035
	}
}

COMMAND READ_P1035
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1035 }
	}
}

METHOD SET_PAR_NUMBER_1035
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1035;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1035 LIKE READ_P1035
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 11, P1035 }
		REPLY { }
	}
}

VARIABLE P1036
{
	LABEL "P1036 SoftPLC Parameter 27|de|P1036 SoftPLC Parameter 27|es|P1036 Parmetro SoftPLC 27";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1036
	}
}

COMMAND READ_P1036
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1036 }
	}
}

METHOD SET_PAR_NUMBER_1036
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1036;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1036 LIKE READ_P1036
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 12, P1036 }
		REPLY { }
	}
}

VARIABLE P1037
{
	LABEL "P1037 SoftPLC Parameter 28|de|P1037 SoftPLC Parameter 28|es|P1037 Parmetro SoftPLC 28";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1037
	}
}

COMMAND READ_P1037
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1037 }
	}
}

METHOD SET_PAR_NUMBER_1037
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1037;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1037 LIKE READ_P1037
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 13, P1037 }
		REPLY { }
	}
}

VARIABLE P1038
{
	LABEL "P1038 SoftPLC Parameter 29|de|P1038 SoftPLC Parameter 29|es|P1038 Parmetro SoftPLC 29";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1038
	}
}

COMMAND READ_P1038
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1038 }
	}
}

METHOD SET_PAR_NUMBER_1038
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1038;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1038 LIKE READ_P1038
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 14, P1038 }
		REPLY { }
	}
}

VARIABLE P1039
{
	LABEL "P1039 SoftPLC Parameter 30|de|P1039 SoftPLC Parameter 30|es|P1039 Parmetro SoftPLC 30";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1039
	}
}

COMMAND READ_P1039
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1039 }
	}
}

METHOD SET_PAR_NUMBER_1039
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1039;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1039 LIKE READ_P1039
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 15, P1039 }
		REPLY { }
	}
}

VARIABLE P1040
{
	LABEL "P1040 SoftPLC Parameter 31|de|P1040 SoftPLC Parameter 31|es|P1040 Parmetro SoftPLC 31";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1040
	}
}

COMMAND READ_P1040
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1040 }
	}
}

METHOD SET_PAR_NUMBER_1040
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1040;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1040 LIKE READ_P1040
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 16, P1040 }
		REPLY { }
	}
}

VARIABLE P1041
{
	LABEL "P1041 SoftPLC Parameter 32|de|P1041 SoftPLC Parameter 32|es|P1041 Parmetro SoftPLC 32";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1041
	}
}

COMMAND READ_P1041
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1041 }
	}
}

METHOD SET_PAR_NUMBER_1041
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1041;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1041 LIKE READ_P1041
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 17, P1041 }
		REPLY { }
	}
}

VARIABLE P1042
{
	LABEL "P1042 SoftPLC Parameter 33|de|P1042 SoftPLC Parameter 33|es|P1042 Parmetro SoftPLC 33";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1042
	}
}

COMMAND READ_P1042
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1042 }
	}
}

METHOD SET_PAR_NUMBER_1042
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1042;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1042 LIKE READ_P1042
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 18, P1042 }
		REPLY { }
	}
}

VARIABLE P1043
{
	LABEL "P1043 SoftPLC Parameter 34|de|P1043 SoftPLC Parameter 34|es|P1043 Parmetro SoftPLC 34";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1043
	}
}

COMMAND READ_P1043
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1043 }
	}
}

METHOD SET_PAR_NUMBER_1043
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1043;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1043 LIKE READ_P1043
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 19, P1043 }
		REPLY { }
	}
}

VARIABLE P1044
{
	LABEL "P1044 SoftPLC Parameter 35|de|P1044 SoftPLC Parameter 35|es|P1044 Parmetro SoftPLC 35";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1044
	}
}

COMMAND READ_P1044
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1044 }
	}
}

METHOD SET_PAR_NUMBER_1044
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1044;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1044 LIKE READ_P1044
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 20, P1044 }
		REPLY { }
	}
}

VARIABLE P1045
{
	LABEL "P1045 SoftPLC Parameter 36|de|P1045 SoftPLC Parameter 36|es|P1045 Parmetro SoftPLC 36";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1045
	}
}

COMMAND READ_P1045
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1045 }
	}
}

METHOD SET_PAR_NUMBER_1045
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1045;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1045 LIKE READ_P1045
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 21, P1045 }
		REPLY { }
	}
}

VARIABLE P1046
{
	LABEL "P1046 SoftPLC Parameter 37|de|P1046 SoftPLC Parameter 37|es|P1046 Parmetro SoftPLC 37";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1046
	}
}

COMMAND READ_P1046
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1046 }
	}
}

METHOD SET_PAR_NUMBER_1046
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1046;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1046 LIKE READ_P1046
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 22, P1046 }
		REPLY { }
	}
}

VARIABLE P1047
{
	LABEL "P1047 SoftPLC Parameter 38|de|P1047 SoftPLC Parameter 38|es|P1047 Parmetro SoftPLC 38";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1047
	}
}

COMMAND READ_P1047
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1047 }
	}
}

METHOD SET_PAR_NUMBER_1047
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1047;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1047 LIKE READ_P1047
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 23, P1047 }
		REPLY { }
	}
}

VARIABLE P1048
{
	LABEL "P1048 SoftPLC Parameter 39|de|P1048 SoftPLC Parameter 39|es|P1048 Parmetro SoftPLC 39";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1048
	}
}

COMMAND READ_P1048
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1048 }
	}
}

METHOD SET_PAR_NUMBER_1048
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1048;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1048 LIKE READ_P1048
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 24, P1048 }
		REPLY { }
	}
}

VARIABLE P1049
{
	LABEL "P1049 SoftPLC Parameter 40|de|P1049 SoftPLC Parameter 40|es|P1049 Parmetro SoftPLC 40";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1049
	}
}

COMMAND READ_P1049
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1049 }
	}
}

METHOD SET_PAR_NUMBER_1049
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1049;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1049 LIKE READ_P1049
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 25, P1049 }
		REPLY { }
	}
}

VARIABLE P1050
{
	LABEL "P1050 SoftPLC Parameter 41|de|P1050 SoftPLC Parameter 41|es|P1050 Parmetro SoftPLC 41";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1050
	}
}

COMMAND READ_P1050
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1050 }
	}
}

METHOD SET_PAR_NUMBER_1050
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1050;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1050 LIKE READ_P1050
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 26, P1050 }
		REPLY { }
	}
}

VARIABLE P1051
{
	LABEL "P1051 SoftPLC Parameter 42|de|P1051 SoftPLC Parameter 42|es|P1051 Parmetro SoftPLC 42";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1051
	}
}

COMMAND READ_P1051
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1051 }
	}
}

METHOD SET_PAR_NUMBER_1051
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1051;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1051 LIKE READ_P1051
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 27, P1051 }
		REPLY { }
	}
}

VARIABLE P1052
{
	LABEL "P1052 SoftPLC Parameter 43|de|P1052 SoftPLC Parameter 43|es|P1052 Parmetro SoftPLC 43";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1052
	}
}

COMMAND READ_P1052
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1052 }
	}
}

METHOD SET_PAR_NUMBER_1052
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1052;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1052 LIKE READ_P1052
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 28, P1052 }
		REPLY { }
	}
}

VARIABLE P1053
{
	LABEL "P1053 SoftPLC Parameter 44|de|P1053 SoftPLC Parameter 44|es|P1053 Parmetro SoftPLC 44";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1053
	}
}

COMMAND READ_P1053
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1053 }
	}
}

METHOD SET_PAR_NUMBER_1053
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1053;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1053 LIKE READ_P1053
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 29, P1053 }
		REPLY { }
	}
}

VARIABLE P1054
{
	LABEL "P1054 SoftPLC Parameter 45|de|P1054 SoftPLC Parameter 45|es|P1054 Parmetro SoftPLC 45";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1054
	}
}

COMMAND READ_P1054
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1054 }
	}
}

METHOD SET_PAR_NUMBER_1054
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1054;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1054 LIKE READ_P1054
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 30, P1054 }
		REPLY { }
	}
}

VARIABLE P1055
{
	LABEL "P1055 SoftPLC Parameter 46|de|P1055 SoftPLC Parameter 46|es|P1055 Parmetro SoftPLC 46";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1055
	}
}

COMMAND READ_P1055
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1055 }
	}
}

METHOD SET_PAR_NUMBER_1055
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1055;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1055 LIKE READ_P1055
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 31, P1055 }
		REPLY { }
	}
}

VARIABLE P1056
{
	LABEL "P1056 SoftPLC Parameter 47|de|P1056 SoftPLC Parameter 47|es|P1056 Parmetro SoftPLC 47";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1056
	}
}

COMMAND READ_P1056
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1056 }
	}
}

METHOD SET_PAR_NUMBER_1056
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1056;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1056 LIKE READ_P1056
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 32, P1056 }
		REPLY { }
	}
}

VARIABLE P1057
{
	LABEL "P1057 SoftPLC Parameter 48|de|P1057 SoftPLC Parameter 48|es|P1057 Parmetro SoftPLC 48";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1057
	}
}

COMMAND READ_P1057
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1057 }
	}
}

METHOD SET_PAR_NUMBER_1057
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1057;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1057 LIKE READ_P1057
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 33, P1057 }
		REPLY { }
	}
}

VARIABLE P1058
{
	LABEL "P1058 SoftPLC Parameter 49|de|P1058 SoftPLC Parameter 49|es|P1058 Parmetro SoftPLC 49";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1058
	}
}

COMMAND READ_P1058
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1058 }
	}
}

METHOD SET_PAR_NUMBER_1058
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1058;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1058 LIKE READ_P1058
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 34, P1058 }
		REPLY { }
	}
}

VARIABLE P1059
{
	LABEL "P1059 SoftPLC Parameter 50|de|P1059 SoftPLC Parameter 50|es|P1059 Parmetro SoftPLC 50";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1059
	}
}

COMMAND READ_P1059
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1059 }
	}
}

METHOD SET_PAR_NUMBER_1059
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1059;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1059 LIKE READ_P1059
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 35, P1059 }
		REPLY { }
	}
}











